Class: Kubernetes::ApiClient

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/api_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config = Configuration.default) ⇒ ApiClient

Initializes the ApiClient

Parameters:

  • config (Hash) (defaults to: Configuration.default)

    a customizable set of options

Options Hash (config):

  • Configuration (Configuration)

    for initializing the object, default to Configuration.default



35
36
37
38
39
40
41
42
# File 'lib/kubernetes/api_client.rb', line 35

def initialize(config = Configuration.default)
  @config = config
  @user_agent = "OpenAPI-Generator/#{VERSION}/ruby"
  @default_headers = {
    'Content-Type' => 'application/json',
    'User-Agent' => @user_agent
  }
end

Instance Attribute Details

#configObject

The Configuration object holding settings to be used in the API client.



26
27
28
# File 'lib/kubernetes/api_client.rb', line 26

def config
  @config
end

#default_headersHash

Defines the headers to be used in HTTP requests of all API calls by default.

Returns:

  • (Hash)


31
32
33
# File 'lib/kubernetes/api_client.rb', line 31

def default_headers
  @default_headers
end

Class Method Details

.defaultObject



44
45
46
47
48
49
50
# File 'lib/kubernetes/api_client.rb', line 44

def self.default
  return @@default if defined?(@@default) && @@default

  @default_mutex.synchronize do
    @@default ||= ApiClient.new
  end
end

.reset_defaultObject



52
53
54
55
56
# File 'lib/kubernetes/api_client.rb', line 52

def self.reset_default
  @default_mutex.synchronize do
    @@default = nil
  end
end

Instance Method Details

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/kubernetes/api_client.rb', line 412

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as typhoeus will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#build_request(http_method, path, opts = {}) ⇒ Typhoeus::Request

Builds the HTTP request

Parameters:

  • http_method (String)

    HTTP method/verb (e.g. POST)

  • path (String)

    URL path (e.g. /account/new)

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :header_params (Hash)

    Header parameters

  • :query_params (Hash)

    Query parameters

  • :form_params (Hash)

    Query parameters

  • :body (Object)

    HTTP body (JSON/XML)

Returns:

  • (Typhoeus::Request)

    A Typhoeus Request



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/kubernetes/api_client.rb', line 111

def build_request(http_method, path, opts = {})
  url = build_request_url(path, opts)
  http_method = http_method.to_sym.downcase

  header_params = @default_headers.merge(opts[:header_params] || {})
  query_params = opts[:query_params] || {}
  form_params = opts[:form_params] || {}

  update_params_for_auth! header_params, query_params, opts[:auth_names]

  # set ssl_verifyhosts option based on @config.verify_ssl_host (true/false)
  _verify_ssl_host = @config.verify_ssl_host ? 2 : 0

  req_opts = {
    :method => http_method,
    :headers => header_params,
    :params => query_params,
    :params_encoding => @config.params_encoding,
    :timeout => @config.timeout,
    :ssl_verifypeer => @config.verify_ssl,
    :ssl_verifyhost => _verify_ssl_host,
    :sslcert => @config.cert_file,
    :sslkey => @config.key_file,
    :verbose => @config.debugging
  }

  # set custom cert, if provided
  req_opts[:cainfo] = @config.ssl_ca_cert if @config.ssl_ca_cert

  if [:post, :patch, :put, :delete].include?(http_method)
    req_body = build_request_body(header_params, form_params, opts[:body])
    req_opts.update :body => req_body
    if @config.debugging
      @config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n"
    end
  end

  request = Typhoeus::Request.new(url, req_opts)
  download_file(request) if opts[:return_type] == 'File'
  request
end

#build_request_body(header_params, form_params, body) ⇒ String

Builds the HTTP request body

Parameters:

  • header_params (Hash)

    Header parameters

  • form_params (Hash)

    Query parameters

  • body (Object)

    HTTP body (JSON/XML)

Returns:

  • (String)

    HTTP body data in the form of string



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/kubernetes/api_client.rb', line 159

def build_request_body(header_params, form_params, body)
  # http form
  if header_params['Content-Type'] == 'application/x-www-form-urlencoded' ||
      header_params['Content-Type'] == 'multipart/form-data'
    data = {}
    form_params.each do |key, value|
      case value
      when ::File, ::Array, nil
        # let typhoeus handle File, Array and nil parameters
        data[key] = value
      else
        data[key] = value.to_s
      end
    end
  elsif body
    data = body.is_a?(String) ? body : body.to_json
  else
    data = nil
  end
  data
end

#build_request_url(path, opts = {}) ⇒ Object



320
321
322
323
324
# File 'lib/kubernetes/api_client.rb', line 320

def build_request_url(path, opts = {})
  # Add leading and trailing slashes to path
  path = "/#{path}".gsub(/\/+/, '/')
  @config.base_url(opts[:operation]) + path
end

#call_api(http_method, path, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Call an API with given options.

Returns:

  • (Array<(Object, Integer, Hash)>)

    an array of 3 elements: the data deserialized from response body (could be nil), response status code and response headers.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/kubernetes/api_client.rb', line 62

def call_api(http_method, path, opts = {})
  retries_performed = 0

  loop do
    request = build_request(http_method, path, opts)
    response = request.run

    if @config.debugging
      @config.logger.debug "HTTP response body ~BEGIN~\n#{response.body}\n~END~\n"
    end

    unless response.success?
      if retry_request?(response, retries_performed)
        interval_seconds = retry_interval_seconds(response, retries_performed)
        log_retry_attempt(response, retries_performed + 1, interval_seconds)
        sleep interval_seconds
        retries_performed += 1
        next
      end

      if response.timed_out?
        fail ApiError.new(:code => 0,
                          :message => 'Connection timed out')
      elsif response.code == 0
        # Errors from libcurl will be made visible here
        fail ApiError.new(:code => 0,
                          :message => response.return_message)
      else
        fail ApiError.new(:code => response.code,
                          :response_headers => response.headers,
                          :response_body => response.body),
             response.status_message
      end
    end

    data = opts[:return_type] ? deserialize(response, opts[:return_type]) : nil
    return data, response.code, response.headers
  end
end

#convert_to_type(data, return_type) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/kubernetes/api_client.rb', line 274

def convert_to_type(data, return_type)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'Time'
    # parse date time (expecting ISO 8601 format)
    Time.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type) }
    end
  else
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(return_type)
    klass.respond_to?(:openapi_one_of) ? klass.build(data) : klass.build_from_hash(data)
  end
end

#deserialize(response, return_type) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • response (Response)

    HTTP response

  • return_type (String)

    some examples: “User”, “Array<User>”, “Hash<String, Integer>”



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/kubernetes/api_client.rb', line 235

def deserialize(response, return_type)
  body = response.body

  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  return @tempfile if return_type == 'File'

  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  unless json_mime?(content_type)
    fail ApiError.new(:code => response.code,
                      :response_headers => response.headers,
                      :response_body => body,
                      :message => "Content-Type is not supported: #{content_type}")
  end

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date Time).include?(return_type)
      data = body
    else
      raise e
    end
  end

  convert_to_type data, return_type
end

#download_file(request) ⇒ Object

Save response body into a file in (the defined) temporary folder, using the filename from the “Content-Disposition” header if provided, otherwise a random filename. The response body is written to the file in chunks in order to handle files which size is larger than maximum Ruby String or even larger than the maximum memory a Ruby process can use.



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/kubernetes/api_client.rb', line 188

def download_file(request)
  tempfile = nil
  encoding = nil
  request.on_headers do |response|
    content_disposition = response.headers['Content-Disposition']
    if content_disposition && content_disposition =~ /filename=/i
      filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
      prefix = sanitize_filename(filename)
    else
      prefix = 'download-'
    end
    prefix = prefix + '-' unless prefix.end_with?('-')
    encoding = response.body.encoding
    tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
    @tempfile = tempfile
  end
  request.on_body do |chunk|
    chunk.force_encoding(encoding)
    tempfile.write(chunk)
  end
  request.on_complete do |response|
    if tempfile
      tempfile.close
      @config.logger.info "Temp file written to #{tempfile.path}, please copy the file to a proper folder "\
                          "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                          "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                          "explicitly with `tempfile.delete`"
    end
  end
end

#fetch_retry_configuration(key, default) ⇒ Object



500
501
502
503
504
505
506
507
508
# File 'lib/kubernetes/api_client.rb', line 500

def fetch_retry_configuration(key, default)
  return default unless @config.retry_configuration.is_a?(Hash)

  if @config.retry_configuration.key?(key)
    @config.retry_configuration[key]
  else
    @config.retry_configuration.fetch(key.to_s, default)
  end
end

#json_mime?(mime) ⇒ Boolean

Check if the given MIME is a JSON MIME. JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



227
228
229
# File 'lib/kubernetes/api_client.rb', line 227

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil?
end

#log_retry_attempt(response, retry_number, interval_seconds) ⇒ Object



446
447
448
449
450
451
452
453
# File 'lib/kubernetes/api_client.rb', line 446

def log_retry_attempt(response, retry_number, interval_seconds)
  @config.logger.info(
    "Retrying API request after HTTP #{response.code} (retry #{retry_number}/#{max_retry_attempts}) in #{interval_seconds} seconds"
  )
  return unless @config.debugging

  @config.logger.debug("Retry response body: #{response.body}")
end

#max_retry_attemptsObject



455
456
457
458
# File 'lib/kubernetes/api_client.rb', line 455

def max_retry_attempts
  value = fetch_retry_configuration(:max_retries, 0)
  [value.to_i, 0].max
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



389
390
391
# File 'lib/kubernetes/api_client.rb', line 389

def object_to_hash(obj)
  sanitize_for_serialization(obj)
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



375
376
377
378
379
380
381
382
383
384
# File 'lib/kubernetes/api_client.rb', line 375

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#parse_retry_after_from_body(body) ⇒ Object



488
489
490
491
492
493
494
495
496
497
498
# File 'lib/kubernetes/api_client.rb', line 488

def parse_retry_after_from_body(body)
  return nil if body.nil? || body.empty?

  parsed = JSON.parse(body)
  retry_after = parsed.dig('details', 'retryAfterSeconds') || parsed.dig(:details, :retryAfterSeconds)
  return nil if retry_after.nil?

  retry_after.to_f
rescue JSON::ParserError, TypeError
  nil
end

#parse_retry_after_header(header_value) ⇒ Object



476
477
478
479
480
481
482
483
484
485
486
# File 'lib/kubernetes/api_client.rb', line 476

def parse_retry_after_header(header_value)
  return nil if header_value.nil?

  integer_value = Integer(header_value, exception: false)
  return integer_value.to_f if integer_value

  retry_at = Time.httpdate(header_value)
  [retry_at - Time.now, 0.0].max
rescue ArgumentError
  nil
end

#retry_base_interval_secondsObject



460
461
462
# File 'lib/kubernetes/api_client.rb', line 460

def retry_base_interval_seconds
  [fetch_retry_configuration(:base_interval_seconds, 1.0).to_f, 0.0].max
end

#retry_interval_seconds(response, retries_performed) ⇒ Object



439
440
441
442
443
444
# File 'lib/kubernetes/api_client.rb', line 439

def retry_interval_seconds(response, retries_performed)
  exponential_interval = retry_base_interval_seconds * (2**retries_performed)
  server_interval = server_retry_after_seconds(response)

  server_interval ? [exponential_interval, server_interval].max : exponential_interval
end

#retry_request?(response, retries_performed) ⇒ Boolean

Returns:

  • (Boolean)


430
431
432
433
434
435
436
437
# File 'lib/kubernetes/api_client.rb', line 430

def retry_request?(response, retries_performed)
  return false if response.timed_out?
  return false if response.code.to_i == 0
  return false if max_retry_attempts <= 0
  return false if retries_performed >= max_retry_attempts

  retry_statuses.include?(response.code.to_i)
end

#retry_statusesObject



464
465
466
# File 'lib/kubernetes/api_client.rb', line 464

def retry_statuses
  Array(fetch_retry_configuration(:retry_statuses, [429, 500, 501, 502, 503])).map(&:to_i)
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



316
317
318
# File 'lib/kubernetes/api_client.rb', line 316

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#sanitize_for_serialization(obj) ⇒ Object



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/kubernetes/api_client.rb', line 393

def sanitize_for_serialization(obj)
  case obj
  when Array
    obj.map { |item| sanitize_for_serialization(item) }
  when Hash
    obj.each_with_object({}) do |(key, value), result|
      result[key] = sanitize_for_serialization(value)
    end
  when Time, Date, DateTime
    obj.iso8601
  else
    return sanitize_for_serialization(obj.to_hash) if obj.respond_to?(:to_hash)

    obj
  end
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



354
355
356
357
358
359
# File 'lib/kubernetes/api_client.rb', line 354

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



364
365
366
367
368
369
370
# File 'lib/kubernetes/api_client.rb', line 364

def select_header_content_type(content_types)
  # use application/json by default
  return 'application/json' if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#server_retry_after_seconds(response) ⇒ Object



468
469
470
471
472
473
474
# File 'lib/kubernetes/api_client.rb', line 468

def server_retry_after_seconds(response)
  header_value = response.headers['Retry-After'] if response.respond_to?(:headers) && response.headers.is_a?(Hash)
  header_seconds = parse_retry_after_header(header_value)
  return header_seconds if header_seconds

  parse_retry_after_from_body(response.body)
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update hearder and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



331
332
333
334
335
336
337
338
339
340
341
# File 'lib/kubernetes/api_client.rb', line 331

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` or `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. openapi-generator/ruby/1.0.0)



346
347
348
349
# File 'lib/kubernetes/api_client.rb', line 346

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end