Class: Kubernetes::AuthenticationV1Api

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/api/authentication_v1_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AuthenticationV1Api

Returns a new instance of AuthenticationV1Api.



19
20
21
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_self_subject_review(body, opts = {}) ⇒ V1SelfSubjectReview

create a SelfSubjectReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If 'true', then the output is pretty printed. Defaults to 'false' unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:



30
31
32
33
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 30

def create_self_subject_review(body, opts = {})
  data, _status_code, _headers = create_self_subject_review_with_http_info(body, opts)
  data
end

#create_self_subject_review_with_http_info(body, opts = {}) ⇒ Array<(V1SelfSubjectReview, Integer, Hash)>

create a SelfSubjectReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:

  • (Array<(V1SelfSubjectReview, Integer, Hash)>)

    V1SelfSubjectReview data, response status code and response headers



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 43

def create_self_subject_review_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthenticationV1Api.create_self_subject_review ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AuthenticationV1Api.create_self_subject_review"
  end
  # resource path
  local_var_path = '/apis/authentication.k8s.io/v1/selfsubjectreviews'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'dryRun'] = opts[:'dry_run'] if !opts[:'dry_run'].nil?
  query_params[:'fieldManager'] = opts[:'field_manager'] if !opts[:'field_manager'].nil?
  query_params[:'fieldValidation'] = opts[:'field_validation'] if !opts[:'field_validation'].nil?
  query_params[:'pretty'] = opts[:'pretty'] if !opts[:'pretty'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'V1SelfSubjectReview'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthenticationV1Api.create_self_subject_review",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthenticationV1Api#create_self_subject_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_token_review(body, opts = {}) ⇒ V1TokenReview

create a TokenReview

Parameters:

  • body (V1TokenReview)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:



103
104
105
106
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 103

def create_token_review(body, opts = {})
  data, _status_code, _headers = create_token_review_with_http_info(body, opts)
  data
end

#create_token_review_with_http_info(body, opts = {}) ⇒ Array<(V1TokenReview, Integer, Hash)>

create a TokenReview

Parameters:

  • body (V1TokenReview)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:

  • (Array<(V1TokenReview, Integer, Hash)>)

    V1TokenReview data, response status code and response headers



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 116

def create_token_review_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthenticationV1Api.create_token_review ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AuthenticationV1Api.create_token_review"
  end
  # resource path
  local_var_path = '/apis/authentication.k8s.io/v1/tokenreviews'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'dryRun'] = opts[:'dry_run'] if !opts[:'dry_run'].nil?
  query_params[:'fieldManager'] = opts[:'field_manager'] if !opts[:'field_manager'].nil?
  query_params[:'fieldValidation'] = opts[:'field_validation'] if !opts[:'field_validation'].nil?
  query_params[:'pretty'] = opts[:'pretty'] if !opts[:'pretty'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'V1TokenReview'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthenticationV1Api.create_token_review",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthenticationV1Api#create_token_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_api_resources_authentication_v1(opts = {}) ⇒ V1APIResourceList

get available resources

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



171
172
173
174
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 171

def get_api_resources_authentication_v1(opts = {})
  data, _status_code, _headers = get_api_resources_authentication_v1_with_http_info(opts)
  data
end

#get_api_resources_authentication_v1_with_http_info(opts = {}) ⇒ Array<(V1APIResourceList, Integer, Hash)>

get available resources

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1APIResourceList, Integer, Hash)>)

    V1APIResourceList data, response status code and response headers



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/kubernetes/api/authentication_v1_api.rb', line 179

def get_api_resources_authentication_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthenticationV1Api.get_api_resources_authentication_v1 ...'
  end
  # resource path
  local_var_path = '/apis/authentication.k8s.io/v1/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'V1APIResourceList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthenticationV1Api.get_api_resources_authentication_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthenticationV1Api#get_api_resources_authentication_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end