Class: Kubernetes::AuthorizationV1Api

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/api/authorization_v1_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AuthorizationV1Api

Returns a new instance of AuthorizationV1Api.



19
20
21
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_namespaced_local_subject_access_review(namespace, body, opts = {}) ⇒ V1LocalSubjectAccessReview

create a LocalSubjectAccessReview

Parameters:

  • namespace (String)

    object name and auth scope, such as for teams and projects

  • body (V1LocalSubjectAccessReview)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If 'true', then the output is pretty printed. Defaults to 'false' unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:



31
32
33
34
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 31

def create_namespaced_local_subject_access_review(namespace, body, opts = {})
  data, _status_code, _headers = create_namespaced_local_subject_access_review_with_http_info(namespace, body, opts)
  data
end

#create_namespaced_local_subject_access_review_with_http_info(namespace, body, opts = {}) ⇒ Array<(V1LocalSubjectAccessReview, Integer, Hash)>

create a LocalSubjectAccessReview

Parameters:

  • namespace (String)

    object name and auth scope, such as for teams and projects

  • body (V1LocalSubjectAccessReview)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:

  • (Array<(V1LocalSubjectAccessReview, Integer, Hash)>)

    V1LocalSubjectAccessReview data, response status code and response headers



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 45

def create_namespaced_local_subject_access_review_with_http_info(namespace, body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthorizationV1Api.create_namespaced_local_subject_access_review ...'
  end
  # verify the required parameter 'namespace' is set
  if @api_client.config.client_side_validation && namespace.nil?
    fail ArgumentError, "Missing the required parameter 'namespace' when calling AuthorizationV1Api.create_namespaced_local_subject_access_review"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AuthorizationV1Api.create_namespaced_local_subject_access_review"
  end
  # resource path
  local_var_path = '/apis/authorization.k8s.io/v1/namespaces/{namespace}/localsubjectaccessreviews'.sub('{' + 'namespace' + '}', CGI.escape(namespace.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'dryRun'] = opts[:'dry_run'] if !opts[:'dry_run'].nil?
  query_params[:'fieldManager'] = opts[:'field_manager'] if !opts[:'field_manager'].nil?
  query_params[:'fieldValidation'] = opts[:'field_validation'] if !opts[:'field_validation'].nil?
  query_params[:'pretty'] = opts[:'pretty'] if !opts[:'pretty'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'V1LocalSubjectAccessReview'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthorizationV1Api.create_namespaced_local_subject_access_review",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthorizationV1Api#create_namespaced_local_subject_access_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_self_subject_access_review(body, opts = {}) ⇒ V1SelfSubjectAccessReview

create a SelfSubjectAccessReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:



109
110
111
112
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 109

def create_self_subject_access_review(body, opts = {})
  data, _status_code, _headers = create_self_subject_access_review_with_http_info(body, opts)
  data
end

#create_self_subject_access_review_with_http_info(body, opts = {}) ⇒ Array<(V1SelfSubjectAccessReview, Integer, Hash)>

create a SelfSubjectAccessReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:

  • (Array<(V1SelfSubjectAccessReview, Integer, Hash)>)

    V1SelfSubjectAccessReview data, response status code and response headers



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 122

def create_self_subject_access_review_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthorizationV1Api.create_self_subject_access_review ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AuthorizationV1Api.create_self_subject_access_review"
  end
  # resource path
  local_var_path = '/apis/authorization.k8s.io/v1/selfsubjectaccessreviews'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'dryRun'] = opts[:'dry_run'] if !opts[:'dry_run'].nil?
  query_params[:'fieldManager'] = opts[:'field_manager'] if !opts[:'field_manager'].nil?
  query_params[:'fieldValidation'] = opts[:'field_validation'] if !opts[:'field_validation'].nil?
  query_params[:'pretty'] = opts[:'pretty'] if !opts[:'pretty'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'V1SelfSubjectAccessReview'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthorizationV1Api.create_self_subject_access_review",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthorizationV1Api#create_self_subject_access_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_self_subject_rules_review(body, opts = {}) ⇒ V1SelfSubjectRulesReview

create a SelfSubjectRulesReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:



182
183
184
185
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 182

def create_self_subject_rules_review(body, opts = {})
  data, _status_code, _headers = create_self_subject_rules_review_with_http_info(body, opts)
  data
end

#create_self_subject_rules_review_with_http_info(body, opts = {}) ⇒ Array<(V1SelfSubjectRulesReview, Integer, Hash)>

create a SelfSubjectRulesReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:

  • (Array<(V1SelfSubjectRulesReview, Integer, Hash)>)

    V1SelfSubjectRulesReview data, response status code and response headers



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 195

def create_self_subject_rules_review_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthorizationV1Api.create_self_subject_rules_review ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AuthorizationV1Api.create_self_subject_rules_review"
  end
  # resource path
  local_var_path = '/apis/authorization.k8s.io/v1/selfsubjectrulesreviews'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'dryRun'] = opts[:'dry_run'] if !opts[:'dry_run'].nil?
  query_params[:'fieldManager'] = opts[:'field_manager'] if !opts[:'field_manager'].nil?
  query_params[:'fieldValidation'] = opts[:'field_validation'] if !opts[:'field_validation'].nil?
  query_params[:'pretty'] = opts[:'pretty'] if !opts[:'pretty'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'V1SelfSubjectRulesReview'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthorizationV1Api.create_self_subject_rules_review",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthorizationV1Api#create_self_subject_rules_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_subject_access_review(body, opts = {}) ⇒ V1SubjectAccessReview

create a SubjectAccessReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:



255
256
257
258
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 255

def create_subject_access_review(body, opts = {})
  data, _status_code, _headers = create_subject_access_review_with_http_info(body, opts)
  data
end

#create_subject_access_review_with_http_info(body, opts = {}) ⇒ Array<(V1SubjectAccessReview, Integer, Hash)>

create a SubjectAccessReview

Parameters:

Options Hash (opts):

  • :dry_run (String)

    When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed

  • :field_manager (String)

    fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by golang.org/pkg/unicode/#IsPrint.

  • :field_validation (String)

    fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered.

  • :pretty (String)

    If &#39;true&#39;, then the output is pretty printed. Defaults to &#39;false&#39; unless the user-agent indicates a browser or command-line HTTP tool (curl and wget).

Returns:

  • (Array<(V1SubjectAccessReview, Integer, Hash)>)

    V1SubjectAccessReview data, response status code and response headers



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 268

def create_subject_access_review_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthorizationV1Api.create_subject_access_review ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AuthorizationV1Api.create_subject_access_review"
  end
  # resource path
  local_var_path = '/apis/authorization.k8s.io/v1/subjectaccessreviews'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'dryRun'] = opts[:'dry_run'] if !opts[:'dry_run'].nil?
  query_params[:'fieldManager'] = opts[:'field_manager'] if !opts[:'field_manager'].nil?
  query_params[:'fieldValidation'] = opts[:'field_validation'] if !opts[:'field_validation'].nil?
  query_params[:'pretty'] = opts[:'pretty'] if !opts[:'pretty'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'V1SubjectAccessReview'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthorizationV1Api.create_subject_access_review",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthorizationV1Api#create_subject_access_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_api_resources_authorization_v1(opts = {}) ⇒ V1APIResourceList

get available resources

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



323
324
325
326
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 323

def get_api_resources_authorization_v1(opts = {})
  data, _status_code, _headers = get_api_resources_authorization_v1_with_http_info(opts)
  data
end

#get_api_resources_authorization_v1_with_http_info(opts = {}) ⇒ Array<(V1APIResourceList, Integer, Hash)>

get available resources

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(V1APIResourceList, Integer, Hash)>)

    V1APIResourceList data, response status code and response headers



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/kubernetes/api/authorization_v1_api.rb', line 331

def get_api_resources_authorization_v1_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuthorizationV1Api.get_api_resources_authorization_v1 ...'
  end
  # resource path
  local_var_path = '/apis/authorization.k8s.io/v1/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json', 'application/yaml', 'application/vnd.kubernetes.protobuf', 'application/cbor'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'V1APIResourceList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['BearerToken']

  new_options = opts.merge(
    :operation => :"AuthorizationV1Api.get_api_resources_authorization_v1",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuthorizationV1Api#get_api_resources_authorization_v1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end