Class: Kubernetes::Configuration
- Inherits:
-
Object
- Object
- Kubernetes::Configuration
- Defined in:
- lib/kubernetes/loader.rb,
lib/kubernetes/configuration.rb
Overview
Configuration is a utility class for loading kubernetes configurations
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
-
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
-
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
-
#base_path ⇒ Object
Defines url base path.
-
#cert_file ⇒ Object
TLS/SSL setting Client certificate file (for client certificate).
-
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation.
-
#debugging ⇒ true, false
Set this to enable/disable debugging.
-
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
-
#host ⇒ Object
Defines url host.
-
#inject_format ⇒ Object
Returns the value of attribute inject_format.
-
#key_file ⇒ Object
TLS/SSL setting Client private key file (for client certificate).
-
#logger ⇒ #debug
Defines the logger used for debugging.
-
#params_encoding ⇒ Object
Set this to customize parameters encoding of array parameter with multi collectionFormat.
-
#password ⇒ String
Defines the password used with HTTP basic authentication.
-
#retry_configuration ⇒ Object
Optional retry configuration for retriable HTTP responses.
-
#scheme ⇒ Object
Defines url scheme.
-
#server_index ⇒ Object
Define server configuration index.
-
#server_operation_index ⇒ Object
Define server operation configuration index.
-
#server_operation_variables ⇒ Object
Default server operation variables.
-
#server_variables ⇒ Object
Default server variables.
-
#ssl_ca_cert ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
-
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response).
-
#timeout ⇒ Object
The time limit for HTTP request in seconds.
-
#username ⇒ String
Defines the username used with HTTP basic authentication.
-
#verify_ssl ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server.
-
#verify_ssl_host ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.
Class Method Summary collapse
-
.default ⇒ Object
The default Configuration object.
-
.default_config ⇒ Object
Backward-compatible alias used by examples and older integrations.
- .load_file_config(file, result) ⇒ Object
- .load_local_config(result) ⇒ Object
- .reset_default ⇒ Object
Instance Method Summary collapse
-
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
-
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
-
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings.
-
#basic_auth_token ⇒ Object
Gets Basic Auth token string.
- #configure {|_self| ... } ⇒ Object
-
#initialize {|_self| ... } ⇒ Configuration
constructor
A new instance of Configuration.
- #operation_server_settings ⇒ Object
-
#server_settings ⇒ Object
Returns an array of Server setting.
-
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings.
Constructor Details
#initialize {|_self| ... } ⇒ Configuration
Returns a new instance of Configuration.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/kubernetes/configuration.rb', line 150 def initialize @scheme = 'http' @host = 'localhost' @base_path = '' @server_index = nil @server_operation_index = {} @server_variables = {} @server_operation_variables = {} @api_key = {} @api_key_prefix = {} @timeout = 0 @retry_configuration = nil @client_side_validation = true @verify_ssl = true @verify_ssl_host = true @params_encoding = nil @cert_file = nil @key_file = nil @debugging = false @inject_format = false @force_ending_format = false @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT) yield(self) if block_given? end |
Instance Attribute Details
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
68 69 70 |
# File 'lib/kubernetes/configuration.rb', line 68 def access_token @access_token end |
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
47 48 49 |
# File 'lib/kubernetes/configuration.rb', line 47 def api_key @api_key end |
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
55 56 57 |
# File 'lib/kubernetes/configuration.rb', line 55 def api_key_prefix @api_key_prefix end |
#base_path ⇒ Object
Defines url base path
27 28 29 |
# File 'lib/kubernetes/configuration.rb', line 27 def base_path @base_path end |
#cert_file ⇒ Object
TLS/SSL setting Client certificate file (for client certificate)
133 134 135 |
# File 'lib/kubernetes/configuration.rb', line 133 def cert_file @cert_file end |
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation. Default to true.
102 103 104 |
# File 'lib/kubernetes/configuration.rb', line 102 def client_side_validation @client_side_validation end |
#debugging ⇒ true, false
Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with ‘logger.debug` (see the `logger` attribute). Default to false.
75 76 77 |
# File 'lib/kubernetes/configuration.rb', line 75 def debugging @debugging end |
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
148 149 150 |
# File 'lib/kubernetes/configuration.rb', line 148 def force_ending_format @force_ending_format end |
#host ⇒ Object
Defines url host
24 25 26 |
# File 'lib/kubernetes/configuration.rb', line 24 def host @host end |
#inject_format ⇒ Object
Returns the value of attribute inject_format.
146 147 148 |
# File 'lib/kubernetes/configuration.rb', line 146 def inject_format @inject_format end |
#key_file ⇒ Object
TLS/SSL setting Client private key file (for client certificate)
137 138 139 |
# File 'lib/kubernetes/configuration.rb', line 137 def key_file @key_file end |
#logger ⇒ #debug
Defines the logger used for debugging. Default to ‘Rails.logger` (when in Rails) or logging to STDOUT.
81 82 83 |
# File 'lib/kubernetes/configuration.rb', line 81 def logger @logger end |
#params_encoding ⇒ Object
Set this to customize parameters encoding of array parameter with multi collectionFormat. Default to nil.
github.com/typhoeus/ethon/blob/master/lib/ethon/easy/queryable.rb#L96
144 145 146 |
# File 'lib/kubernetes/configuration.rb', line 144 def params_encoding @params_encoding end |
#password ⇒ String
Defines the password used with HTTP basic authentication.
65 66 67 |
# File 'lib/kubernetes/configuration.rb', line 65 def password @password end |
#retry_configuration ⇒ Object
Optional retry configuration for retriable HTTP responses. Example:
{ max_retries: 4, base_interval_seconds: 1.0, retry_statuses: [429, 500, 501, 502, 503] }
97 98 99 |
# File 'lib/kubernetes/configuration.rb', line 97 def retry_configuration @retry_configuration end |
#scheme ⇒ Object
Defines url scheme
21 22 23 |
# File 'lib/kubernetes/configuration.rb', line 21 def scheme @scheme end |
#server_index ⇒ Object
Define server configuration index
30 31 32 |
# File 'lib/kubernetes/configuration.rb', line 30 def server_index @server_index end |
#server_operation_index ⇒ Object
Define server operation configuration index
33 34 35 |
# File 'lib/kubernetes/configuration.rb', line 33 def server_operation_index @server_operation_index end |
#server_operation_variables ⇒ Object
Default server operation variables
39 40 41 |
# File 'lib/kubernetes/configuration.rb', line 39 def server_operation_variables @server_operation_variables end |
#server_variables ⇒ Object
Default server variables
36 37 38 |
# File 'lib/kubernetes/configuration.rb', line 36 def server_variables @server_variables end |
#ssl_ca_cert ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
github.com/typhoeus/typhoeus/blob/master/lib/typhoeus/easy_factory.rb#L145
129 130 131 |
# File 'lib/kubernetes/configuration.rb', line 129 def ssl_ca_cert @ssl_ca_cert end |
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use ‘Tempfile`.
88 89 90 |
# File 'lib/kubernetes/configuration.rb', line 88 def temp_folder_path @temp_folder_path end |
#timeout ⇒ Object
The time limit for HTTP request in seconds. Default to 0 (never times out).
92 93 94 |
# File 'lib/kubernetes/configuration.rb', line 92 def timeout @timeout end |
#username ⇒ String
Defines the username used with HTTP basic authentication.
60 61 62 |
# File 'lib/kubernetes/configuration.rb', line 60 def username @username end |
#verify_ssl ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.
111 112 113 |
# File 'lib/kubernetes/configuration.rb', line 111 def verify_ssl @verify_ssl end |
#verify_ssl_host ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.
120 121 122 |
# File 'lib/kubernetes/configuration.rb', line 120 def verify_ssl_host @verify_ssl_host end |
Class Method Details
.default ⇒ Object
The default Configuration object.
177 178 179 180 181 182 183 |
# File 'lib/kubernetes/configuration.rb', line 177 def self.default return @@default if defined?(@@default) && @@default @default_mutex.synchronize do @@default ||= Configuration.new end end |
.default_config ⇒ Object
Backward-compatible alias used by examples and older integrations.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/kubernetes/configuration.rb', line 192 def self.default_config result = Configuration.new return result if load_local_config(result) # In cluster config if InClusterConfig.in_cluster? k_config = InClusterConfig.new k_config.configure(result) return result end result.scheme = 'http' result.host = 'localhost:8080' result end |
.load_file_config(file, result) ⇒ Object
49 50 51 52 53 |
# File 'lib/kubernetes/loader.rb', line 49 def self.load_file_config(file, result) k_config = KubeConfig.new(file) k_config.configure(result) result end |
.load_local_config(result) ⇒ Object
37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/kubernetes/loader.rb', line 37 def self.load_local_config(result) # KUBECONFIG environment variable kc = (ENV['KUBECONFIG']).to_s return load_file_config(kc, result) if File.exist?(kc) # default home location kc = "#{ENV['HOME']}/.kube/config" return unless File.exist?(kc) load_file_config(kc, result) end |
.reset_default ⇒ Object
185 186 187 188 189 |
# File 'lib/kubernetes/configuration.rb', line 185 def self.reset_default @default_mutex.synchronize do @@default = nil end end |
Instance Method Details
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
226 227 228 229 230 231 232 233 234 |
# File 'lib/kubernetes/configuration.rb', line 226 def api_key_with_prefix(param_name, param_alias = nil) key = @api_key[param_name] key = @api_key.fetch(param_alias, key) unless param_alias.nil? if @api_key_prefix[param_name] "#{@api_key_prefix[param_name]} #{key}" else key end end |
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/kubernetes/configuration.rb', line 242 def auth_settings { 'BearerToken' => { type: 'api_key', in: 'header', key: 'authorization', value: api_key_with_prefix('BearerToken') }, } end |
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings
217 218 219 220 221 222 |
# File 'lib/kubernetes/configuration.rb', line 217 def base_url(operation = nil) index = server_operation_index.fetch(operation, server_index) return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if index == nil server_url(index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation]) end |
#basic_auth_token ⇒ Object
Gets Basic Auth token string
237 238 239 |
# File 'lib/kubernetes/configuration.rb', line 237 def basic_auth_token 'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n") end |
#configure {|_self| ... } ⇒ Object
196 197 198 |
# File 'lib/kubernetes/configuration.rb', line 196 def configure yield(self) if block_given? end |
#operation_server_settings ⇒ Object
264 265 266 267 |
# File 'lib/kubernetes/configuration.rb', line 264 def operation_server_settings { } end |
#server_settings ⇒ Object
Returns an array of Server setting
255 256 257 258 259 260 261 262 |
# File 'lib/kubernetes/configuration.rb', line 255 def server_settings [ { url: "", description: "No description provided", } ] end |
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/kubernetes/configuration.rb', line 273 def server_url(index, variables = {}, servers = nil) servers = server_settings if servers == nil # check array index out of bound if (index < 0 || index >= servers.size) fail ArgumentError, "Invalid index #{index} when selecting the server. Must be less than #{servers.size}" end server = servers[index] url = server[:url].dup return url unless server.key? :variables # go through variable and assign a value server[:variables].each do |name, variable| variable_key = if variables.key?(name) name elsif variables.key?(name.to_s) name.to_s elsif name.respond_to?(:to_sym) && variables.key?(name.to_sym) name.to_sym end if variable_key variable_value = variables[variable_key] if (!variable.key?(:enum_values) || variable[:enum_values].include?(variable_value)) url.gsub! "{" + name.to_s + "}", variable_value else fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variable_value}. Must be #{variable[:enum_values]}." end else # use default value url.gsub! "{" + name.to_s + "}", variable[:default_value] end end url end |