Class: Kubernetes::CoreV1Event

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/core_v1_event.rb

Overview

Event is a report of an event somewhere in the cluster. Events have a limited retention time and triggers and messages may evolve with time. Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason. Events should be treated as informative, best-effort, supplemental data.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CoreV1Event

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/kubernetes/models/core_v1_event.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::CoreV1Event` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::CoreV1Event`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'api_version')
    self.api_version = attributes[:'api_version']
  end

  if attributes.key?(:'count')
    self.count = attributes[:'count']
  end

  if attributes.key?(:'event_time')
    self.event_time = attributes[:'event_time']
  end

  if attributes.key?(:'first_timestamp')
    self.first_timestamp = attributes[:'first_timestamp']
  end

  if attributes.key?(:'involved_object')
    self.involved_object = attributes[:'involved_object']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'last_timestamp')
    self.last_timestamp = attributes[:'last_timestamp']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'related')
    self.related = attributes[:'related']
  end

  if attributes.key?(:'reporting_component')
    self.reporting_component = attributes[:'reporting_component']
  end

  if attributes.key?(:'reporting_instance')
    self.reporting_instance = attributes[:'reporting_instance']
  end

  if attributes.key?(:'series')
    self.series = attributes[:'series']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#actionObject

What action was taken/failed regarding to the Regarding object.



20
21
22
# File 'lib/kubernetes/models/core_v1_event.rb', line 20

def action
  @action
end

#api_versionObject

APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources



23
24
25
# File 'lib/kubernetes/models/core_v1_event.rb', line 23

def api_version
  @api_version
end

#countObject

The number of times this event has occurred.



26
27
28
# File 'lib/kubernetes/models/core_v1_event.rb', line 26

def count
  @count
end

#event_timeObject

Time when this Event was first observed.



29
30
31
# File 'lib/kubernetes/models/core_v1_event.rb', line 29

def event_time
  @event_time
end

#first_timestampObject

The time at which the event was first recorded. (Time of server receipt is in TypeMeta.)



32
33
34
# File 'lib/kubernetes/models/core_v1_event.rb', line 32

def first_timestamp
  @first_timestamp
end

#involved_objectObject

Returns the value of attribute involved_object.



34
35
36
# File 'lib/kubernetes/models/core_v1_event.rb', line 34

def involved_object
  @involved_object
end

#kindObject

Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds



37
38
39
# File 'lib/kubernetes/models/core_v1_event.rb', line 37

def kind
  @kind
end

#last_timestampObject

The time at which the most recent occurrence of this event was recorded.



40
41
42
# File 'lib/kubernetes/models/core_v1_event.rb', line 40

def last_timestamp
  @last_timestamp
end

#messageObject

A human-readable description of the status of this operation.



43
44
45
# File 'lib/kubernetes/models/core_v1_event.rb', line 43

def message
  @message
end

#metadataObject

Returns the value of attribute metadata.



45
46
47
# File 'lib/kubernetes/models/core_v1_event.rb', line 45

def 
  @metadata
end

#reasonObject

This should be a short, machine understandable string that gives the reason for the transition into the object’s current status.



48
49
50
# File 'lib/kubernetes/models/core_v1_event.rb', line 48

def reason
  @reason
end

Returns the value of attribute related.



50
51
52
# File 'lib/kubernetes/models/core_v1_event.rb', line 50

def related
  @related
end

#reporting_componentObject

Name of the controller that emitted this Event, e.g. ‘kubernetes.io/kubelet`.



53
54
55
# File 'lib/kubernetes/models/core_v1_event.rb', line 53

def reporting_component
  @reporting_component
end

#reporting_instanceObject

ID of the controller instance, e.g. ‘kubelet-xyzf`.



56
57
58
# File 'lib/kubernetes/models/core_v1_event.rb', line 56

def reporting_instance
  @reporting_instance
end

#seriesObject

Returns the value of attribute series.



58
59
60
# File 'lib/kubernetes/models/core_v1_event.rb', line 58

def series
  @series
end

#sourceObject

Returns the value of attribute source.



60
61
62
# File 'lib/kubernetes/models/core_v1_event.rb', line 60

def source
  @source
end

#typeObject

Type of this event (Normal, Warning), new types could be added in the future



63
64
65
# File 'lib/kubernetes/models/core_v1_event.rb', line 63

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/kubernetes/models/core_v1_event.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/kubernetes/models/core_v1_event.rb', line 66

def self.attribute_map
  {
    :'action' => :'action',
    :'api_version' => :'apiVersion',
    :'count' => :'count',
    :'event_time' => :'eventTime',
    :'first_timestamp' => :'firstTimestamp',
    :'involved_object' => :'involvedObject',
    :'kind' => :'kind',
    :'last_timestamp' => :'lastTimestamp',
    :'message' => :'message',
    :'metadata' => :'metadata',
    :'reason' => :'reason',
    :'related' => :'related',
    :'reporting_component' => :'reportingComponent',
    :'reporting_instance' => :'reportingInstance',
    :'series' => :'series',
    :'source' => :'source',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
# File 'lib/kubernetes/models/core_v1_event.rb', line 268

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
# File 'lib/kubernetes/models/core_v1_event.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/kubernetes/models/core_v1_event.rb', line 94

def self.openapi_types
  {
    :'action' => :'String',
    :'api_version' => :'String',
    :'count' => :'Integer',
    :'event_time' => :'Time',
    :'first_timestamp' => :'Time',
    :'involved_object' => :'V1ObjectReference',
    :'kind' => :'String',
    :'last_timestamp' => :'Time',
    :'message' => :'String',
    :'metadata' => :'V1ObjectMeta',
    :'reason' => :'String',
    :'related' => :'V1ObjectReference',
    :'reporting_component' => :'String',
    :'reporting_instance' => :'String',
    :'series' => :'CoreV1EventSeries',
    :'source' => :'V1EventSource',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/kubernetes/models/core_v1_event.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      api_version == o.api_version &&
      count == o.count &&
      event_time == o.event_time &&
      first_timestamp == o.first_timestamp &&
      involved_object == o.involved_object &&
      kind == o.kind &&
      last_timestamp == o.last_timestamp &&
      message == o.message &&
       == o. &&
      reason == o.reason &&
      related == o.related &&
      reporting_component == o.reporting_component &&
      reporting_instance == o.reporting_instance &&
      series == o.series &&
      source == o.source &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/kubernetes/models/core_v1_event.rb', line 298

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/kubernetes/models/core_v1_event.rb', line 369

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/kubernetes/models/core_v1_event.rb', line 275

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


255
256
257
# File 'lib/kubernetes/models/core_v1_event.rb', line 255

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



261
262
263
# File 'lib/kubernetes/models/core_v1_event.rb', line 261

def hash
  [action, api_version, count, event_time, first_timestamp, involved_object, kind, last_timestamp, message, , reason, related, reporting_component, reporting_instance, series, source, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/kubernetes/models/core_v1_event.rb', line 208

def list_invalid_properties
  invalid_properties = Array.new
  if @involved_object.nil?
    invalid_properties.push('invalid value for "involved_object", involved_object cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
# File 'lib/kubernetes/models/core_v1_event.rb', line 345

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/kubernetes/models/core_v1_event.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



339
340
341
# File 'lib/kubernetes/models/core_v1_event.rb', line 339

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



223
224
225
226
227
# File 'lib/kubernetes/models/core_v1_event.rb', line 223

def valid?
  return false if @involved_object.nil?
  return false if @metadata.nil?
  true
end