Class: Kubernetes::EventsV1Event

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/events_v1_event.rb

Overview

Event is a report of an event somewhere in the cluster. It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time. Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason. Events should be treated as informative, best-effort, supplemental data.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EventsV1Event

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/kubernetes/models/events_v1_event.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::EventsV1Event` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::EventsV1Event`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'action')
    self.action = attributes[:'action']
  end

  if attributes.key?(:'api_version')
    self.api_version = attributes[:'api_version']
  end

  if attributes.key?(:'deprecated_count')
    self.deprecated_count = attributes[:'deprecated_count']
  end

  if attributes.key?(:'deprecated_first_timestamp')
    self.deprecated_first_timestamp = attributes[:'deprecated_first_timestamp']
  end

  if attributes.key?(:'deprecated_last_timestamp')
    self.deprecated_last_timestamp = attributes[:'deprecated_last_timestamp']
  end

  if attributes.key?(:'deprecated_source')
    self.deprecated_source = attributes[:'deprecated_source']
  end

  if attributes.key?(:'event_time')
    self.event_time = attributes[:'event_time']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'regarding')
    self.regarding = attributes[:'regarding']
  end

  if attributes.key?(:'related')
    self.related = attributes[:'related']
  end

  if attributes.key?(:'reporting_controller')
    self.reporting_controller = attributes[:'reporting_controller']
  end

  if attributes.key?(:'reporting_instance')
    self.reporting_instance = attributes[:'reporting_instance']
  end

  if attributes.key?(:'series')
    self.series = attributes[:'series']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#actionObject

action is what action was taken/failed regarding to the regarding object. It is machine-readable. This field cannot be empty for new Events and it can have at most 128 characters.



20
21
22
# File 'lib/kubernetes/models/events_v1_event.rb', line 20

def action
  @action
end

#api_versionObject

APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources



23
24
25
# File 'lib/kubernetes/models/events_v1_event.rb', line 23

def api_version
  @api_version
end

#deprecated_countObject

deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type.



26
27
28
# File 'lib/kubernetes/models/events_v1_event.rb', line 26

def deprecated_count
  @deprecated_count
end

#deprecated_first_timestampObject

deprecatedFirstTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.



29
30
31
# File 'lib/kubernetes/models/events_v1_event.rb', line 29

def deprecated_first_timestamp
  @deprecated_first_timestamp
end

#deprecated_last_timestampObject

deprecatedLastTimestamp is the deprecated field assuring backward compatibility with core.v1 Event type.



32
33
34
# File 'lib/kubernetes/models/events_v1_event.rb', line 32

def deprecated_last_timestamp
  @deprecated_last_timestamp
end

#deprecated_sourceObject

Returns the value of attribute deprecated_source.



34
35
36
# File 'lib/kubernetes/models/events_v1_event.rb', line 34

def deprecated_source
  @deprecated_source
end

#event_timeObject

eventTime is the time when this Event was first observed. It is required.



37
38
39
# File 'lib/kubernetes/models/events_v1_event.rb', line 37

def event_time
  @event_time
end

#kindObject

Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds



40
41
42
# File 'lib/kubernetes/models/events_v1_event.rb', line 40

def kind
  @kind
end

#metadataObject

Returns the value of attribute metadata.



42
43
44
# File 'lib/kubernetes/models/events_v1_event.rb', line 42

def 
  @metadata
end

#noteObject

note is a human-readable description of the status of this operation. Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB.



45
46
47
# File 'lib/kubernetes/models/events_v1_event.rb', line 45

def note
  @note
end

#reasonObject

reason is why the action was taken. It is human-readable. This field cannot be empty for new Events and it can have at most 128 characters.



48
49
50
# File 'lib/kubernetes/models/events_v1_event.rb', line 48

def reason
  @reason
end

#regardingObject

Returns the value of attribute regarding.



50
51
52
# File 'lib/kubernetes/models/events_v1_event.rb', line 50

def regarding
  @regarding
end

Returns the value of attribute related.



52
53
54
# File 'lib/kubernetes/models/events_v1_event.rb', line 52

def related
  @related
end

#reporting_controllerObject

reportingController is the name of the controller that emitted this Event, e.g. ‘kubernetes.io/kubelet`. This field cannot be empty for new Events.



55
56
57
# File 'lib/kubernetes/models/events_v1_event.rb', line 55

def reporting_controller
  @reporting_controller
end

#reporting_instanceObject

reportingInstance is the ID of the controller instance, e.g. ‘kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters.



58
59
60
# File 'lib/kubernetes/models/events_v1_event.rb', line 58

def reporting_instance
  @reporting_instance
end

#seriesObject

Returns the value of attribute series.



60
61
62
# File 'lib/kubernetes/models/events_v1_event.rb', line 60

def series
  @series
end

#typeObject

type is the type of this event (Normal, Warning), new types could be added in the future. It is machine-readable. This field cannot be empty for new Events.



63
64
65
# File 'lib/kubernetes/models/events_v1_event.rb', line 63

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/kubernetes/models/events_v1_event.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/kubernetes/models/events_v1_event.rb', line 66

def self.attribute_map
  {
    :'action' => :'action',
    :'api_version' => :'apiVersion',
    :'deprecated_count' => :'deprecatedCount',
    :'deprecated_first_timestamp' => :'deprecatedFirstTimestamp',
    :'deprecated_last_timestamp' => :'deprecatedLastTimestamp',
    :'deprecated_source' => :'deprecatedSource',
    :'event_time' => :'eventTime',
    :'kind' => :'kind',
    :'metadata' => :'metadata',
    :'note' => :'note',
    :'reason' => :'reason',
    :'regarding' => :'regarding',
    :'related' => :'related',
    :'reporting_controller' => :'reportingController',
    :'reporting_instance' => :'reportingInstance',
    :'series' => :'series',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



263
264
265
# File 'lib/kubernetes/models/events_v1_event.rb', line 263

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
# File 'lib/kubernetes/models/events_v1_event.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/kubernetes/models/events_v1_event.rb', line 94

def self.openapi_types
  {
    :'action' => :'String',
    :'api_version' => :'String',
    :'deprecated_count' => :'Integer',
    :'deprecated_first_timestamp' => :'Time',
    :'deprecated_last_timestamp' => :'Time',
    :'deprecated_source' => :'V1EventSource',
    :'event_time' => :'Time',
    :'kind' => :'String',
    :'metadata' => :'V1ObjectMeta',
    :'note' => :'String',
    :'reason' => :'String',
    :'regarding' => :'V1ObjectReference',
    :'related' => :'V1ObjectReference',
    :'reporting_controller' => :'String',
    :'reporting_instance' => :'String',
    :'series' => :'EventsV1EventSeries',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/kubernetes/models/events_v1_event.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action == o.action &&
      api_version == o.api_version &&
      deprecated_count == o.deprecated_count &&
      deprecated_first_timestamp == o.deprecated_first_timestamp &&
      deprecated_last_timestamp == o.deprecated_last_timestamp &&
      deprecated_source == o.deprecated_source &&
      event_time == o.event_time &&
      kind == o.kind &&
       == o. &&
      note == o.note &&
      reason == o.reason &&
      regarding == o.regarding &&
      related == o.related &&
      reporting_controller == o.reporting_controller &&
      reporting_instance == o.reporting_instance &&
      series == o.series &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/kubernetes/models/events_v1_event.rb', line 293

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/kubernetes/models/events_v1_event.rb', line 364

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/kubernetes/models/events_v1_event.rb', line 270

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


250
251
252
# File 'lib/kubernetes/models/events_v1_event.rb', line 250

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



256
257
258
# File 'lib/kubernetes/models/events_v1_event.rb', line 256

def hash
  [action, api_version, deprecated_count, deprecated_first_timestamp, deprecated_last_timestamp, deprecated_source, event_time, kind, , note, reason, regarding, related, reporting_controller, reporting_instance, series, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



208
209
210
211
212
213
214
215
# File 'lib/kubernetes/models/events_v1_event.rb', line 208

def list_invalid_properties
  invalid_properties = Array.new
  if @event_time.nil?
    invalid_properties.push('invalid value for "event_time", event_time cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
# File 'lib/kubernetes/models/events_v1_event.rb', line 340

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/kubernetes/models/events_v1_event.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/kubernetes/models/events_v1_event.rb', line 334

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



219
220
221
222
# File 'lib/kubernetes/models/events_v1_event.rb', line 219

def valid?
  return false if @event_time.nil?
  true
end