Class: Kubernetes::V1APIGroup
- Inherits:
-
Object
- Object
- Kubernetes::V1APIGroup
- Defined in:
- lib/kubernetes/models/v1_api_group.rb
Overview
APIGroup contains the name, the supported versions, and the preferred version of a group.
Instance Attribute Summary collapse
-
#api_version ⇒ Object
APIVersion defines the versioned schema of this representation of an object.
-
#kind ⇒ Object
Kind is a string value representing the REST resource this object represents.
-
#name ⇒ Object
name is the name of the group.
-
#preferred_version ⇒ Object
Returns the value of attribute preferred_version.
-
#server_address_by_client_cidrs ⇒ Object
a map of client CIDR to server address that is serving this group.
-
#versions ⇒ Object
versions are the versions supported in this group.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1APIGroup
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1APIGroup
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1APIGroup` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1APIGroup`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'api_version') self.api_version = attributes[:'api_version'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'preferred_version') self.preferred_version = attributes[:'preferred_version'] end if attributes.key?(:'server_address_by_client_cidrs') if (value = attributes[:'server_address_by_client_cidrs']).is_a?(Array) self.server_address_by_client_cidrs = value end end if attributes.key?(:'versions') if (value = attributes[:'versions']).is_a?(Array) self.versions = value end end end |
Instance Attribute Details
#api_version ⇒ Object
APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
20 21 22 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 20 def api_version @api_version end |
#kind ⇒ Object
Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
23 24 25 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 23 def kind @kind end |
#name ⇒ Object
name is the name of the group.
26 27 28 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 26 def name @name end |
#preferred_version ⇒ Object
Returns the value of attribute preferred_version.
28 29 30 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 28 def preferred_version @preferred_version end |
#server_address_by_client_cidrs ⇒ Object
a map of client CIDR to server address that is serving this group. This is to help clients reach servers in the most network-efficient way possible. Clients can use the appropriate server address as per the CIDR that they match. In case of multiple matches, clients should use the longest matching CIDR. The server returns only those CIDRs that it thinks that the client can match. For example: the master will return an internal IP CIDR only, if the client reaches the server using an internal IP. Server looks at X-Forwarded-For header or X-Real-Ip header or request.RemoteAddr (in that order) to get the client IP.
31 32 33 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 31 def server_address_by_client_cidrs @server_address_by_client_cidrs end |
#versions ⇒ Object
versions are the versions supported in this group.
34 35 36 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 34 def versions @versions end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 49 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 37 def self.attribute_map { :'api_version' => :'apiVersion', :'kind' => :'kind', :'name' => :'name', :'preferred_version' => :'preferredVersion', :'server_address_by_client_cidrs' => :'serverAddressByClientCIDRs', :'versions' => :'versions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 166 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 54 def self.openapi_types { :'api_version' => :'String', :'kind' => :'String', :'name' => :'String', :'preferred_version' => :'V1GroupVersionForDiscovery', :'server_address_by_client_cidrs' => :'Array<V1ServerAddressByClientCIDR>', :'versions' => :'Array<V1GroupVersionForDiscovery>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && api_version == o.api_version && kind == o.kind && name == o.name && preferred_version == o.preferred_version && server_address_by_client_cidrs == o.server_address_by_client_cidrs && versions == o.versions end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 196 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 267 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 173 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
153 154 155 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 153 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 159 def hash [api_version, kind, name, preferred_version, server_address_by_client_cidrs, versions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 117 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @versions.nil? invalid_properties.push('invalid value for "versions", versions cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
243 244 245 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 243 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
237 238 239 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 237 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 |
# File 'lib/kubernetes/models/v1_api_group.rb', line 132 def valid? return false if @name.nil? return false if @versions.nil? true end |