Class: Kubernetes::V1APIResource
- Inherits:
-
Object
- Object
- Kubernetes::V1APIResource
- Defined in:
- lib/kubernetes/models/v1_api_resource.rb
Overview
APIResource specifies the name of a resource and whether it is namespaced.
Instance Attribute Summary collapse
-
#categories ⇒ Object
categories is a list of the grouped resources this resource belongs to (e.g. ‘all’).
-
#group ⇒ Object
group is the preferred group of the resource.
-
#kind ⇒ Object
kind is the kind for the resource (e.g. ‘Foo’ is the kind for a resource ‘foo’).
-
#name ⇒ Object
name is the plural name of the resource.
-
#namespaced ⇒ Object
namespaced indicates if a resource is namespaced or not.
-
#short_names ⇒ Object
shortNames is a list of suggested short names of the resource.
-
#singular_name ⇒ Object
singularName is the singular name of the resource.
-
#storage_version_hash ⇒ Object
The hash value of the storage version, the version this resource is converted to when written to the data store.
-
#verbs ⇒ Object
verbs is a list of supported kube verbs (this includes get, list, watch, create, update, patch, delete, deletecollection, and proxy).
-
#version ⇒ Object
version is the preferred version of the resource.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1APIResource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1APIResource
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1APIResource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1APIResource`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'categories') if (value = attributes[:'categories']).is_a?(Array) self.categories = value end end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'namespaced') self.namespaced = attributes[:'namespaced'] end if attributes.key?(:'short_names') if (value = attributes[:'short_names']).is_a?(Array) self.short_names = value end end if attributes.key?(:'singular_name') self.singular_name = attributes[:'singular_name'] end if attributes.key?(:'storage_version_hash') self.storage_version_hash = attributes[:'storage_version_hash'] end if attributes.key?(:'verbs') if (value = attributes[:'verbs']).is_a?(Array) self.verbs = value end end if attributes.key?(:'version') self.version = attributes[:'version'] end end |
Instance Attribute Details
#categories ⇒ Object
categories is a list of the grouped resources this resource belongs to (e.g. ‘all’)
20 21 22 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 20 def categories @categories end |
#group ⇒ Object
group is the preferred group of the resource. Empty implies the group of the containing resource list. For subresources, this may have a different value, for example: Scale".
23 24 25 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 23 def group @group end |
#kind ⇒ Object
kind is the kind for the resource (e.g. ‘Foo’ is the kind for a resource ‘foo’)
26 27 28 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 26 def kind @kind end |
#name ⇒ Object
name is the plural name of the resource.
29 30 31 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 29 def name @name end |
#namespaced ⇒ Object
namespaced indicates if a resource is namespaced or not.
32 33 34 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 32 def namespaced @namespaced end |
#short_names ⇒ Object
shortNames is a list of suggested short names of the resource.
35 36 37 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 35 def short_names @short_names end |
#singular_name ⇒ Object
singularName is the singular name of the resource. This allows clients to handle plural and singular opaquely. The singularName is more correct for reporting status on a single item and both singular and plural are allowed from the kubectl CLI interface.
38 39 40 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 38 def singular_name @singular_name end |
#storage_version_hash ⇒ Object
The hash value of the storage version, the version this resource is converted to when written to the data store. Value must be treated as opaque by clients. Only equality comparison on the value is valid. This is an alpha feature and may change or be removed in the future. The field is populated by the apiserver only if the StorageVersionHash feature gate is enabled. This field will remain optional even if it graduates.
41 42 43 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 41 def storage_version_hash @storage_version_hash end |
#verbs ⇒ Object
verbs is a list of supported kube verbs (this includes get, list, watch, create, update, patch, delete, deletecollection, and proxy)
44 45 46 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 44 def verbs @verbs end |
#version ⇒ Object
version is the preferred version of the resource. Empty implies the version of the containing resource list For subresources, this may have a different value, for example: v1 (while inside a v1beta1 version of the core resource’s group)".
47 48 49 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 47 def version @version end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 66 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 50 def self.attribute_map { :'categories' => :'categories', :'group' => :'group', :'kind' => :'kind', :'name' => :'name', :'namespaced' => :'namespaced', :'short_names' => :'shortNames', :'singular_name' => :'singularName', :'storage_version_hash' => :'storageVersionHash', :'verbs' => :'verbs', :'version' => :'version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 224 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 71 def self.openapi_types { :'categories' => :'Array<String>', :'group' => :'String', :'kind' => :'String', :'name' => :'String', :'namespaced' => :'Boolean', :'short_names' => :'Array<String>', :'singular_name' => :'String', :'storage_version_hash' => :'String', :'verbs' => :'Array<String>', :'version' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && categories == o.categories && group == o.group && kind == o.kind && name == o.name && namespaced == o.namespaced && short_names == o.short_names && singular_name == o.singular_name && storage_version_hash == o.storage_version_hash && verbs == o.verbs && version == o.version end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 254 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 325 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 231 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 217 def hash [categories, group, kind, name, namespaced, short_names, singular_name, storage_version_hash, verbs, version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 156 def list_invalid_properties invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @namespaced.nil? invalid_properties.push('invalid value for "namespaced", namespaced cannot be nil.') end if @singular_name.nil? invalid_properties.push('invalid value for "singular_name", singular_name cannot be nil.') end if @verbs.nil? invalid_properties.push('invalid value for "verbs", verbs cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
301 302 303 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 301 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 307 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
295 296 297 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 295 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
183 184 185 186 187 188 189 190 |
# File 'lib/kubernetes/models/v1_api_resource.rb', line 183 def valid? return false if @kind.nil? return false if @name.nil? return false if @namespaced.nil? return false if @singular_name.nil? return false if @verbs.nil? true end |