Class: Kubernetes::V1APIServiceSpec
- Inherits:
-
Object
- Object
- Kubernetes::V1APIServiceSpec
- Defined in:
- lib/kubernetes/models/v1_api_service_spec.rb
Overview
APIServiceSpec contains information for locating and communicating with a server. Only https is supported, though you are able to disable certificate verification.
Instance Attribute Summary collapse
-
#ca_bundle ⇒ Object
CABundle is a PEM encoded CA bundle which will be used to validate an API server’s serving certificate.
-
#group ⇒ Object
Group is the API group name this server hosts.
-
#group_priority_minimum ⇒ Object
GroupPriorityMinimum is the priority this group should have at least.
-
#insecure_skip_tls_verify ⇒ Object
InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server.
-
#service ⇒ Object
Returns the value of attribute service.
-
#version ⇒ Object
Version is the API version this server hosts.
-
#version_priority ⇒ Object
VersionPriority controls the ordering of this API version inside of its group.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1APIServiceSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1APIServiceSpec
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1APIServiceSpec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1APIServiceSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ca_bundle') self.ca_bundle = attributes[:'ca_bundle'] end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'group_priority_minimum') self.group_priority_minimum = attributes[:'group_priority_minimum'] end if attributes.key?(:'insecure_skip_tls_verify') self.insecure_skip_tls_verify = attributes[:'insecure_skip_tls_verify'] end if attributes.key?(:'service') self.service = attributes[:'service'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'version_priority') self.version_priority = attributes[:'version_priority'] end end |
Instance Attribute Details
#ca_bundle ⇒ Object
CABundle is a PEM encoded CA bundle which will be used to validate an API server’s serving certificate. If unspecified, system trust roots on the apiserver are used.
20 21 22 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 20 def ca_bundle @ca_bundle end |
#group ⇒ Object
Group is the API group name this server hosts
23 24 25 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 23 def group @group end |
#group_priority_minimum ⇒ Object
GroupPriorityMinimum is the priority this group should have at least. Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMinimum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object. (v1.bar before v1.foo) We’d recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s
26 27 28 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 26 def group_priority_minimum @group_priority_minimum end |
#insecure_skip_tls_verify ⇒ Object
InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. This is strongly discouraged. You should use the CABundle instead.
29 30 31 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 29 def insecure_skip_tls_verify @insecure_skip_tls_verify end |
#service ⇒ Object
Returns the value of attribute service.
31 32 33 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 31 def service @service end |
#version ⇒ Object
Version is the API version this server hosts. For example, "v1"
34 35 36 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 34 def version @version end |
#version_priority ⇒ Object
VersionPriority controls the ordering of this API version inside of its group. Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it’s inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10.
37 38 39 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 37 def version_priority @version_priority end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 53 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 40 def self.attribute_map { :'ca_bundle' => :'caBundle', :'group' => :'group', :'group_priority_minimum' => :'groupPriorityMinimum', :'insecure_skip_tls_verify' => :'insecureSkipTLSVerify', :'service' => :'service', :'version' => :'version', :'version_priority' => :'versionPriority' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 189 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 58 def self.openapi_types { :'ca_bundle' => :'String', :'group' => :'String', :'group_priority_minimum' => :'Integer', :'insecure_skip_tls_verify' => :'Boolean', :'service' => :'ApiregistrationV1ServiceReference', :'version' => :'String', :'version_priority' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && ca_bundle == o.ca_bundle && group == o.group && group_priority_minimum == o.group_priority_minimum && insecure_skip_tls_verify == o.insecure_skip_tls_verify && service == o.service && version == o.version && version_priority == o.version_priority end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 219 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 290 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 196 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
176 177 178 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 176 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
182 183 184 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 182 def hash [ca_bundle, group, group_priority_minimum, insecure_skip_tls_verify, service, version, version_priority].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 122 def list_invalid_properties invalid_properties = Array.new pattern = Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) if !@ca_bundle.nil? && @ca_bundle !~ pattern invalid_properties.push("invalid value for \"ca_bundle\", must conform to the pattern #{pattern}.") end if @group_priority_minimum.nil? invalid_properties.push('invalid value for "group_priority_minimum", group_priority_minimum cannot be nil.') end if @version_priority.nil? invalid_properties.push('invalid value for "version_priority", version_priority cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
266 267 268 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 266 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 260 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
142 143 144 145 146 147 |
# File 'lib/kubernetes/models/v1_api_service_spec.rb', line 142 def valid? return false if !@ca_bundle.nil? && @ca_bundle !~ Regexp.new(/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/) return false if @group_priority_minimum.nil? return false if @version_priority.nil? true end |