Class: Kubernetes::V1CELDeviceSelector
- Inherits:
-
Object
- Object
- Kubernetes::V1CELDeviceSelector
- Defined in:
- lib/kubernetes/models/v1_cel_device_selector.rb
Overview
CELDeviceSelector contains a CEL expression for selecting a device.
Instance Attribute Summary collapse
-
#expression ⇒ Object
Expression is a CEL expression which evaluates a single device.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1CELDeviceSelector
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1CELDeviceSelector
Initializes the object
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 49 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1CELDeviceSelector` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1CELDeviceSelector`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'expression') self.expression = attributes[:'expression'] end end |
Instance Attribute Details
#expression ⇒ Object
Expression is a CEL expression which evaluates a single device. It must evaluate to true when the device under consideration satisfies the desired criteria, and false when it does not. Any other result is an error and causes allocation of devices to abort. The expression’s input is an object named "device", which carries the following properties: - driver (string): the name of the driver which defines this device. - attributes (mapobject): the device’s attributes, grouped by prefix (e.g. device.attributes evaluates to an object with all of the attributes which were prefixed by "dra.example.com". - capacity (mapobject): the device’s capacities, grouped by prefix. - allowMultipleAllocations (bool): the allowMultipleAllocations property of the device (v1.34+ with the DRAConsumableCapacity feature enabled). Example: Consider a device with driver="dra.example.com", which exposes two attributes named "model" and "ext.example.com/family" and which exposes one capacity named "modules". This input to this expression would have the following fields: device.driver device.attributes.model device.attributes.family device.capacity.modules The device.driver field can be used to check for a specific driver, either as a high-level precondition (i.e. you only want to consider devices from this driver) or as part of a multi-clause expression that is meant to consider devices from different drivers. The value type of each attribute is defined by the device definition, and users who write these expressions must consult the documentation for their specific drivers. The value type of each capacity is Quantity. If an unknown prefix is used as a lookup in either device.attributes or device.capacity, an empty map will be returned. Any reference to an unknown field will cause an evaluation error and allocation to abort. A robust expression should check for the existence of attributes before referencing them. For ease of use, the cel.bind() function is enabled, and can be used to simplify expressions that access multiple attributes with the same domain. For example: cel.bind(dra, device.attributes, dra.someBool && dra.anotherBool) The length of the expression must be smaller or equal to 10 Ki. The cost of evaluating it is also limited based on the estimated number of logical steps.
20 21 22 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 20 def expression @expression end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
30 31 32 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 30 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 23 def self.attribute_map { :'expression' => :'expression' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
108 109 110 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 108 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
42 43 44 45 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 42 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
35 36 37 38 39 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 35 def self.openapi_types { :'expression' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
87 88 89 90 91 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 87 def ==(o) return true if self.equal?(o) self.class == o.class && expression == o.expression end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 138 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 209 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 115 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
95 96 97 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 95 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
101 102 103 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 101 def hash [expression].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
69 70 71 72 73 74 75 76 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 69 def list_invalid_properties invalid_properties = Array.new if @expression.nil? invalid_properties.push('invalid value for "expression", expression cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
185 186 187 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 185 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 191 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
179 180 181 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 179 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
80 81 82 83 |
# File 'lib/kubernetes/models/v1_cel_device_selector.rb', line 80 def valid? return false if @expression.nil? true end |