Class: Kubernetes::V1ContainerStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_container_status.rb

Overview

ContainerStatus contains details for the current status of this container.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1ContainerStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/kubernetes/models/v1_container_status.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ContainerStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ContainerStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allocated_resources')
    if (value = attributes[:'allocated_resources']).is_a?(Hash)
      self.allocated_resources = value
    end
  end

  if attributes.key?(:'allocated_resources_status')
    if (value = attributes[:'allocated_resources_status']).is_a?(Array)
      self.allocated_resources_status = value
    end
  end

  if attributes.key?(:'container_id')
    self.container_id = attributes[:'container_id']
  end

  if attributes.key?(:'image')
    self.image = attributes[:'image']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'last_state')
    self.last_state = attributes[:'last_state']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'ready')
    self.ready = attributes[:'ready']
  end

  if attributes.key?(:'resources')
    self.resources = attributes[:'resources']
  end

  if attributes.key?(:'restart_count')
    self.restart_count = attributes[:'restart_count']
  end

  if attributes.key?(:'started')
    self.started = attributes[:'started']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'stop_signal')
    self.stop_signal = attributes[:'stop_signal']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'volume_mounts')
    if (value = attributes[:'volume_mounts']).is_a?(Array)
      self.volume_mounts = value
    end
  end
end

Instance Attribute Details

#allocated_resourcesObject

AllocatedResources represents the compute resources allocated for this container by the node. Kubelet sets this value to Container.Resources.Requests upon successful pod admission and after successfully admitting desired pod resize.



20
21
22
# File 'lib/kubernetes/models/v1_container_status.rb', line 20

def allocated_resources
  @allocated_resources
end

#allocated_resources_statusObject

AllocatedResourcesStatus represents the status of various resources allocated for this Pod.



23
24
25
# File 'lib/kubernetes/models/v1_container_status.rb', line 23

def allocated_resources_status
  @allocated_resources_status
end

#container_idObject

ContainerID is the ID of the container in the format ‘<type>://<container_id>’. Where type is a container runtime identifier, returned from Version call of CRI API (for example "containerd").



26
27
28
# File 'lib/kubernetes/models/v1_container_status.rb', line 26

def container_id
  @container_id
end

#imageObject

Image is the name of container image that the container is running. The container image may not match the image used in the PodSpec, as it may have been resolved by the runtime. More info: kubernetes.io/docs/concepts/containers/images.



29
30
31
# File 'lib/kubernetes/models/v1_container_status.rb', line 29

def image
  @image
end

#image_idObject

ImageID is the image ID of the container’s image. The image ID may not match the image ID of the image used in the PodSpec, as it may have been resolved by the runtime.



32
33
34
# File 'lib/kubernetes/models/v1_container_status.rb', line 32

def image_id
  @image_id
end

#last_stateObject

Returns the value of attribute last_state.



34
35
36
# File 'lib/kubernetes/models/v1_container_status.rb', line 34

def last_state
  @last_state
end

#nameObject

Name is a DNS_LABEL representing the unique name of the container. Each container in a pod must have a unique name across all container types. Cannot be updated.



37
38
39
# File 'lib/kubernetes/models/v1_container_status.rb', line 37

def name
  @name
end

#readyObject

Ready specifies whether the container is currently passing its readiness check. The value will change as readiness probes keep executing. If no readiness probes are specified, this field defaults to true once the container is fully started (see Started field). The value is typically used to determine whether a container is ready to accept traffic.



40
41
42
# File 'lib/kubernetes/models/v1_container_status.rb', line 40

def ready
  @ready
end

#resourcesObject

Returns the value of attribute resources.



42
43
44
# File 'lib/kubernetes/models/v1_container_status.rb', line 42

def resources
  @resources
end

#restart_countObject

RestartCount holds the number of times the container has been restarted. Kubelet makes an effort to always increment the value, but there are cases when the state may be lost due to node restarts and then the value may be reset to 0. The value is never negative.



45
46
47
# File 'lib/kubernetes/models/v1_container_status.rb', line 45

def restart_count
  @restart_count
end

#startedObject

Started indicates whether the container has finished its postStart lifecycle hook and passed its startup probe. Initialized as false, becomes true after startupProbe is considered successful. Resets to false when the container is restarted, or if kubelet loses state temporarily. In both cases, startup probes will run again. Is always true when no startupProbe is defined and container is running and has passed the postStart lifecycle hook. The null value must be treated the same as false.



48
49
50
# File 'lib/kubernetes/models/v1_container_status.rb', line 48

def started
  @started
end

#stateObject

Returns the value of attribute state.



50
51
52
# File 'lib/kubernetes/models/v1_container_status.rb', line 50

def state
  @state
end

#stop_signalObject

StopSignal reports the effective stop signal for this container



53
54
55
# File 'lib/kubernetes/models/v1_container_status.rb', line 53

def stop_signal
  @stop_signal
end

#userObject

Returns the value of attribute user.



55
56
57
# File 'lib/kubernetes/models/v1_container_status.rb', line 55

def user
  @user
end

#volume_mountsObject

Status of volume mounts.



58
59
60
# File 'lib/kubernetes/models/v1_container_status.rb', line 58

def volume_mounts
  @volume_mounts
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/kubernetes/models/v1_container_status.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/kubernetes/models/v1_container_status.rb', line 61

def self.attribute_map
  {
    :'allocated_resources' => :'allocatedResources',
    :'allocated_resources_status' => :'allocatedResourcesStatus',
    :'container_id' => :'containerID',
    :'image' => :'image',
    :'image_id' => :'imageID',
    :'last_state' => :'lastState',
    :'name' => :'name',
    :'ready' => :'ready',
    :'resources' => :'resources',
    :'restart_count' => :'restartCount',
    :'started' => :'started',
    :'state' => :'state',
    :'stop_signal' => :'stopSignal',
    :'user' => :'user',
    :'volume_mounts' => :'volumeMounts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
# File 'lib/kubernetes/models/v1_container_status.rb', line 270

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/kubernetes/models/v1_container_status.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/kubernetes/models/v1_container_status.rb', line 87

def self.openapi_types
  {
    :'allocated_resources' => :'Hash<String, String>',
    :'allocated_resources_status' => :'Array<V1ResourceStatus>',
    :'container_id' => :'String',
    :'image' => :'String',
    :'image_id' => :'String',
    :'last_state' => :'V1ContainerState',
    :'name' => :'String',
    :'ready' => :'Boolean',
    :'resources' => :'V1ResourceRequirements',
    :'restart_count' => :'Integer',
    :'started' => :'Boolean',
    :'state' => :'V1ContainerState',
    :'stop_signal' => :'String',
    :'user' => :'V1ContainerUser',
    :'volume_mounts' => :'Array<V1VolumeMountStatus>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/kubernetes/models/v1_container_status.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allocated_resources == o.allocated_resources &&
      allocated_resources_status == o.allocated_resources_status &&
      container_id == o.container_id &&
      image == o.image &&
      image_id == o.image_id &&
      last_state == o.last_state &&
      name == o.name &&
      ready == o.ready &&
      resources == o.resources &&
      restart_count == o.restart_count &&
      started == o.started &&
      state == o.state &&
      stop_signal == o.stop_signal &&
      user == o.user &&
      volume_mounts == o.volume_mounts
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/kubernetes/models/v1_container_status.rb', line 300

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/kubernetes/models/v1_container_status.rb', line 371

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/kubernetes/models/v1_container_status.rb', line 277

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/kubernetes/models/v1_container_status.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/kubernetes/models/v1_container_status.rb', line 263

def hash
  [allocated_resources, allocated_resources_status, container_id, image, image_id, last_state, name, ready, resources, restart_count, started, state, stop_signal, user, volume_mounts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/kubernetes/models/v1_container_status.rb', line 197

def list_invalid_properties
  invalid_properties = Array.new
  if @image.nil?
    invalid_properties.push('invalid value for "image", image cannot be nil.')
  end

  if @image_id.nil?
    invalid_properties.push('invalid value for "image_id", image_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @ready.nil?
    invalid_properties.push('invalid value for "ready", ready cannot be nil.')
  end

  if @restart_count.nil?
    invalid_properties.push('invalid value for "restart_count", restart_count cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
# File 'lib/kubernetes/models/v1_container_status.rb', line 347

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/kubernetes/models/v1_container_status.rb', line 353

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



341
342
343
# File 'lib/kubernetes/models/v1_container_status.rb', line 341

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
231
# File 'lib/kubernetes/models/v1_container_status.rb', line 224

def valid?
  return false if @image.nil?
  return false if @image_id.nil?
  return false if @name.nil?
  return false if @ready.nil?
  return false if @restart_count.nil?
  true
end