Class: Kubernetes::V1CronJobSpec
- Inherits:
-
Object
- Object
- Kubernetes::V1CronJobSpec
- Defined in:
- lib/kubernetes/models/v1_cron_job_spec.rb
Overview
CronJobSpec describes how the job execution will look like and when it will actually run.
Instance Attribute Summary collapse
-
#concurrency_policy ⇒ Object
Specifies how to treat concurrent executions of a Job.
-
#failed_jobs_history_limit ⇒ Object
The number of failed finished jobs to retain.
-
#job_template ⇒ Object
Returns the value of attribute job_template.
-
#schedule ⇒ Object
The schedule in Cron format, see en.wikipedia.org/wiki/Cron.
-
#starting_deadline_seconds ⇒ Object
Optional deadline in seconds for starting the job if it misses scheduled time for any reason.
-
#successful_jobs_history_limit ⇒ Object
The number of successful finished jobs to retain.
-
#suspend ⇒ Object
This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.
-
#time_zone ⇒ Object
The time zone name for the given schedule, see en.wikipedia.org/wiki/List_of_tz_database_time_zones.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1CronJobSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1CronJobSpec
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1CronJobSpec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1CronJobSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'concurrency_policy') self.concurrency_policy = attributes[:'concurrency_policy'] end if attributes.key?(:'failed_jobs_history_limit') self.failed_jobs_history_limit = attributes[:'failed_jobs_history_limit'] end if attributes.key?(:'job_template') self.job_template = attributes[:'job_template'] end if attributes.key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.key?(:'starting_deadline_seconds') self.starting_deadline_seconds = attributes[:'starting_deadline_seconds'] end if attributes.key?(:'successful_jobs_history_limit') self.successful_jobs_history_limit = attributes[:'successful_jobs_history_limit'] end if attributes.key?(:'suspend') self.suspend = attributes[:'suspend'] end if attributes.key?(:'time_zone') self.time_zone = attributes[:'time_zone'] end end |
Instance Attribute Details
#concurrency_policy ⇒ Object
Specifies how to treat concurrent executions of a Job. Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn’t finished yet; - "Replace": cancels currently running job and replaces it with a new one
20 21 22 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 20 def concurrency_policy @concurrency_policy end |
#failed_jobs_history_limit ⇒ Object
The number of failed finished jobs to retain. Value must be non-negative integer. Defaults to 1.
23 24 25 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 23 def failed_jobs_history_limit @failed_jobs_history_limit end |
#job_template ⇒ Object
Returns the value of attribute job_template.
25 26 27 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 25 def job_template @job_template end |
#schedule ⇒ Object
The schedule in Cron format, see en.wikipedia.org/wiki/Cron.
28 29 30 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 28 def schedule @schedule end |
#starting_deadline_seconds ⇒ Object
Optional deadline in seconds for starting the job if it misses scheduled time for any reason. Missed jobs executions will be counted as failed ones.
31 32 33 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 31 def starting_deadline_seconds @starting_deadline_seconds end |
#successful_jobs_history_limit ⇒ Object
The number of successful finished jobs to retain. Value must be non-negative integer. Defaults to 3.
34 35 36 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 34 def successful_jobs_history_limit @successful_jobs_history_limit end |
#suspend ⇒ Object
This flag tells the controller to suspend subsequent executions, it does not apply to already started executions. Defaults to false.
37 38 39 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 37 def suspend @suspend end |
#time_zone ⇒ Object
The time zone name for the given schedule, see en.wikipedia.org/wiki/List_of_tz_database_time_zones. If not specified, this will default to the time zone of the kube-controller-manager process. The set of valid time zone names and the time zone offset is loaded from the system-wide time zone database by the API server during CronJob validation and the controller manager during execution. If no system-wide time zone database can be found a bundled version of the database is used instead. If the time zone name becomes invalid during the lifetime of a CronJob or due to a change in host configuration, the controller will stop creating new new Jobs and will create a system event with the reason UnknownTimeZone. More information can be found in kubernetes.io/docs/concepts/workloads/controllers/cron-jobs/#time-zones
40 41 42 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 40 def time_zone @time_zone end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 57 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 43 def self.attribute_map { :'concurrency_policy' => :'concurrencyPolicy', :'failed_jobs_history_limit' => :'failedJobsHistoryLimit', :'job_template' => :'jobTemplate', :'schedule' => :'schedule', :'starting_deadline_seconds' => :'startingDeadlineSeconds', :'successful_jobs_history_limit' => :'successfulJobsHistoryLimit', :'suspend' => :'suspend', :'time_zone' => :'timeZone' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 182 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 62 def self.openapi_types { :'concurrency_policy' => :'String', :'failed_jobs_history_limit' => :'Integer', :'job_template' => :'V1JobTemplateSpec', :'schedule' => :'String', :'starting_deadline_seconds' => :'Integer', :'successful_jobs_history_limit' => :'Integer', :'suspend' => :'Boolean', :'time_zone' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 154 def ==(o) return true if self.equal?(o) self.class == o.class && concurrency_policy == o.concurrency_policy && failed_jobs_history_limit == o.failed_jobs_history_limit && job_template == o.job_template && schedule == o.schedule && starting_deadline_seconds == o.starting_deadline_seconds && successful_jobs_history_limit == o.successful_jobs_history_limit && suspend == o.suspend && time_zone == o.time_zone end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 212 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 283 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 189 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 175 def hash [concurrency_policy, failed_jobs_history_limit, job_template, schedule, starting_deadline_seconds, successful_jobs_history_limit, suspend, time_zone].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 131 def list_invalid_properties invalid_properties = Array.new if @job_template.nil? invalid_properties.push('invalid value for "job_template", job_template cannot be nil.') end if @schedule.nil? invalid_properties.push('invalid value for "schedule", schedule cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
259 260 261 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 259 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 253 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 |
# File 'lib/kubernetes/models/v1_cron_job_spec.rb', line 146 def valid? return false if @job_template.nil? return false if @schedule.nil? true end |