Class: Kubernetes::V1CustomResourceDefinitionVersion
- Inherits:
-
Object
- Object
- Kubernetes::V1CustomResourceDefinitionVersion
- Defined in:
- lib/kubernetes/models/v1_custom_resource_definition_version.rb
Overview
CustomResourceDefinitionVersion describes a version for CRD.
Instance Attribute Summary collapse
-
#additional_printer_columns ⇒ Object
additionalPrinterColumns specifies additional columns returned in Table output.
-
#deprecated ⇒ Object
deprecated indicates this version of the custom resource API is deprecated.
-
#deprecation_warning ⇒ Object
deprecationWarning overrides the default warning returned to API clients.
-
#name ⇒ Object
name is the version name, e.g.
-
#schema ⇒ Object
Returns the value of attribute schema.
-
#selectable_fields ⇒ Object
selectableFields specifies paths to fields that may be used as field selectors.
-
#served ⇒ Object
served is a flag enabling/disabling this version from being served via REST APIs.
-
#storage ⇒ Object
storage indicates this version should be used when persisting custom resources to storage.
-
#subresources ⇒ Object
Returns the value of attribute subresources.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1CustomResourceDefinitionVersion
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1CustomResourceDefinitionVersion
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1CustomResourceDefinitionVersion` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1CustomResourceDefinitionVersion`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'additional_printer_columns') if (value = attributes[:'additional_printer_columns']).is_a?(Array) self.additional_printer_columns = value end end if attributes.key?(:'deprecated') self.deprecated = attributes[:'deprecated'] end if attributes.key?(:'deprecation_warning') self.deprecation_warning = attributes[:'deprecation_warning'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'schema') self.schema = attributes[:'schema'] end if attributes.key?(:'selectable_fields') if (value = attributes[:'selectable_fields']).is_a?(Array) self.selectable_fields = value end end if attributes.key?(:'served') self.served = attributes[:'served'] end if attributes.key?(:'storage') self.storage = attributes[:'storage'] end if attributes.key?(:'subresources') self.subresources = attributes[:'subresources'] end end |
Instance Attribute Details
#additional_printer_columns ⇒ Object
additionalPrinterColumns specifies additional columns returned in Table output. See kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If no columns are specified, a single column displaying the age of the custom resource is used.
20 21 22 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 20 def additional_printer_columns @additional_printer_columns end |
#deprecated ⇒ Object
deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false.
23 24 25 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 23 def deprecated @deprecated end |
#deprecation_warning ⇒ Object
deprecationWarning overrides the default warning returned to API clients. May only be set when ‘deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists.
26 27 28 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 26 def deprecation_warning @deprecation_warning end |
#name ⇒ Object
name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at ‘/apis/<group>/<version>/…` if `served` is true.
29 30 31 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 29 def name @name end |
#schema ⇒ Object
Returns the value of attribute schema.
31 32 33 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 31 def schema @schema end |
#selectable_fields ⇒ Object
selectableFields specifies paths to fields that may be used as field selectors. A maximum of 8 selectable fields are allowed. See kubernetes.io/docs/concepts/overview/working-with-objects/field-selectors
34 35 36 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 34 def selectable_fields @selectable_fields end |
#served ⇒ Object
served is a flag enabling/disabling this version from being served via REST APIs
37 38 39 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 37 def served @served end |
#storage ⇒ Object
storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true.
40 41 42 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 40 def storage @storage end |
#subresources ⇒ Object
Returns the value of attribute subresources.
42 43 44 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 42 def subresources @subresources end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 60 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 45 def self.attribute_map { :'additional_printer_columns' => :'additionalPrinterColumns', :'deprecated' => :'deprecated', :'deprecation_warning' => :'deprecationWarning', :'name' => :'name', :'schema' => :'schema', :'selectable_fields' => :'selectableFields', :'served' => :'served', :'storage' => :'storage', :'subresources' => :'subresources' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 200 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 65 def self.openapi_types { :'additional_printer_columns' => :'Array<V1CustomResourceColumnDefinition>', :'deprecated' => :'Boolean', :'deprecation_warning' => :'String', :'name' => :'String', :'schema' => :'V1CustomResourceValidation', :'selectable_fields' => :'Array<V1SelectableField>', :'served' => :'Boolean', :'storage' => :'Boolean', :'subresources' => :'V1CustomResourceSubresources' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && additional_printer_columns == o.additional_printer_columns && deprecated == o.deprecated && deprecation_warning == o.deprecation_warning && name == o.name && schema == o.schema && selectable_fields == o.selectable_fields && served == o.served && storage == o.storage && subresources == o.subresources end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 230 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 301 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 207 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 193 def hash [additional_printer_columns, deprecated, deprecation_warning, name, schema, selectable_fields, served, storage, subresources].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 143 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @served.nil? invalid_properties.push('invalid value for "served", served cannot be nil.') end if @storage.nil? invalid_properties.push('invalid value for "storage", storage cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
277 278 279 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 277 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
271 272 273 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 271 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 |
# File 'lib/kubernetes/models/v1_custom_resource_definition_version.rb', line 162 def valid? return false if @name.nil? return false if @served.nil? return false if @storage.nil? true end |