Class: Kubernetes::V1DaemonSetSpec
- Inherits:
-
Object
- Object
- Kubernetes::V1DaemonSetSpec
- Defined in:
- lib/kubernetes/models/v1_daemon_set_spec.rb
Overview
DaemonSetSpec is the specification of a daemon set.
Instance Attribute Summary collapse
-
#min_ready_seconds ⇒ Object
The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available.
-
#revision_history_limit ⇒ Object
The number of old history to retain to allow rollback.
-
#selector ⇒ Object
Returns the value of attribute selector.
-
#template ⇒ Object
Returns the value of attribute template.
-
#update_strategy ⇒ Object
Returns the value of attribute update_strategy.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1DaemonSetSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1DaemonSetSpec
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1DaemonSetSpec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1DaemonSetSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'min_ready_seconds') self.min_ready_seconds = attributes[:'min_ready_seconds'] end if attributes.key?(:'revision_history_limit') self.revision_history_limit = attributes[:'revision_history_limit'] end if attributes.key?(:'selector') self.selector = attributes[:'selector'] end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'update_strategy') self.update_strategy = attributes[:'update_strategy'] end end |
Instance Attribute Details
#min_ready_seconds ⇒ Object
The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready).
20 21 22 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 20 def min_ready_seconds @min_ready_seconds end |
#revision_history_limit ⇒ Object
The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.
23 24 25 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 23 def revision_history_limit @revision_history_limit end |
#selector ⇒ Object
Returns the value of attribute selector.
25 26 27 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 25 def selector @selector end |
#template ⇒ Object
Returns the value of attribute template.
27 28 29 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 27 def template @template end |
#update_strategy ⇒ Object
Returns the value of attribute update_strategy.
29 30 31 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 29 def update_strategy @update_strategy end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 43 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 32 def self.attribute_map { :'min_ready_seconds' => :'minReadySeconds', :'revision_history_limit' => :'revisionHistoryLimit', :'selector' => :'selector', :'template' => :'template', :'update_strategy' => :'updateStrategy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 150 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 59 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 56 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 48 def self.openapi_types { :'min_ready_seconds' => :'Integer', :'revision_history_limit' => :'Integer', :'selector' => :'V1LabelSelector', :'template' => :'V1PodTemplateSpec', :'update_strategy' => :'V1DaemonSetUpdateStrategy' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && min_ready_seconds == o.min_ready_seconds && revision_history_limit == o.revision_history_limit && selector == o.selector && template == o.template && update_strategy == o.update_strategy end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 180 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 251 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 157 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
137 138 139 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 137 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 143 def hash [min_ready_seconds, revision_history_limit, selector, template, update_strategy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 102 def list_invalid_properties invalid_properties = Array.new if @selector.nil? invalid_properties.push('invalid value for "selector", selector cannot be nil.') end if @template.nil? invalid_properties.push('invalid value for "template", template cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
227 228 229 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 227 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
221 222 223 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 221 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 |
# File 'lib/kubernetes/models/v1_daemon_set_spec.rb', line 117 def valid? return false if @selector.nil? return false if @template.nil? true end |