Class: Kubernetes::V1DeleteOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_delete_options.rb

Overview

DeleteOptions may be provided when deleting an API object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1DeleteOptions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/kubernetes/models/v1_delete_options.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1DeleteOptions` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1DeleteOptions`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'api_version')
    self.api_version = attributes[:'api_version']
  end

  if attributes.key?(:'dry_run')
    if (value = attributes[:'dry_run']).is_a?(Array)
      self.dry_run = value
    end
  end

  if attributes.key?(:'grace_period_seconds')
    self.grace_period_seconds = attributes[:'grace_period_seconds']
  end

  if attributes.key?(:'ignore_store_read_error_with_cluster_breaking_potential')
    self.ignore_store_read_error_with_cluster_breaking_potential = attributes[:'ignore_store_read_error_with_cluster_breaking_potential']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'orphan_dependents')
    self.orphan_dependents = attributes[:'orphan_dependents']
  end

  if attributes.key?(:'preconditions')
    self.preconditions = attributes[:'preconditions']
  end

  if attributes.key?(:'propagation_policy')
    self.propagation_policy = attributes[:'propagation_policy']
  end
end

Instance Attribute Details

#api_versionObject

APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources



20
21
22
# File 'lib/kubernetes/models/v1_delete_options.rb', line 20

def api_version
  @api_version
end

#dry_runObject

When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed



23
24
25
# File 'lib/kubernetes/models/v1_delete_options.rb', line 23

def dry_run
  @dry_run
end

#grace_period_secondsObject

The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately.



26
27
28
# File 'lib/kubernetes/models/v1_delete_options.rb', line 26

def grace_period_seconds
  @grace_period_seconds
end

#ignore_store_read_error_with_cluster_breaking_potentialObject

if set to true, it will trigger an unsafe deletion of the resource in case the normal deletion flow fails with a corrupt object error. A resource is considered corrupt if it can not be retrieved from the underlying storage successfully because of a) its data can not be transformed e.g. decryption failure, or b) it fails to decode into an object. NOTE: unsafe deletion ignores finalizer constraints, skips precondition checks, and removes the object from the storage. WARNING: This may potentially break the cluster if the workload associated with the resource being unsafe-deleted relies on normal deletion flow. Use only if you REALLY know what you are doing. The default value is false, and the user must opt in to enable it



29
30
31
# File 'lib/kubernetes/models/v1_delete_options.rb', line 29

def ignore_store_read_error_with_cluster_breaking_potential
  @ignore_store_read_error_with_cluster_breaking_potential
end

#kindObject

Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds



32
33
34
# File 'lib/kubernetes/models/v1_delete_options.rb', line 32

def kind
  @kind
end

#orphan_dependentsObject

Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object’s finalizers list. Either this field or PropagationPolicy may be set, but not both.



35
36
37
# File 'lib/kubernetes/models/v1_delete_options.rb', line 35

def orphan_dependents
  @orphan_dependents
end

#preconditionsObject

Returns the value of attribute preconditions.



37
38
39
# File 'lib/kubernetes/models/v1_delete_options.rb', line 37

def preconditions
  @preconditions
end

#propagation_policyObject

Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: ‘Orphan’ - orphan the dependents; ‘Background’ - allow the garbage collector to delete the dependents in the background; ‘Foreground’ - a cascading policy that deletes all dependents in the foreground.



40
41
42
# File 'lib/kubernetes/models/v1_delete_options.rb', line 40

def propagation_policy
  @propagation_policy
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/kubernetes/models/v1_delete_options.rb', line 57

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/kubernetes/models/v1_delete_options.rb', line 43

def self.attribute_map
  {
    :'api_version' => :'apiVersion',
    :'dry_run' => :'dryRun',
    :'grace_period_seconds' => :'gracePeriodSeconds',
    :'ignore_store_read_error_with_cluster_breaking_potential' => :'ignoreStoreReadErrorWithClusterBreakingPotential',
    :'kind' => :'kind',
    :'orphan_dependents' => :'orphanDependents',
    :'preconditions' => :'preconditions',
    :'propagation_policy' => :'propagationPolicy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
# File 'lib/kubernetes/models/v1_delete_options.rb', line 174

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/kubernetes/models/v1_delete_options.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/kubernetes/models/v1_delete_options.rb', line 62

def self.openapi_types
  {
    :'api_version' => :'String',
    :'dry_run' => :'Array<String>',
    :'grace_period_seconds' => :'Integer',
    :'ignore_store_read_error_with_cluster_breaking_potential' => :'Boolean',
    :'kind' => :'String',
    :'orphan_dependents' => :'Boolean',
    :'preconditions' => :'V1Preconditions',
    :'propagation_policy' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/kubernetes/models/v1_delete_options.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      api_version == o.api_version &&
      dry_run == o.dry_run &&
      grace_period_seconds == o.grace_period_seconds &&
      ignore_store_read_error_with_cluster_breaking_potential == o.ignore_store_read_error_with_cluster_breaking_potential &&
      kind == o.kind &&
      orphan_dependents == o.orphan_dependents &&
      preconditions == o.preconditions &&
      propagation_policy == o.propagation_policy
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/kubernetes/models/v1_delete_options.rb', line 204

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/kubernetes/models/v1_delete_options.rb', line 275

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/kubernetes/models/v1_delete_options.rb', line 181

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/kubernetes/models/v1_delete_options.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/kubernetes/models/v1_delete_options.rb', line 167

def hash
  [api_version, dry_run, grace_period_seconds, ignore_store_read_error_with_cluster_breaking_potential, kind, orphan_dependents, preconditions, propagation_policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
# File 'lib/kubernetes/models/v1_delete_options.rb', line 133

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
# File 'lib/kubernetes/models/v1_delete_options.rb', line 251

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/kubernetes/models/v1_delete_options.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



245
246
247
# File 'lib/kubernetes/models/v1_delete_options.rb', line 245

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
# File 'lib/kubernetes/models/v1_delete_options.rb', line 140

def valid?
  true
end