Class: Kubernetes::V1DeploymentSpec

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_deployment_spec.rb

Overview

DeploymentSpec is the specification of the desired behavior of the Deployment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1DeploymentSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1DeploymentSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1DeploymentSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'min_ready_seconds')
    self.min_ready_seconds = attributes[:'min_ready_seconds']
  end

  if attributes.key?(:'paused')
    self.paused = attributes[:'paused']
  end

  if attributes.key?(:'progress_deadline_seconds')
    self.progress_deadline_seconds = attributes[:'progress_deadline_seconds']
  end

  if attributes.key?(:'replicas')
    self.replicas = attributes[:'replicas']
  end

  if attributes.key?(:'revision_history_limit')
    self.revision_history_limit = attributes[:'revision_history_limit']
  end

  if attributes.key?(:'selector')
    self.selector = attributes[:'selector']
  end

  if attributes.key?(:'strategy')
    self.strategy = attributes[:'strategy']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end
end

Instance Attribute Details

#min_ready_secondsObject

Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)



20
21
22
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 20

def min_ready_seconds
  @min_ready_seconds
end

#pausedObject

Indicates that the deployment is paused.



23
24
25
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 23

def paused
  @paused
end

#progress_deadline_secondsObject

The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s.



26
27
28
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 26

def progress_deadline_seconds
  @progress_deadline_seconds
end

#replicasObject

Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1.



29
30
31
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 29

def replicas
  @replicas
end

#revision_history_limitObject

The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10.



32
33
34
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 32

def revision_history_limit
  @revision_history_limit
end

#selectorObject

Returns the value of attribute selector.



34
35
36
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 34

def selector
  @selector
end

#strategyObject

Returns the value of attribute strategy.



36
37
38
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 36

def strategy
  @strategy
end

#templateObject

Returns the value of attribute template.



38
39
40
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 38

def template
  @template
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 55

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 41

def self.attribute_map
  {
    :'min_ready_seconds' => :'minReadySeconds',
    :'paused' => :'paused',
    :'progress_deadline_seconds' => :'progressDeadlineSeconds',
    :'replicas' => :'replicas',
    :'revision_history_limit' => :'revisionHistoryLimit',
    :'selector' => :'selector',
    :'strategy' => :'strategy',
    :'template' => :'template'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 180

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 60

def self.openapi_types
  {
    :'min_ready_seconds' => :'Integer',
    :'paused' => :'Boolean',
    :'progress_deadline_seconds' => :'Integer',
    :'replicas' => :'Integer',
    :'revision_history_limit' => :'Integer',
    :'selector' => :'V1LabelSelector',
    :'strategy' => :'V1DeploymentStrategy',
    :'template' => :'V1PodTemplateSpec'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      min_ready_seconds == o.min_ready_seconds &&
      paused == o.paused &&
      progress_deadline_seconds == o.progress_deadline_seconds &&
      replicas == o.replicas &&
      revision_history_limit == o.revision_history_limit &&
      selector == o.selector &&
      strategy == o.strategy &&
      template == o.template
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 210

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 281

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 187

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


167
168
169
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 167

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



173
174
175
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 173

def hash
  [min_ready_seconds, paused, progress_deadline_seconds, replicas, revision_history_limit, selector, strategy, template].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 129

def list_invalid_properties
  invalid_properties = Array.new
  if @selector.nil?
    invalid_properties.push('invalid value for "selector", selector cannot be nil.')
  end

  if @template.nil?
    invalid_properties.push('invalid value for "template", template cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 257

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



251
252
253
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 251

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
# File 'lib/kubernetes/models/v1_deployment_spec.rb', line 144

def valid?
  return false if @selector.nil?
  return false if @template.nil?
  true
end