Class: Kubernetes::V1DeviceConstraint

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_device_constraint.rb

Overview

DeviceConstraint must have exactly one field set besides Requests.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1DeviceConstraint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1DeviceConstraint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1DeviceConstraint`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'distinct_attribute')
    self.distinct_attribute = attributes[:'distinct_attribute']
  end

  if attributes.key?(:'match_attribute')
    self.match_attribute = attributes[:'match_attribute']
  end

  if attributes.key?(:'requests')
    if (value = attributes[:'requests']).is_a?(Array)
      self.requests = value
    end
  end
end

Instance Attribute Details

#distinct_attributeObject

DistinctAttribute requires that all devices in question have this attribute and that its type and value are unique across those devices. This acts as the inverse of MatchAttribute. This constraint is used to avoid allocating multiple requests to the same device by ensuring attribute-level differentiation. This is useful for scenarios where resource requests must be fulfilled by separate physical devices. For example, a container requests two network interfaces that must be allocated from two different physical NICs.



20
21
22
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 20

def distinct_attribute
  @distinct_attribute
end

#match_attributeObject

MatchAttribute requires that all devices in question have this attribute and that its type and value are the same across those devices. For example, if you specified "dra.example.com/numa" (a hypothetical example!), then only devices in the same NUMA node will be chosen. A device which does not have that attribute will not be chosen. All devices should use a value of the same type for this attribute because that is part of its specification, but if one device doesn’t, then it also will not be chosen. Must include the domain qualifier.



23
24
25
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 23

def match_attribute
  @match_attribute
end

#requestsObject

Requests is a list of the one or more requests in this claim which must co-satisfy this constraint. If a request is fulfilled by multiple devices, then all of the devices must satisfy the constraint. If this is not specified, this constraint applies to all requests in this claim. References to subrequests must include the name of the main request and may include the subrequest using the format <main request>. If just the main request is given, the constraint applies to all subrequests.



26
27
28
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 26

def requests
  @requests
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 38

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 29

def self.attribute_map
  {
    :'distinct_attribute' => :'distinctAttribute',
    :'match_attribute' => :'matchAttribute',
    :'requests' => :'requests'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



125
126
127
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 125

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 52

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 43

def self.openapi_types
  {
    :'distinct_attribute' => :'String',
    :'match_attribute' => :'String',
    :'requests' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



102
103
104
105
106
107
108
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 102

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      distinct_attribute == o.distinct_attribute &&
      match_attribute == o.match_attribute &&
      requests == o.requests
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 155

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 226

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 132

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


112
113
114
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 112

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



118
119
120
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 118

def hash
  [distinct_attribute, match_attribute, requests].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



89
90
91
92
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 89

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



202
203
204
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 202

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



196
197
198
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 196

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



96
97
98
# File 'lib/kubernetes/models/v1_device_constraint.rb', line 96

def valid?
  true
end