Class: Kubernetes::V1Endpoint

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_endpoint.rb

Overview

Endpoint represents a single logical "backend" implementing a service.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1Endpoint

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/kubernetes/models/v1_endpoint.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1Endpoint` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1Endpoint`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'addresses')
    if (value = attributes[:'addresses']).is_a?(Array)
      self.addresses = value
    end
  end

  if attributes.key?(:'conditions')
    self.conditions = attributes[:'conditions']
  end

  if attributes.key?(:'deprecated_topology')
    if (value = attributes[:'deprecated_topology']).is_a?(Hash)
      self.deprecated_topology = value
    end
  end

  if attributes.key?(:'hints')
    self.hints = attributes[:'hints']
  end

  if attributes.key?(:'hostname')
    self.hostname = attributes[:'hostname']
  end

  if attributes.key?(:'node_name')
    self.node_name = attributes[:'node_name']
  end

  if attributes.key?(:'target_ref')
    self.target_ref = attributes[:'target_ref']
  end

  if attributes.key?(:'zone')
    self.zone = attributes[:'zone']
  end
end

Instance Attribute Details

#addressesObject

addresses of this endpoint. For EndpointSlices of addressType "IPv4" or "IPv6", the values are IP addresses in canonical form. The syntax and semantics of other addressType values are not defined. This must contain at least one address but no more than 100. EndpointSlices generated by the EndpointSlice controller will always have exactly 1 address. No semantics are defined for additional addresses beyond the first, and kube-proxy does not look at them.



20
21
22
# File 'lib/kubernetes/models/v1_endpoint.rb', line 20

def addresses
  @addresses
end

#conditionsObject

Returns the value of attribute conditions.



22
23
24
# File 'lib/kubernetes/models/v1_endpoint.rb', line 22

def conditions
  @conditions
end

#deprecated_topologyObject

deprecatedTopology contains topology information part of the v1beta1 API. This field is deprecated, and will be removed when the v1beta1 API is removed (no sooner than kubernetes v1.24). While this field can hold values, it is not writable through the v1 API, and any attempts to write to it will be silently ignored. Topology information can be found in the zone and nodeName fields instead.



25
26
27
# File 'lib/kubernetes/models/v1_endpoint.rb', line 25

def deprecated_topology
  @deprecated_topology
end

#hintsObject

Returns the value of attribute hints.



27
28
29
# File 'lib/kubernetes/models/v1_endpoint.rb', line 27

def hints
  @hints
end

#hostnameObject

hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation.



30
31
32
# File 'lib/kubernetes/models/v1_endpoint.rb', line 30

def hostname
  @hostname
end

#node_nameObject

nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node.



33
34
35
# File 'lib/kubernetes/models/v1_endpoint.rb', line 33

def node_name
  @node_name
end

#target_refObject

Returns the value of attribute target_ref.



35
36
37
# File 'lib/kubernetes/models/v1_endpoint.rb', line 35

def target_ref
  @target_ref
end

#zoneObject

zone is the name of the Zone this endpoint exists in.



38
39
40
# File 'lib/kubernetes/models/v1_endpoint.rb', line 38

def zone
  @zone
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/kubernetes/models/v1_endpoint.rb', line 55

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/kubernetes/models/v1_endpoint.rb', line 41

def self.attribute_map
  {
    :'addresses' => :'addresses',
    :'conditions' => :'conditions',
    :'deprecated_topology' => :'deprecatedTopology',
    :'hints' => :'hints',
    :'hostname' => :'hostname',
    :'node_name' => :'nodeName',
    :'target_ref' => :'targetRef',
    :'zone' => :'zone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
# File 'lib/kubernetes/models/v1_endpoint.rb', line 179

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/kubernetes/models/v1_endpoint.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/kubernetes/models/v1_endpoint.rb', line 60

def self.openapi_types
  {
    :'addresses' => :'Array<String>',
    :'conditions' => :'V1EndpointConditions',
    :'deprecated_topology' => :'Hash<String, String>',
    :'hints' => :'V1EndpointHints',
    :'hostname' => :'String',
    :'node_name' => :'String',
    :'target_ref' => :'V1ObjectReference',
    :'zone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/kubernetes/models/v1_endpoint.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      addresses == o.addresses &&
      conditions == o.conditions &&
      deprecated_topology == o.deprecated_topology &&
      hints == o.hints &&
      hostname == o.hostname &&
      node_name == o.node_name &&
      target_ref == o.target_ref &&
      zone == o.zone
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/kubernetes/models/v1_endpoint.rb', line 209

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/kubernetes/models/v1_endpoint.rb', line 280

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/kubernetes/models/v1_endpoint.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/kubernetes/models/v1_endpoint.rb', line 166

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



172
173
174
# File 'lib/kubernetes/models/v1_endpoint.rb', line 172

def hash
  [addresses, conditions, deprecated_topology, hints, hostname, node_name, target_ref, zone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
# File 'lib/kubernetes/models/v1_endpoint.rb', line 133

def list_invalid_properties
  invalid_properties = Array.new
  if @addresses.nil?
    invalid_properties.push('invalid value for "addresses", addresses cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
# File 'lib/kubernetes/models/v1_endpoint.rb', line 256

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/kubernetes/models/v1_endpoint.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



250
251
252
# File 'lib/kubernetes/models/v1_endpoint.rb', line 250

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
# File 'lib/kubernetes/models/v1_endpoint.rb', line 144

def valid?
  return false if @addresses.nil?
  true
end