Class: Kubernetes::V1EphemeralContainer

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_ephemeral_container.rb

Overview

An EphemeralContainer is a temporary container that you may add to an existing Pod for user-initiated activities such as debugging. Ephemeral containers have no resource or scheduling guarantees, and they will not be restarted when they exit or when a Pod is removed or restarted. The kubelet may evict a Pod if an ephemeral container causes the Pod to exceed its resource allocation. To add an ephemeral container, use the ephemeralcontainers subresource of an existing Pod. Ephemeral containers may not be removed or restarted.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1EphemeralContainer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 168

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1EphemeralContainer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1EphemeralContainer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'args')
    if (value = attributes[:'args']).is_a?(Array)
      self.args = value
    end
  end

  if attributes.key?(:'command')
    if (value = attributes[:'command']).is_a?(Array)
      self.command = value
    end
  end

  if attributes.key?(:'env')
    if (value = attributes[:'env']).is_a?(Array)
      self.env = value
    end
  end

  if attributes.key?(:'env_from')
    if (value = attributes[:'env_from']).is_a?(Array)
      self.env_from = value
    end
  end

  if attributes.key?(:'image')
    self.image = attributes[:'image']
  end

  if attributes.key?(:'image_pull_policy')
    self.image_pull_policy = attributes[:'image_pull_policy']
  end

  if attributes.key?(:'lifecycle')
    self.lifecycle = attributes[:'lifecycle']
  end

  if attributes.key?(:'liveness_probe')
    self.liveness_probe = attributes[:'liveness_probe']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'ports')
    if (value = attributes[:'ports']).is_a?(Array)
      self.ports = value
    end
  end

  if attributes.key?(:'readiness_probe')
    self.readiness_probe = attributes[:'readiness_probe']
  end

  if attributes.key?(:'resize_policy')
    if (value = attributes[:'resize_policy']).is_a?(Array)
      self.resize_policy = value
    end
  end

  if attributes.key?(:'resources')
    self.resources = attributes[:'resources']
  end

  if attributes.key?(:'restart_policy')
    self.restart_policy = attributes[:'restart_policy']
  end

  if attributes.key?(:'restart_policy_rules')
    if (value = attributes[:'restart_policy_rules']).is_a?(Array)
      self.restart_policy_rules = value
    end
  end

  if attributes.key?(:'security_context')
    self.security_context = attributes[:'security_context']
  end

  if attributes.key?(:'startup_probe')
    self.startup_probe = attributes[:'startup_probe']
  end

  if attributes.key?(:'stdin')
    self.stdin = attributes[:'stdin']
  end

  if attributes.key?(:'stdin_once')
    self.stdin_once = attributes[:'stdin_once']
  end

  if attributes.key?(:'target_container_name')
    self.target_container_name = attributes[:'target_container_name']
  end

  if attributes.key?(:'termination_message_path')
    self.termination_message_path = attributes[:'termination_message_path']
  end

  if attributes.key?(:'termination_message_policy')
    self.termination_message_policy = attributes[:'termination_message_policy']
  end

  if attributes.key?(:'tty')
    self.tty = attributes[:'tty']
  end

  if attributes.key?(:'volume_devices')
    if (value = attributes[:'volume_devices']).is_a?(Array)
      self.volume_devices = value
    end
  end

  if attributes.key?(:'volume_mounts')
    if (value = attributes[:'volume_mounts']).is_a?(Array)
      self.volume_mounts = value
    end
  end

  if attributes.key?(:'working_dir')
    self.working_dir = attributes[:'working_dir']
  end
end

Instance Attribute Details

#argsObject

Arguments to the entrypoint. The image’s CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container’s environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell



20
21
22
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 20

def args
  @args
end

#commandObject

Entrypoint array. Not executed within a shell. The image’s ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container’s environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell



23
24
25
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 23

def command
  @command
end

#envObject

List of environment variables to set in the container. Cannot be updated.



26
27
28
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 26

def env
  @env
end

#env_fromObject

List of sources to populate environment variables in the container. The keys defined within a source may consist of any printable ASCII characters except ‘=’. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.



29
30
31
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 29

def env_from
  @env_from
end

#imageObject

Container image name. More info: kubernetes.io/docs/concepts/containers/images



32
33
34
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 32

def image
  @image
end

#image_pull_policyObject

Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: kubernetes.io/docs/concepts/containers/images#updating-images



35
36
37
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 35

def image_pull_policy
  @image_pull_policy
end

#lifecycleObject

Returns the value of attribute lifecycle.



37
38
39
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 37

def lifecycle
  @lifecycle
end

#liveness_probeObject

Returns the value of attribute liveness_probe.



39
40
41
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 39

def liveness_probe
  @liveness_probe
end

#nameObject

Name of the ephemeral container specified as a DNS_LABEL. This name must be unique among all containers, init containers and ephemeral containers.



42
43
44
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 42

def name
  @name
end

#portsObject

Ports are not allowed for ephemeral containers.



45
46
47
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 45

def ports
  @ports
end

#readiness_probeObject

Returns the value of attribute readiness_probe.



47
48
49
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 47

def readiness_probe
  @readiness_probe
end

#resize_policyObject

Resources resize policy for the container.



50
51
52
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 50

def resize_policy
  @resize_policy
end

#resourcesObject

Returns the value of attribute resources.



52
53
54
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 52

def resources
  @resources
end

#restart_policyObject

Restart policy for the container to manage the restart behavior of each container within a pod. You cannot set this field on ephemeral containers.



55
56
57
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 55

def restart_policy
  @restart_policy
end

#restart_policy_rulesObject

Represents a list of rules to be checked to determine if the container should be restarted on exit. You cannot set this field on ephemeral containers.



58
59
60
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 58

def restart_policy_rules
  @restart_policy_rules
end

#security_contextObject

Returns the value of attribute security_context.



60
61
62
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 60

def security_context
  @security_context
end

#startup_probeObject

Returns the value of attribute startup_probe.



62
63
64
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 62

def startup_probe
  @startup_probe
end

#stdinObject

Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.



65
66
67
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 65

def stdin
  @stdin
end

#stdin_onceObject

Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false



68
69
70
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 68

def stdin_once
  @stdin_once
end

#target_container_nameObject

If set, the name of the container from PodSpec that this ephemeral container targets. The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container uses the namespaces configured in the Pod spec. The container runtime must implement support for this feature. If the runtime does not support namespace targeting then the result of setting this field is undefined.



71
72
73
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 71

def target_container_name
  @target_container_name
end

#termination_message_pathObject

Optional: Path at which the file to which the container’s termination message will be written is mounted into the container’s filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.



74
75
76
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 74

def termination_message_path
  @termination_message_path
end

#termination_message_policyObject

Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.



77
78
79
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 77

def termination_message_policy
  @termination_message_policy
end

#ttyObject

Whether this container should allocate a TTY for itself, also requires ‘stdin’ to be true. Default is false.



80
81
82
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 80

def tty
  @tty
end

#volume_devicesObject

volumeDevices is the list of block devices to be used by the container.



83
84
85
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 83

def volume_devices
  @volume_devices
end

#volume_mountsObject

Pod volumes to mount into the container’s filesystem. Subpath mounts are not allowed for ephemeral containers. Cannot be updated.



86
87
88
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 86

def volume_mounts
  @volume_mounts
end

#working_dirObject

Container’s working directory. If not specified, the container runtime’s default will be used, which might be configured in the container image. Cannot be updated.



89
90
91
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 89

def working_dir
  @working_dir
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



124
125
126
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 124

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 92

def self.attribute_map
  {
    :'args' => :'args',
    :'command' => :'command',
    :'env' => :'env',
    :'env_from' => :'envFrom',
    :'image' => :'image',
    :'image_pull_policy' => :'imagePullPolicy',
    :'lifecycle' => :'lifecycle',
    :'liveness_probe' => :'livenessProbe',
    :'name' => :'name',
    :'ports' => :'ports',
    :'readiness_probe' => :'readinessProbe',
    :'resize_policy' => :'resizePolicy',
    :'resources' => :'resources',
    :'restart_policy' => :'restartPolicy',
    :'restart_policy_rules' => :'restartPolicyRules',
    :'security_context' => :'securityContext',
    :'startup_probe' => :'startupProbe',
    :'stdin' => :'stdin',
    :'stdin_once' => :'stdinOnce',
    :'target_container_name' => :'targetContainerName',
    :'termination_message_path' => :'terminationMessagePath',
    :'termination_message_policy' => :'terminationMessagePolicy',
    :'tty' => :'tty',
    :'volume_devices' => :'volumeDevices',
    :'volume_mounts' => :'volumeMounts',
    :'working_dir' => :'workingDir'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



370
371
372
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 370

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



161
162
163
164
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 161

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 129

def self.openapi_types
  {
    :'args' => :'Array<String>',
    :'command' => :'Array<String>',
    :'env' => :'Array<V1EnvVar>',
    :'env_from' => :'Array<V1EnvFromSource>',
    :'image' => :'String',
    :'image_pull_policy' => :'String',
    :'lifecycle' => :'V1Lifecycle',
    :'liveness_probe' => :'V1Probe',
    :'name' => :'String',
    :'ports' => :'Array<V1ContainerPort>',
    :'readiness_probe' => :'V1Probe',
    :'resize_policy' => :'Array<V1ContainerResizePolicy>',
    :'resources' => :'V1ResourceRequirements',
    :'restart_policy' => :'String',
    :'restart_policy_rules' => :'Array<V1ContainerRestartRule>',
    :'security_context' => :'V1SecurityContext',
    :'startup_probe' => :'V1Probe',
    :'stdin' => :'Boolean',
    :'stdin_once' => :'Boolean',
    :'target_container_name' => :'String',
    :'termination_message_path' => :'String',
    :'termination_message_policy' => :'String',
    :'tty' => :'Boolean',
    :'volume_devices' => :'Array<V1VolumeDevice>',
    :'volume_mounts' => :'Array<V1VolumeMount>',
    :'working_dir' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 324

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      args == o.args &&
      command == o.command &&
      env == o.env &&
      env_from == o.env_from &&
      image == o.image &&
      image_pull_policy == o.image_pull_policy &&
      lifecycle == o.lifecycle &&
      liveness_probe == o.liveness_probe &&
      name == o.name &&
      ports == o.ports &&
      readiness_probe == o.readiness_probe &&
      resize_policy == o.resize_policy &&
      resources == o.resources &&
      restart_policy == o.restart_policy &&
      restart_policy_rules == o.restart_policy_rules &&
      security_context == o.security_context &&
      startup_probe == o.startup_probe &&
      stdin == o.stdin &&
      stdin_once == o.stdin_once &&
      target_container_name == o.target_container_name &&
      termination_message_path == o.termination_message_path &&
      termination_message_policy == o.termination_message_policy &&
      tty == o.tty &&
      volume_devices == o.volume_devices &&
      volume_mounts == o.volume_mounts &&
      working_dir == o.working_dir
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 400

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 471

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 377

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


357
358
359
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 357

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



363
364
365
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 363

def hash
  [args, command, env, env_from, image, image_pull_policy, lifecycle, liveness_probe, name, ports, readiness_probe, resize_policy, resources, restart_policy, restart_policy_rules, security_context, startup_probe, stdin, stdin_once, target_container_name, termination_message_path, termination_message_policy, tty, volume_devices, volume_mounts, working_dir].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



306
307
308
309
310
311
312
313
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 306

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



447
448
449
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 447

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 453

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



441
442
443
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 441

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



317
318
319
320
# File 'lib/kubernetes/models/v1_ephemeral_container.rb', line 317

def valid?
  return false if @name.nil?
  true
end