Class: Kubernetes::V1ExactDeviceRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_exact_device_request.rb

Overview

ExactDeviceRequest is a request for one or more identical devices.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1ExactDeviceRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ExactDeviceRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ExactDeviceRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'admin_access')
    self.admin_access = attributes[:'admin_access']
  end

  if attributes.key?(:'allocation_mode')
    self.allocation_mode = attributes[:'allocation_mode']
  end

  if attributes.key?(:'capacity')
    self.capacity = attributes[:'capacity']
  end

  if attributes.key?(:'count')
    self.count = attributes[:'count']
  end

  if attributes.key?(:'device_class_name')
    self.device_class_name = attributes[:'device_class_name']
  end

  if attributes.key?(:'selectors')
    if (value = attributes[:'selectors']).is_a?(Array)
      self.selectors = value
    end
  end

  if attributes.key?(:'tolerations')
    if (value = attributes[:'tolerations']).is_a?(Array)
      self.tolerations = value
    end
  end
end

Instance Attribute Details

#admin_accessObject

AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device. They ignore all ordinary claims to the device with respect to access modes and any resource allocations. This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.



20
21
22
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 20

def admin_access
  @admin_access
end

#allocation_modeObject

AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are: - ExactCount: This request is for a specific number of devices. This is the default. The exact number is provided in the count field. - All: This request is for all of the matching devices in a pool. At least one device must exist on the node for the allocation to succeed. Allocation will fail if some devices are already allocated, unless adminAccess is requested. If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field. More modes may get added in the future. Clients must refuse to handle requests with unknown modes.



23
24
25
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 23

def allocation_mode
  @allocation_mode
end

#capacityObject

Returns the value of attribute capacity.



25
26
27
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 25

def capacity
  @capacity
end

#countObject

Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one.



28
29
30
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 28

def count
  @count
end

#device_class_nameObject

DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request. A DeviceClassName is required. Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.



31
32
33
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 31

def device_class_name
  @device_class_name
end

#selectorsObject

Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered.



34
35
36
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 34

def selectors
  @selectors
end

#tolerationsObject

If specified, the request’s tolerations. Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute. In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated. The maximum number of tolerations is 16. This is an alpha field and requires enabling the DRADeviceTaints feature gate.



37
38
39
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 37

def tolerations
  @tolerations
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 53

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 40

def self.attribute_map
  {
    :'admin_access' => :'adminAccess',
    :'allocation_mode' => :'allocationMode',
    :'capacity' => :'capacity',
    :'count' => :'count',
    :'device_class_name' => :'deviceClassName',
    :'selectors' => :'selectors',
    :'tolerations' => :'tolerations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 171

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 58

def self.openapi_types
  {
    :'admin_access' => :'Boolean',
    :'allocation_mode' => :'String',
    :'capacity' => :'V1CapacityRequirements',
    :'count' => :'Integer',
    :'device_class_name' => :'String',
    :'selectors' => :'Array<V1DeviceSelector>',
    :'tolerations' => :'Array<V1DeviceToleration>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
153
154
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 144

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      admin_access == o.admin_access &&
      allocation_mode == o.allocation_mode &&
      capacity == o.capacity &&
      count == o.count &&
      device_class_name == o.device_class_name &&
      selectors == o.selectors &&
      tolerations == o.tolerations
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 201

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 272

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 178

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 164

def hash
  [admin_access, allocation_mode, capacity, count, device_class_name, selectors, tolerations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 126

def list_invalid_properties
  invalid_properties = Array.new
  if @device_class_name.nil?
    invalid_properties.push('invalid value for "device_class_name", device_class_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 248

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



242
243
244
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 242

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
# File 'lib/kubernetes/models/v1_exact_device_request.rb', line 137

def valid?
  return false if @device_class_name.nil?
  true
end