Class: Kubernetes::V1ISCSIVolumeSource

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_iscsi_volume_source.rb

Overview

Represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1ISCSIVolumeSource

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ISCSIVolumeSource` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ISCSIVolumeSource`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'chap_auth_discovery')
    self.chap_auth_discovery = attributes[:'chap_auth_discovery']
  end

  if attributes.key?(:'chap_auth_session')
    self.chap_auth_session = attributes[:'chap_auth_session']
  end

  if attributes.key?(:'fs_type')
    self.fs_type = attributes[:'fs_type']
  end

  if attributes.key?(:'initiator_name')
    self.initiator_name = attributes[:'initiator_name']
  end

  if attributes.key?(:'iqn')
    self.iqn = attributes[:'iqn']
  end

  if attributes.key?(:'iscsi_interface')
    self.iscsi_interface = attributes[:'iscsi_interface']
  end

  if attributes.key?(:'lun')
    self.lun = attributes[:'lun']
  end

  if attributes.key?(:'portals')
    if (value = attributes[:'portals']).is_a?(Array)
      self.portals = value
    end
  end

  if attributes.key?(:'read_only')
    self.read_only = attributes[:'read_only']
  end

  if attributes.key?(:'secret_ref')
    self.secret_ref = attributes[:'secret_ref']
  end

  if attributes.key?(:'target_portal')
    self.target_portal = attributes[:'target_portal']
  end
end

Instance Attribute Details

#chap_auth_discoveryObject

chapAuthDiscovery defines whether support iSCSI Discovery CHAP authentication



20
21
22
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 20

def chap_auth_discovery
  @chap_auth_discovery
end

#chap_auth_sessionObject

chapAuthSession defines whether support iSCSI Session CHAP authentication



23
24
25
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 23

def chap_auth_session
  @chap_auth_session
end

#fs_typeObject

fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: kubernetes.io/docs/concepts/storage/volumes#iscsi



26
27
28
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 26

def fs_type
  @fs_type
end

#initiator_nameObject

initiatorName is the custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection.



29
30
31
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 29

def initiator_name
  @initiator_name
end

#iqnObject

iqn is the target iSCSI Qualified Name.



32
33
34
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 32

def iqn
  @iqn
end

#iscsi_interfaceObject

iscsiInterface is the interface Name that uses an iSCSI transport. Defaults to ‘default’ (tcp).



35
36
37
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 35

def iscsi_interface
  @iscsi_interface
end

#lunObject

lun represents iSCSI Target Lun number.



38
39
40
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 38

def lun
  @lun
end

#portalsObject

portals is the iSCSI Target Portal List. The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).



41
42
43
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 41

def portals
  @portals
end

#read_onlyObject

readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false.



44
45
46
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 44

def read_only
  @read_only
end

#secret_refObject

Returns the value of attribute secret_ref.



46
47
48
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 46

def secret_ref
  @secret_ref
end

#target_portalObject

targetPortal is iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260).



49
50
51
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 49

def target_portal
  @target_portal
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 52

def self.attribute_map
  {
    :'chap_auth_discovery' => :'chapAuthDiscovery',
    :'chap_auth_session' => :'chapAuthSession',
    :'fs_type' => :'fsType',
    :'initiator_name' => :'initiatorName',
    :'iqn' => :'iqn',
    :'iscsi_interface' => :'iscsiInterface',
    :'lun' => :'lun',
    :'portals' => :'portals',
    :'read_only' => :'readOnly',
    :'secret_ref' => :'secretRef',
    :'target_portal' => :'targetPortal'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 219

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 74

def self.openapi_types
  {
    :'chap_auth_discovery' => :'Boolean',
    :'chap_auth_session' => :'Boolean',
    :'fs_type' => :'String',
    :'initiator_name' => :'String',
    :'iqn' => :'String',
    :'iscsi_interface' => :'String',
    :'lun' => :'Integer',
    :'portals' => :'Array<String>',
    :'read_only' => :'Boolean',
    :'secret_ref' => :'V1LocalObjectReference',
    :'target_portal' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      chap_auth_discovery == o.chap_auth_discovery &&
      chap_auth_session == o.chap_auth_session &&
      fs_type == o.fs_type &&
      initiator_name == o.initiator_name &&
      iqn == o.iqn &&
      iscsi_interface == o.iscsi_interface &&
      lun == o.lun &&
      portals == o.portals &&
      read_only == o.read_only &&
      secret_ref == o.secret_ref &&
      target_portal == o.target_portal
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 249

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 320

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 226

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 212

def hash
  [chap_auth_discovery, chap_auth_session, fs_type, initiator_name, iqn, iscsi_interface, lun, portals, read_only, secret_ref, target_portal].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  if @iqn.nil?
    invalid_properties.push('invalid value for "iqn", iqn cannot be nil.')
  end

  if @lun.nil?
    invalid_properties.push('invalid value for "lun", lun cannot be nil.')
  end

  if @target_portal.nil?
    invalid_properties.push('invalid value for "target_portal", target_portal cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 296

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



290
291
292
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 290

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
# File 'lib/kubernetes/models/v1_iscsi_volume_source.rb', line 179

def valid?
  return false if @iqn.nil?
  return false if @lun.nil?
  return false if @target_portal.nil?
  true
end