Class: Kubernetes::V1JobStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_job_status.rb

Overview

JobStatus represents the current state of a Job.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1JobStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/kubernetes/models/v1_job_status.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1JobStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1JobStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end

  if attributes.key?(:'completed_indexes')
    self.completed_indexes = attributes[:'completed_indexes']
  end

  if attributes.key?(:'completion_time')
    self.completion_time = attributes[:'completion_time']
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'failed')
    self.failed = attributes[:'failed']
  end

  if attributes.key?(:'failed_indexes')
    self.failed_indexes = attributes[:'failed_indexes']
  end

  if attributes.key?(:'ready')
    self.ready = attributes[:'ready']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'succeeded')
    self.succeeded = attributes[:'succeeded']
  end

  if attributes.key?(:'terminating')
    self.terminating = attributes[:'terminating']
  end

  if attributes.key?(:'uncounted_terminated_pods')
    self.uncounted_terminated_pods = attributes[:'uncounted_terminated_pods']
  end
end

Instance Attribute Details

#activeObject

The number of pending and running pods which are not terminating (without a deletionTimestamp). The value is zero for finished jobs.



20
21
22
# File 'lib/kubernetes/models/v1_job_status.rb', line 20

def active
  @active
end

#completed_indexesObject

completedIndexes holds the completed indexes when .spec.completionMode = "Indexed" in a text format. The indexes are represented as decimal integers separated by commas. The numbers are listed in increasing order. Three or more consecutive numbers are compressed and represented by the first and last element of the series, separated by a hyphen. For example, if the completed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7".



23
24
25
# File 'lib/kubernetes/models/v1_job_status.rb', line 23

def completed_indexes
  @completed_indexes
end

#completion_timeObject

Represents time when the job was completed. It is not guaranteed to be set in happens-before order across separate operations. It is represented in RFC3339 form and is in UTC. The completion time is set when the job finishes successfully, and only then. The value cannot be updated or removed. The value indicates the same or later point in time as the startTime field.



26
27
28
# File 'lib/kubernetes/models/v1_job_status.rb', line 26

def completion_time
  @completion_time
end

#conditionsObject

The latest available observations of an object’s current state. When a Job fails, one of the conditions will have type "Failed" and status true. When a Job is suspended, one of the conditions will have type "Suspended" and status true; when the Job is resumed, the status of this condition will become false. When a Job is completed, one of the conditions will have type "Complete" and status true. A job is considered finished when it is in a terminal condition, either "Complete" or "Failed". A Job cannot have both the "Complete" and "Failed" conditions. Additionally, it cannot be in the "Complete" and "FailureTarget" conditions. The "Complete", "Failed" and "FailureTarget" conditions cannot be disabled. More info: kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/



29
30
31
# File 'lib/kubernetes/models/v1_job_status.rb', line 29

def conditions
  @conditions
end

#failedObject

The number of pods which reached phase Failed. The value increases monotonically.



32
33
34
# File 'lib/kubernetes/models/v1_job_status.rb', line 32

def failed
  @failed
end

#failed_indexesObject

FailedIndexes holds the failed indexes when spec.backoffLimitPerIndex is set. The indexes are represented in the text format analogous as for the ‘completedIndexes` field, ie. they are kept as decimal integers separated by commas. The numbers are listed in increasing order. Three or more consecutive numbers are compressed and represented by the first and last element of the series, separated by a hyphen. For example, if the failed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7". The set of failed indexes cannot overlap with the set of completed indexes.



35
36
37
# File 'lib/kubernetes/models/v1_job_status.rb', line 35

def failed_indexes
  @failed_indexes
end

#readyObject

The number of active pods which have a Ready condition and are not terminating (without a deletionTimestamp).



38
39
40
# File 'lib/kubernetes/models/v1_job_status.rb', line 38

def ready
  @ready
end

#start_timeObject

Represents time when the job controller started processing a job. When a Job is created in the suspended state, this field is not set until the first time it is resumed. This field is reset every time a Job is resumed from suspension. It is represented in RFC3339 form and is in UTC. Once set, the field can only be removed when the job is suspended. The field cannot be modified while the job is unsuspended or finished.



41
42
43
# File 'lib/kubernetes/models/v1_job_status.rb', line 41

def start_time
  @start_time
end

#succeededObject

The number of pods which reached phase Succeeded. The value increases monotonically for a given spec. However, it may decrease in reaction to scale down of elastic indexed jobs.



44
45
46
# File 'lib/kubernetes/models/v1_job_status.rb', line 44

def succeeded
  @succeeded
end

#terminatingObject

The number of pods which are terminating (in phase Pending or Running and have a deletionTimestamp). This field is beta-level. The job controller populates the field when the feature gate JobPodReplacementPolicy is enabled (enabled by default).



47
48
49
# File 'lib/kubernetes/models/v1_job_status.rb', line 47

def terminating
  @terminating
end

#uncounted_terminated_podsObject

Returns the value of attribute uncounted_terminated_pods.



49
50
51
# File 'lib/kubernetes/models/v1_job_status.rb', line 49

def uncounted_terminated_pods
  @uncounted_terminated_pods
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/kubernetes/models/v1_job_status.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/kubernetes/models/v1_job_status.rb', line 52

def self.attribute_map
  {
    :'active' => :'active',
    :'completed_indexes' => :'completedIndexes',
    :'completion_time' => :'completionTime',
    :'conditions' => :'conditions',
    :'failed' => :'failed',
    :'failed_indexes' => :'failedIndexes',
    :'ready' => :'ready',
    :'start_time' => :'startTime',
    :'succeeded' => :'succeeded',
    :'terminating' => :'terminating',
    :'uncounted_terminated_pods' => :'uncountedTerminatedPods'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
# File 'lib/kubernetes/models/v1_job_status.rb', line 204

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/kubernetes/models/v1_job_status.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/kubernetes/models/v1_job_status.rb', line 74

def self.openapi_types
  {
    :'active' => :'Integer',
    :'completed_indexes' => :'String',
    :'completion_time' => :'Time',
    :'conditions' => :'Array<V1JobCondition>',
    :'failed' => :'Integer',
    :'failed_indexes' => :'String',
    :'ready' => :'Integer',
    :'start_time' => :'Time',
    :'succeeded' => :'Integer',
    :'terminating' => :'Integer',
    :'uncounted_terminated_pods' => :'V1UncountedTerminatedPods'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/kubernetes/models/v1_job_status.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active == o.active &&
      completed_indexes == o.completed_indexes &&
      completion_time == o.completion_time &&
      conditions == o.conditions &&
      failed == o.failed &&
      failed_indexes == o.failed_indexes &&
      ready == o.ready &&
      start_time == o.start_time &&
      succeeded == o.succeeded &&
      terminating == o.terminating &&
      uncounted_terminated_pods == o.uncounted_terminated_pods
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/kubernetes/models/v1_job_status.rb', line 234

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/kubernetes/models/v1_job_status.rb', line 305

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/kubernetes/models/v1_job_status.rb', line 211

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/kubernetes/models/v1_job_status.rb', line 191

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



197
198
199
# File 'lib/kubernetes/models/v1_job_status.rb', line 197

def hash
  [active, completed_indexes, completion_time, conditions, failed, failed_indexes, ready, start_time, succeeded, terminating, uncounted_terminated_pods].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
# File 'lib/kubernetes/models/v1_job_status.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
# File 'lib/kubernetes/models/v1_job_status.rb', line 281

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/kubernetes/models/v1_job_status.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



275
276
277
# File 'lib/kubernetes/models/v1_job_status.rb', line 275

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
# File 'lib/kubernetes/models/v1_job_status.rb', line 167

def valid?
  true
end