Class: Kubernetes::V1NamedRuleWithOperations

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_named_rule_with_operations.rb

Overview

NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1NamedRuleWithOperations

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1NamedRuleWithOperations` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1NamedRuleWithOperations`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'api_groups')
    if (value = attributes[:'api_groups']).is_a?(Array)
      self.api_groups = value
    end
  end

  if attributes.key?(:'api_versions')
    if (value = attributes[:'api_versions']).is_a?(Array)
      self.api_versions = value
    end
  end

  if attributes.key?(:'operations')
    if (value = attributes[:'operations']).is_a?(Array)
      self.operations = value
    end
  end

  if attributes.key?(:'resource_names')
    if (value = attributes[:'resource_names']).is_a?(Array)
      self.resource_names = value
    end
  end

  if attributes.key?(:'resources')
    if (value = attributes[:'resources']).is_a?(Array)
      self.resources = value
    end
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end
end

Instance Attribute Details

#api_groupsObject

APIGroups is the API groups the resources belong to. ‘*’ is all groups. If ‘*’ is present, the length of the slice must be one. Required.



20
21
22
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 20

def api_groups
  @api_groups
end

#api_versionsObject

APIVersions is the API versions the resources belong to. ‘*’ is all versions. If ‘*’ is present, the length of the slice must be one. Required.



23
24
25
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 23

def api_versions
  @api_versions
end

#operationsObject

Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If ‘*’ is present, the length of the slice must be one. Required.



26
27
28
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 26

def operations
  @operations
end

#resource_namesObject

ResourceNames is an optional white list of names that the rule applies to. An empty set means that everything is allowed.



29
30
31
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 29

def resource_names
  @resource_names
end

#resourcesObject

Resources is a list of resources this rule applies to. For example: ‘pods’ means pods. ‘pods/log’ means the log subresource of pods. ‘*’ means all resources, but not subresources. ‘pods/*’ means all subresources of pods. ‘*/scale’ means all scale subresources. ‘/’ means all resources and their subresources. If wildcard is present, the validation rule will ensure resources do not overlap with each other. Depending on the enclosing object, subresources might not be allowed. Required.



32
33
34
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 32

def resources
  @resources
end

#scopeObject

scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*".



35
36
37
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 35

def scope
  @scope
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 50

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 38

def self.attribute_map
  {
    :'api_groups' => :'apiGroups',
    :'api_versions' => :'apiVersions',
    :'operations' => :'operations',
    :'resource_names' => :'resourceNames',
    :'resources' => :'resources',
    :'scope' => :'scope'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 163

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 55

def self.openapi_types
  {
    :'api_groups' => :'Array<String>',
    :'api_versions' => :'Array<String>',
    :'operations' => :'Array<String>',
    :'resource_names' => :'Array<String>',
    :'resources' => :'Array<String>',
    :'scope' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
144
145
146
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      api_groups == o.api_groups &&
      api_versions == o.api_versions &&
      operations == o.operations &&
      resource_names == o.resource_names &&
      resources == o.resources &&
      scope == o.scope
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 193

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 264

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 170

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


150
151
152
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 150

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



156
157
158
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 156

def hash
  [api_groups, api_versions, operations, resource_names, resources, scope].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 124

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 240

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



234
235
236
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 234

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
# File 'lib/kubernetes/models/v1_named_rule_with_operations.rb', line 131

def valid?
  true
end