Class: Kubernetes::V1NodeStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_node_status.rb

Overview

NodeStatus is information about the current status of a node.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1NodeStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/kubernetes/models/v1_node_status.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1NodeStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1NodeStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'addresses')
    if (value = attributes[:'addresses']).is_a?(Array)
      self.addresses = value
    end
  end

  if attributes.key?(:'allocatable')
    if (value = attributes[:'allocatable']).is_a?(Hash)
      self.allocatable = value
    end
  end

  if attributes.key?(:'capacity')
    if (value = attributes[:'capacity']).is_a?(Hash)
      self.capacity = value
    end
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'config')
    self.config = attributes[:'config']
  end

  if attributes.key?(:'daemon_endpoints')
    self.daemon_endpoints = attributes[:'daemon_endpoints']
  end

  if attributes.key?(:'declared_features')
    if (value = attributes[:'declared_features']).is_a?(Array)
      self.declared_features = value
    end
  end

  if attributes.key?(:'features')
    self.features = attributes[:'features']
  end

  if attributes.key?(:'images')
    if (value = attributes[:'images']).is_a?(Array)
      self.images = value
    end
  end

  if attributes.key?(:'node_info')
    self.node_info = attributes[:'node_info']
  end

  if attributes.key?(:'phase')
    self.phase = attributes[:'phase']
  end

  if attributes.key?(:'runtime_handlers')
    if (value = attributes[:'runtime_handlers']).is_a?(Array)
      self.runtime_handlers = value
    end
  end

  if attributes.key?(:'volumes_attached')
    if (value = attributes[:'volumes_attached']).is_a?(Array)
      self.volumes_attached = value
    end
  end

  if attributes.key?(:'volumes_in_use')
    if (value = attributes[:'volumes_in_use']).is_a?(Array)
      self.volumes_in_use = value
    end
  end
end

Instance Attribute Details

#addressesObject

List of addresses reachable to the node. Queried from cloud provider, if available. More info: kubernetes.io/docs/reference/node/node-status/#addresses Note: This field is declared as mergeable, but the merge key is not sufficiently unique, which can cause data corruption when it is merged. Callers should instead use a full-replacement patch. See pr.k8s.io/79391 for an example. Consumers should assume that addresses can change during the lifetime of a Node. However, there are some exceptions where this may not be possible, such as Pods that inherit a Node’s address in its own status or consumers of the downward API (status.hostIP).



20
21
22
# File 'lib/kubernetes/models/v1_node_status.rb', line 20

def addresses
  @addresses
end

#allocatableObject

Allocatable represents the resources of a node that are available for scheduling. Defaults to Capacity.



23
24
25
# File 'lib/kubernetes/models/v1_node_status.rb', line 23

def allocatable
  @allocatable
end

#capacityObject

Capacity represents the total resources of a node. More info: kubernetes.io/docs/reference/node/node-status/#capacity



26
27
28
# File 'lib/kubernetes/models/v1_node_status.rb', line 26

def capacity
  @capacity
end

#conditionsObject

Conditions is an array of current observed node conditions. More info: kubernetes.io/docs/reference/node/node-status/#condition



29
30
31
# File 'lib/kubernetes/models/v1_node_status.rb', line 29

def conditions
  @conditions
end

#configObject

Returns the value of attribute config.



31
32
33
# File 'lib/kubernetes/models/v1_node_status.rb', line 31

def config
  @config
end

#daemon_endpointsObject

Returns the value of attribute daemon_endpoints.



33
34
35
# File 'lib/kubernetes/models/v1_node_status.rb', line 33

def daemon_endpoints
  @daemon_endpoints
end

#declared_featuresObject

DeclaredFeatures represents the features related to feature gates that are declared by the node.



36
37
38
# File 'lib/kubernetes/models/v1_node_status.rb', line 36

def declared_features
  @declared_features
end

#featuresObject

Returns the value of attribute features.



38
39
40
# File 'lib/kubernetes/models/v1_node_status.rb', line 38

def features
  @features
end

#imagesObject

List of container images on this node



41
42
43
# File 'lib/kubernetes/models/v1_node_status.rb', line 41

def images
  @images
end

#node_infoObject

Returns the value of attribute node_info.



43
44
45
# File 'lib/kubernetes/models/v1_node_status.rb', line 43

def node_info
  @node_info
end

#phaseObject

NodePhase is the recently observed lifecycle phase of the node. More info: kubernetes.io/docs/concepts/nodes/node/#phase The field is never populated, and now is deprecated.



46
47
48
# File 'lib/kubernetes/models/v1_node_status.rb', line 46

def phase
  @phase
end

#runtime_handlersObject

The available runtime handlers.



49
50
51
# File 'lib/kubernetes/models/v1_node_status.rb', line 49

def runtime_handlers
  @runtime_handlers
end

#volumes_attachedObject

List of volumes that are attached to the node.



52
53
54
# File 'lib/kubernetes/models/v1_node_status.rb', line 52

def volumes_attached
  @volumes_attached
end

#volumes_in_useObject

List of attachable volumes in use (mounted) by the node.



55
56
57
# File 'lib/kubernetes/models/v1_node_status.rb', line 55

def volumes_in_use
  @volumes_in_use
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/kubernetes/models/v1_node_status.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/kubernetes/models/v1_node_status.rb', line 58

def self.attribute_map
  {
    :'addresses' => :'addresses',
    :'allocatable' => :'allocatable',
    :'capacity' => :'capacity',
    :'conditions' => :'conditions',
    :'config' => :'config',
    :'daemon_endpoints' => :'daemonEndpoints',
    :'declared_features' => :'declaredFeatures',
    :'features' => :'features',
    :'images' => :'images',
    :'node_info' => :'nodeInfo',
    :'phase' => :'phase',
    :'runtime_handlers' => :'runtimeHandlers',
    :'volumes_attached' => :'volumesAttached',
    :'volumes_in_use' => :'volumesInUse'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
# File 'lib/kubernetes/models/v1_node_status.rb', line 247

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/kubernetes/models/v1_node_status.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/kubernetes/models/v1_node_status.rb', line 83

def self.openapi_types
  {
    :'addresses' => :'Array<V1NodeAddress>',
    :'allocatable' => :'Hash<String, String>',
    :'capacity' => :'Hash<String, String>',
    :'conditions' => :'Array<V1NodeCondition>',
    :'config' => :'V1NodeConfigStatus',
    :'daemon_endpoints' => :'V1NodeDaemonEndpoints',
    :'declared_features' => :'Array<String>',
    :'features' => :'V1NodeFeatures',
    :'images' => :'Array<V1ContainerImage>',
    :'node_info' => :'V1NodeSystemInfo',
    :'phase' => :'String',
    :'runtime_handlers' => :'Array<V1NodeRuntimeHandler>',
    :'volumes_attached' => :'Array<V1AttachedVolume>',
    :'volumes_in_use' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/kubernetes/models/v1_node_status.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      addresses == o.addresses &&
      allocatable == o.allocatable &&
      capacity == o.capacity &&
      conditions == o.conditions &&
      config == o.config &&
      daemon_endpoints == o.daemon_endpoints &&
      declared_features == o.declared_features &&
      features == o.features &&
      images == o.images &&
      node_info == o.node_info &&
      phase == o.phase &&
      runtime_handlers == o.runtime_handlers &&
      volumes_attached == o.volumes_attached &&
      volumes_in_use == o.volumes_in_use
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/kubernetes/models/v1_node_status.rb', line 277

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/kubernetes/models/v1_node_status.rb', line 348

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/kubernetes/models/v1_node_status.rb', line 254

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/kubernetes/models/v1_node_status.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/kubernetes/models/v1_node_status.rb', line 240

def hash
  [addresses, allocatable, capacity, conditions, config, daemon_endpoints, declared_features, features, images, node_info, phase, runtime_handlers, volumes_attached, volumes_in_use].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



200
201
202
203
# File 'lib/kubernetes/models/v1_node_status.rb', line 200

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
# File 'lib/kubernetes/models/v1_node_status.rb', line 324

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/kubernetes/models/v1_node_status.rb', line 330

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/kubernetes/models/v1_node_status.rb', line 318

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
# File 'lib/kubernetes/models/v1_node_status.rb', line 207

def valid?
  true
end