Class: Kubernetes::V1PodFailurePolicyOnExitCodesRequirement

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb

Overview

PodFailurePolicyOnExitCodesRequirement describes the requirement for handling a failed pod based on its container exit codes. In particular, it lookups the .state.terminated.exitCode for each app container and init container status, represented by the .status.containerStatuses and .status.initContainerStatuses fields in the Pod status, respectively. Containers completed with success (exit code 0) are excluded from the requirement check.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1PodFailurePolicyOnExitCodesRequirement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1PodFailurePolicyOnExitCodesRequirement` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1PodFailurePolicyOnExitCodesRequirement`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'container_name')
    self.container_name = attributes[:'container_name']
  end

  if attributes.key?(:'operator')
    self.operator = attributes[:'operator']
  end

  if attributes.key?(:'values')
    if (value = attributes[:'values']).is_a?(Array)
      self.values = value
    end
  end
end

Instance Attribute Details

#container_nameObject

Restricts the check for exit codes to the container with the specified name. When null, the rule applies to all containers. When specified, it should match one the container or initContainer names in the pod template.



20
21
22
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 20

def container_name
  @container_name
end

#operatorObject

Represents the relationship between the container exit code(s) and the specified values. Containers completed with success (exit code 0) are excluded from the requirement check. Possible values are: - In: the requirement is satisfied if at least one container exit code (might be multiple if there are multiple containers not restricted by the ‘containerName’ field) is in the set of specified values. - NotIn: the requirement is satisfied if at least one container exit code (might be multiple if there are multiple containers not restricted by the ‘containerName’ field) is not in the set of specified values. Additional values are considered to be added in the future. Clients should react to an unknown operator by assuming the requirement is not satisfied.



23
24
25
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 23

def operator
  @operator
end

#valuesObject

Specifies the set of values. Each returned container exit code (might be multiple in case of multiple containers) is checked against this set of values with respect to the operator. The list of values must be ordered and must not contain duplicates. Value ‘0’ cannot be used for the In operator. At least one element is required. At most 255 elements are allowed.



26
27
28
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 26

def values
  @values
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 38

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 29

def self.attribute_map
  {
    :'container_name' => :'containerName',
    :'operator' => :'operator',
    :'values' => :'values'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



135
136
137
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 135

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 52

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
49
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 43

def self.openapi_types
  {
    :'container_name' => :'String',
    :'operator' => :'String',
    :'values' => :'Array<Integer>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



112
113
114
115
116
117
118
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 112

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      container_name == o.container_name &&
      operator == o.operator &&
      values == o.values
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 165

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 236

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 142

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


122
123
124
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 122

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



128
129
130
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 128

def hash
  [container_name, operator, values].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 89

def list_invalid_properties
  invalid_properties = Array.new
  if @operator.nil?
    invalid_properties.push('invalid value for "operator", operator cannot be nil.')
  end

  if @values.nil?
    invalid_properties.push('invalid value for "values", values cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 212

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



206
207
208
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 206

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



104
105
106
107
108
# File 'lib/kubernetes/models/v1_pod_failure_policy_on_exit_codes_requirement.rb', line 104

def valid?
  return false if @operator.nil?
  return false if @values.nil?
  true
end