Class: Kubernetes::V1RuntimeClass
- Inherits:
-
Object
- Object
- Kubernetes::V1RuntimeClass
- Defined in:
- lib/kubernetes/models/v1_runtime_class.rb
Overview
RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod. For more details, see kubernetes.io/docs/concepts/containers/runtime-class/
Instance Attribute Summary collapse
-
#api_version ⇒ Object
APIVersion defines the versioned schema of this representation of an object.
-
#handler ⇒ Object
handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class.
-
#kind ⇒ Object
Kind is a string value representing the REST resource this object represents.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#overhead ⇒ Object
Returns the value of attribute overhead.
-
#scheduling ⇒ Object
Returns the value of attribute scheduling.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1RuntimeClass
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1RuntimeClass
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1RuntimeClass` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1RuntimeClass`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'api_version') self.api_version = attributes[:'api_version'] end if attributes.key?(:'handler') self.handler = attributes[:'handler'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'overhead') self.overhead = attributes[:'overhead'] end if attributes.key?(:'scheduling') self.scheduling = attributes[:'scheduling'] end end |
Instance Attribute Details
#api_version ⇒ Object
APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
20 21 22 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 20 def api_version @api_version end |
#handler ⇒ Object
handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration. It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable.
23 24 25 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 23 def handler @handler end |
#kind ⇒ Object
Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
26 27 28 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 26 def kind @kind end |
#metadata ⇒ Object
Returns the value of attribute metadata.
28 29 30 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 28 def @metadata end |
#overhead ⇒ Object
Returns the value of attribute overhead.
30 31 32 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 30 def overhead @overhead end |
#scheduling ⇒ Object
Returns the value of attribute scheduling.
32 33 34 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 32 def scheduling @scheduling end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 47 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 35 def self.attribute_map { :'api_version' => :'apiVersion', :'handler' => :'handler', :'kind' => :'kind', :'metadata' => :'metadata', :'overhead' => :'overhead', :'scheduling' => :'scheduling' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 155 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 61 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 52 def self.openapi_types { :'api_version' => :'String', :'handler' => :'String', :'kind' => :'String', :'metadata' => :'V1ObjectMeta', :'overhead' => :'V1Overhead', :'scheduling' => :'V1Scheduling' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 138 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 129 def ==(o) return true if self.equal?(o) self.class == o.class && api_version == o.api_version && handler == o.handler && kind == o.kind && == o. && overhead == o.overhead && scheduling == o.scheduling end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 185 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 256 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 162 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
142 143 144 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 142 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 148 def hash [api_version, handler, kind, , overhead, scheduling].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 116 117 118 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 111 def list_invalid_properties invalid_properties = Array.new if @handler.nil? invalid_properties.push('invalid value for "handler", handler cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
232 233 234 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 232 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
226 227 228 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 226 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 |
# File 'lib/kubernetes/models/v1_runtime_class.rb', line 122 def valid? return false if @handler.nil? true end |