Class: Kubernetes::V1SecurityContext

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_security_context.rb

Overview

SecurityContext holds security configuration that will be applied to a container. Some fields are present in both SecurityContext and PodSecurityContext. When both are set, the values in SecurityContext take precedence.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1SecurityContext

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/kubernetes/models/v1_security_context.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1SecurityContext` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1SecurityContext`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allow_privilege_escalation')
    self.allow_privilege_escalation = attributes[:'allow_privilege_escalation']
  end

  if attributes.key?(:'app_armor_profile')
    self.app_armor_profile = attributes[:'app_armor_profile']
  end

  if attributes.key?(:'capabilities')
    self.capabilities = attributes[:'capabilities']
  end

  if attributes.key?(:'privileged')
    self.privileged = attributes[:'privileged']
  end

  if attributes.key?(:'proc_mount')
    self.proc_mount = attributes[:'proc_mount']
  end

  if attributes.key?(:'read_only_root_filesystem')
    self.read_only_root_filesystem = attributes[:'read_only_root_filesystem']
  end

  if attributes.key?(:'run_as_group')
    self.run_as_group = attributes[:'run_as_group']
  end

  if attributes.key?(:'run_as_non_root')
    self.run_as_non_root = attributes[:'run_as_non_root']
  end

  if attributes.key?(:'run_as_user')
    self.run_as_user = attributes[:'run_as_user']
  end

  if attributes.key?(:'se_linux_options')
    self.se_linux_options = attributes[:'se_linux_options']
  end

  if attributes.key?(:'seccomp_profile')
    self.seccomp_profile = attributes[:'seccomp_profile']
  end

  if attributes.key?(:'windows_options')
    self.windows_options = attributes[:'windows_options']
  end
end

Instance Attribute Details

#allow_privilege_escalationObject

AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows.



20
21
22
# File 'lib/kubernetes/models/v1_security_context.rb', line 20

def allow_privilege_escalation
  @allow_privilege_escalation
end

#app_armor_profileObject

Returns the value of attribute app_armor_profile.



22
23
24
# File 'lib/kubernetes/models/v1_security_context.rb', line 22

def app_armor_profile
  @app_armor_profile
end

#capabilitiesObject

Returns the value of attribute capabilities.



24
25
26
# File 'lib/kubernetes/models/v1_security_context.rb', line 24

def capabilities
  @capabilities
end

#privilegedObject

Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows.



27
28
29
# File 'lib/kubernetes/models/v1_security_context.rb', line 27

def privileged
  @privileged
end

#proc_mountObject

procMount denotes the type of proc mount to use for the containers. The default value is Default which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows.



30
31
32
# File 'lib/kubernetes/models/v1_security_context.rb', line 30

def proc_mount
  @proc_mount
end

#read_only_root_filesystemObject

Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows.



33
34
35
# File 'lib/kubernetes/models/v1_security_context.rb', line 33

def read_only_root_filesystem
  @read_only_root_filesystem
end

#run_as_groupObject

The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.



36
37
38
# File 'lib/kubernetes/models/v1_security_context.rb', line 36

def run_as_group
  @run_as_group
end

#run_as_non_rootObject

Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence.



39
40
41
# File 'lib/kubernetes/models/v1_security_context.rb', line 39

def run_as_non_root
  @run_as_non_root
end

#run_as_userObject

The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows.



42
43
44
# File 'lib/kubernetes/models/v1_security_context.rb', line 42

def run_as_user
  @run_as_user
end

#se_linux_optionsObject

Returns the value of attribute se_linux_options.



44
45
46
# File 'lib/kubernetes/models/v1_security_context.rb', line 44

def se_linux_options
  @se_linux_options
end

#seccomp_profileObject

Returns the value of attribute seccomp_profile.



46
47
48
# File 'lib/kubernetes/models/v1_security_context.rb', line 46

def seccomp_profile
  @seccomp_profile
end

#windows_optionsObject

Returns the value of attribute windows_options.



48
49
50
# File 'lib/kubernetes/models/v1_security_context.rb', line 48

def windows_options
  @windows_options
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/kubernetes/models/v1_security_context.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/kubernetes/models/v1_security_context.rb', line 51

def self.attribute_map
  {
    :'allow_privilege_escalation' => :'allowPrivilegeEscalation',
    :'app_armor_profile' => :'appArmorProfile',
    :'capabilities' => :'capabilities',
    :'privileged' => :'privileged',
    :'proc_mount' => :'procMount',
    :'read_only_root_filesystem' => :'readOnlyRootFilesystem',
    :'run_as_group' => :'runAsGroup',
    :'run_as_non_root' => :'runAsNonRoot',
    :'run_as_user' => :'runAsUser',
    :'se_linux_options' => :'seLinuxOptions',
    :'seccomp_profile' => :'seccompProfile',
    :'windows_options' => :'windowsOptions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
# File 'lib/kubernetes/models/v1_security_context.rb', line 208

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/kubernetes/models/v1_security_context.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/kubernetes/models/v1_security_context.rb', line 74

def self.openapi_types
  {
    :'allow_privilege_escalation' => :'Boolean',
    :'app_armor_profile' => :'V1AppArmorProfile',
    :'capabilities' => :'V1Capabilities',
    :'privileged' => :'Boolean',
    :'proc_mount' => :'String',
    :'read_only_root_filesystem' => :'Boolean',
    :'run_as_group' => :'Integer',
    :'run_as_non_root' => :'Boolean',
    :'run_as_user' => :'Integer',
    :'se_linux_options' => :'V1SELinuxOptions',
    :'seccomp_profile' => :'V1SeccompProfile',
    :'windows_options' => :'V1WindowsSecurityContextOptions'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/kubernetes/models/v1_security_context.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allow_privilege_escalation == o.allow_privilege_escalation &&
      app_armor_profile == o.app_armor_profile &&
      capabilities == o.capabilities &&
      privileged == o.privileged &&
      proc_mount == o.proc_mount &&
      read_only_root_filesystem == o.read_only_root_filesystem &&
      run_as_group == o.run_as_group &&
      run_as_non_root == o.run_as_non_root &&
      run_as_user == o.run_as_user &&
      se_linux_options == o.se_linux_options &&
      seccomp_profile == o.seccomp_profile &&
      windows_options == o.windows_options
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/kubernetes/models/v1_security_context.rb', line 238

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/kubernetes/models/v1_security_context.rb', line 309

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/kubernetes/models/v1_security_context.rb', line 215

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/kubernetes/models/v1_security_context.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/kubernetes/models/v1_security_context.rb', line 201

def hash
  [allow_privilege_escalation, app_armor_profile, capabilities, privileged, proc_mount, read_only_root_filesystem, run_as_group, run_as_non_root, run_as_user, se_linux_options, seccomp_profile, windows_options].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
# File 'lib/kubernetes/models/v1_security_context.rb', line 163

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
# File 'lib/kubernetes/models/v1_security_context.rb', line 285

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/kubernetes/models/v1_security_context.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



279
280
281
# File 'lib/kubernetes/models/v1_security_context.rb', line 279

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
# File 'lib/kubernetes/models/v1_security_context.rb', line 170

def valid?
  true
end