Class: Kubernetes::V1StatefulSetSpec

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_stateful_set_spec.rb

Overview

A StatefulSetSpec is the specification of a StatefulSet.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1StatefulSetSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1StatefulSetSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1StatefulSetSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'min_ready_seconds')
    self.min_ready_seconds = attributes[:'min_ready_seconds']
  end

  if attributes.key?(:'ordinals')
    self.ordinals = attributes[:'ordinals']
  end

  if attributes.key?(:'persistent_volume_claim_retention_policy')
    self.persistent_volume_claim_retention_policy = attributes[:'persistent_volume_claim_retention_policy']
  end

  if attributes.key?(:'pod_management_policy')
    self.pod_management_policy = attributes[:'pod_management_policy']
  end

  if attributes.key?(:'replicas')
    self.replicas = attributes[:'replicas']
  end

  if attributes.key?(:'revision_history_limit')
    self.revision_history_limit = attributes[:'revision_history_limit']
  end

  if attributes.key?(:'selector')
    self.selector = attributes[:'selector']
  end

  if attributes.key?(:'service_name')
    self.service_name = attributes[:'service_name']
  end

  if attributes.key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.key?(:'update_strategy')
    self.update_strategy = attributes[:'update_strategy']
  end

  if attributes.key?(:'volume_claim_templates')
    if (value = attributes[:'volume_claim_templates']).is_a?(Array)
      self.volume_claim_templates = value
    end
  end
end

Instance Attribute Details

#min_ready_secondsObject

Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready)



20
21
22
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 20

def min_ready_seconds
  @min_ready_seconds
end

#ordinalsObject

Returns the value of attribute ordinals.



22
23
24
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 22

def ordinals
  @ordinals
end

#persistent_volume_claim_retention_policyObject

Returns the value of attribute persistent_volume_claim_retention_policy.



24
25
26
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 24

def persistent_volume_claim_retention_policy
  @persistent_volume_claim_retention_policy
end

#pod_management_policyObject

podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is ‘OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.



27
28
29
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 27

def pod_management_policy
  @pod_management_policy
end

#replicasObject

replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1.



30
31
32
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 30

def replicas
  @replicas
end

#revision_history_limitObject

revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet’s revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10.



33
34
35
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 33

def revision_history_limit
  @revision_history_limit
end

#selectorObject

Returns the value of attribute selector.



35
36
37
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 35

def selector
  @selector
end

#service_nameObject

serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller.



38
39
40
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 38

def service_name
  @service_name
end

#templateObject

Returns the value of attribute template.



40
41
42
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 40

def template
  @template
end

#update_strategyObject

Returns the value of attribute update_strategy.



42
43
44
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 42

def update_strategy
  @update_strategy
end

#volume_claim_templatesObject

volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name.



45
46
47
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 45

def volume_claim_templates
  @volume_claim_templates
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 65

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 48

def self.attribute_map
  {
    :'min_ready_seconds' => :'minReadySeconds',
    :'ordinals' => :'ordinals',
    :'persistent_volume_claim_retention_policy' => :'persistentVolumeClaimRetentionPolicy',
    :'pod_management_policy' => :'podManagementPolicy',
    :'replicas' => :'replicas',
    :'revision_history_limit' => :'revisionHistoryLimit',
    :'selector' => :'selector',
    :'service_name' => :'serviceName',
    :'template' => :'template',
    :'update_strategy' => :'updateStrategy',
    :'volume_claim_templates' => :'volumeClaimTemplates'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 210

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 70

def self.openapi_types
  {
    :'min_ready_seconds' => :'Integer',
    :'ordinals' => :'V1StatefulSetOrdinals',
    :'persistent_volume_claim_retention_policy' => :'V1StatefulSetPersistentVolumeClaimRetentionPolicy',
    :'pod_management_policy' => :'String',
    :'replicas' => :'Integer',
    :'revision_history_limit' => :'Integer',
    :'selector' => :'V1LabelSelector',
    :'service_name' => :'String',
    :'template' => :'V1PodTemplateSpec',
    :'update_strategy' => :'V1StatefulSetUpdateStrategy',
    :'volume_claim_templates' => :'Array<V1PersistentVolumeClaim>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      min_ready_seconds == o.min_ready_seconds &&
      ordinals == o.ordinals &&
      persistent_volume_claim_retention_policy == o.persistent_volume_claim_retention_policy &&
      pod_management_policy == o.pod_management_policy &&
      replicas == o.replicas &&
      revision_history_limit == o.revision_history_limit &&
      selector == o.selector &&
      service_name == o.service_name &&
      template == o.template &&
      update_strategy == o.update_strategy &&
      volume_claim_templates == o.volume_claim_templates
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 240

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 311

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 217

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 203

def hash
  [min_ready_seconds, ordinals, persistent_volume_claim_retention_policy, pod_management_policy, replicas, revision_history_limit, selector, service_name, template, update_strategy, volume_claim_templates].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 156

def list_invalid_properties
  invalid_properties = Array.new
  if @selector.nil?
    invalid_properties.push('invalid value for "selector", selector cannot be nil.')
  end

  if @template.nil?
    invalid_properties.push('invalid value for "template", template cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 287

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



281
282
283
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 281

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
# File 'lib/kubernetes/models/v1_stateful_set_spec.rb', line 171

def valid?
  return false if @selector.nil?
  return false if @template.nil?
  true
end