Class: Kubernetes::V1StorageClass

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_storage_class.rb

Overview

StorageClass describes the parameters for a class of storage for which PersistentVolumes can be dynamically provisioned. StorageClasses are non-namespaced; the name of the storage class according to etcd is in ObjectMeta.Name.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1StorageClass

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/kubernetes/models/v1_storage_class.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1StorageClass` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1StorageClass`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'allow_volume_expansion')
    self.allow_volume_expansion = attributes[:'allow_volume_expansion']
  end

  if attributes.key?(:'allowed_topologies')
    if (value = attributes[:'allowed_topologies']).is_a?(Array)
      self.allowed_topologies = value
    end
  end

  if attributes.key?(:'api_version')
    self.api_version = attributes[:'api_version']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'mount_options')
    if (value = attributes[:'mount_options']).is_a?(Array)
      self.mount_options = value
    end
  end

  if attributes.key?(:'parameters')
    if (value = attributes[:'parameters']).is_a?(Hash)
      self.parameters = value
    end
  end

  if attributes.key?(:'provisioner')
    self.provisioner = attributes[:'provisioner']
  end

  if attributes.key?(:'reclaim_policy')
    self.reclaim_policy = attributes[:'reclaim_policy']
  end

  if attributes.key?(:'volume_binding_mode')
    self.volume_binding_mode = attributes[:'volume_binding_mode']
  end
end

Instance Attribute Details

#allow_volume_expansionObject

allowVolumeExpansion shows whether the storage class allow volume expand.



20
21
22
# File 'lib/kubernetes/models/v1_storage_class.rb', line 20

def allow_volume_expansion
  @allow_volume_expansion
end

#allowed_topologiesObject

allowedTopologies restrict the node topologies where volumes can be dynamically provisioned. Each volume plugin defines its own supported topology specifications. An empty TopologySelectorTerm list means there is no topology restriction. This field is only honored by servers that enable the VolumeScheduling feature.



23
24
25
# File 'lib/kubernetes/models/v1_storage_class.rb', line 23

def allowed_topologies
  @allowed_topologies
end

#api_versionObject

APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources



26
27
28
# File 'lib/kubernetes/models/v1_storage_class.rb', line 26

def api_version
  @api_version
end

#kindObject

Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds



29
30
31
# File 'lib/kubernetes/models/v1_storage_class.rb', line 29

def kind
  @kind
end

#metadataObject

Returns the value of attribute metadata.



31
32
33
# File 'lib/kubernetes/models/v1_storage_class.rb', line 31

def 
  @metadata
end

#mount_optionsObject

mountOptions controls the mountOptions for dynamically provisioned PersistentVolumes of this storage class. e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid.



34
35
36
# File 'lib/kubernetes/models/v1_storage_class.rb', line 34

def mount_options
  @mount_options
end

#parametersObject

parameters holds the parameters for the provisioner that should create volumes of this storage class.



37
38
39
# File 'lib/kubernetes/models/v1_storage_class.rb', line 37

def parameters
  @parameters
end

#provisionerObject

provisioner indicates the type of the provisioner.



40
41
42
# File 'lib/kubernetes/models/v1_storage_class.rb', line 40

def provisioner
  @provisioner
end

#reclaim_policyObject

reclaimPolicy controls the reclaimPolicy for dynamically provisioned PersistentVolumes of this storage class. Defaults to Delete.



43
44
45
# File 'lib/kubernetes/models/v1_storage_class.rb', line 43

def reclaim_policy
  @reclaim_policy
end

#volume_binding_modeObject

volumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound. When unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the VolumeScheduling feature.



46
47
48
# File 'lib/kubernetes/models/v1_storage_class.rb', line 46

def volume_binding_mode
  @volume_binding_mode
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/kubernetes/models/v1_storage_class.rb', line 65

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/kubernetes/models/v1_storage_class.rb', line 49

def self.attribute_map
  {
    :'allow_volume_expansion' => :'allowVolumeExpansion',
    :'allowed_topologies' => :'allowedTopologies',
    :'api_version' => :'apiVersion',
    :'kind' => :'kind',
    :'metadata' => :'metadata',
    :'mount_options' => :'mountOptions',
    :'parameters' => :'parameters',
    :'provisioner' => :'provisioner',
    :'reclaim_policy' => :'reclaimPolicy',
    :'volume_binding_mode' => :'volumeBindingMode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
# File 'lib/kubernetes/models/v1_storage_class.rb', line 203

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/kubernetes/models/v1_storage_class.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/kubernetes/models/v1_storage_class.rb', line 70

def self.openapi_types
  {
    :'allow_volume_expansion' => :'Boolean',
    :'allowed_topologies' => :'Array<V1TopologySelectorTerm>',
    :'api_version' => :'String',
    :'kind' => :'String',
    :'metadata' => :'V1ObjectMeta',
    :'mount_options' => :'Array<String>',
    :'parameters' => :'Hash<String, String>',
    :'provisioner' => :'String',
    :'reclaim_policy' => :'String',
    :'volume_binding_mode' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/kubernetes/models/v1_storage_class.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      allow_volume_expansion == o.allow_volume_expansion &&
      allowed_topologies == o.allowed_topologies &&
      api_version == o.api_version &&
      kind == o.kind &&
       == o. &&
      mount_options == o.mount_options &&
      parameters == o.parameters &&
      provisioner == o.provisioner &&
      reclaim_policy == o.reclaim_policy &&
      volume_binding_mode == o.volume_binding_mode
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/kubernetes/models/v1_storage_class.rb', line 233

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/kubernetes/models/v1_storage_class.rb', line 304

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/kubernetes/models/v1_storage_class.rb', line 210

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/kubernetes/models/v1_storage_class.rb', line 190

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



196
197
198
# File 'lib/kubernetes/models/v1_storage_class.rb', line 196

def hash
  [allow_volume_expansion, allowed_topologies, api_version, kind, , mount_options, parameters, provisioner, reclaim_policy, volume_binding_mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
# File 'lib/kubernetes/models/v1_storage_class.rb', line 155

def list_invalid_properties
  invalid_properties = Array.new
  if @provisioner.nil?
    invalid_properties.push('invalid value for "provisioner", provisioner cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
# File 'lib/kubernetes/models/v1_storage_class.rb', line 280

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/kubernetes/models/v1_storage_class.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



274
275
276
# File 'lib/kubernetes/models/v1_storage_class.rb', line 274

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
# File 'lib/kubernetes/models/v1_storage_class.rb', line 166

def valid?
  return false if @provisioner.nil?
  true
end