Class: Kubernetes::V1ValidatingAdmissionPolicyBindingSpec

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb

Overview

ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1ValidatingAdmissionPolicyBindingSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ValidatingAdmissionPolicyBindingSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ValidatingAdmissionPolicyBindingSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'match_resources')
    self.match_resources = attributes[:'match_resources']
  end

  if attributes.key?(:'param_ref')
    self.param_ref = attributes[:'param_ref']
  end

  if attributes.key?(:'policy_name')
    self.policy_name = attributes[:'policy_name']
  end

  if attributes.key?(:'validation_actions')
    if (value = attributes[:'validation_actions']).is_a?(Array)
      self.validation_actions = value
    end
  end
end

Instance Attribute Details

#match_resourcesObject

Returns the value of attribute match_resources.



19
20
21
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 19

def match_resources
  @match_resources
end

#param_refObject

Returns the value of attribute param_ref.



21
22
23
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 21

def param_ref
  @param_ref
end

#policy_nameObject

PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.



24
25
26
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 24

def policy_name
  @policy_name
end

#validation_actionsObject

validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions. Failures defined by the ValidatingAdmissionPolicy’s FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy. validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action. The supported actions values are: "Deny" specifies that a validation failure results in a denied request. "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses. "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a ‘validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[\"Invalid value\", {\"policy\": \"policy.example.com\", {\"binding\": \"policybinding.example.com\", {\"expressionIndex\": \"1\", {\"validationActions\": [\"Audit\"]]"` Clients should expect to handle additional values by ignoring any values not recognized. "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers. Required.



27
28
29
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 27

def validation_actions
  @validation_actions
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



40
41
42
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 40

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 30

def self.attribute_map
  {
    :'match_resources' => :'matchResources',
    :'param_ref' => :'paramRef',
    :'policy_name' => :'policyName',
    :'validation_actions' => :'validationActions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



133
134
135
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 133

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



45
46
47
48
49
50
51
52
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 45

def self.openapi_types
  {
    :'match_resources' => :'V1MatchResources',
    :'param_ref' => :'V1ParamRef',
    :'policy_name' => :'String',
    :'validation_actions' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



109
110
111
112
113
114
115
116
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 109

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      match_resources == o.match_resources &&
      param_ref == o.param_ref &&
      policy_name == o.policy_name &&
      validation_actions == o.validation_actions
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 163

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 234

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 140

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


120
121
122
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 120

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



126
127
128
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 126

def hash
  [match_resources, param_ref, policy_name, validation_actions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 96

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 210

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



204
205
206
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 204

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



103
104
105
# File 'lib/kubernetes/models/v1_validating_admission_policy_binding_spec.rb', line 103

def valid?
  true
end