Class: Kubernetes::V1ValidatingAdmissionPolicySpec

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_validating_admission_policy_spec.rb

Overview

ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1ValidatingAdmissionPolicySpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ValidatingAdmissionPolicySpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ValidatingAdmissionPolicySpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'audit_annotations')
    if (value = attributes[:'audit_annotations']).is_a?(Array)
      self.audit_annotations = value
    end
  end

  if attributes.key?(:'failure_policy')
    self.failure_policy = attributes[:'failure_policy']
  end

  if attributes.key?(:'match_conditions')
    if (value = attributes[:'match_conditions']).is_a?(Array)
      self.match_conditions = value
    end
  end

  if attributes.key?(:'match_constraints')
    self.match_constraints = attributes[:'match_constraints']
  end

  if attributes.key?(:'param_kind')
    self.param_kind = attributes[:'param_kind']
  end

  if attributes.key?(:'validations')
    if (value = attributes[:'validations']).is_a?(Array)
      self.validations = value
    end
  end

  if attributes.key?(:'variables')
    if (value = attributes[:'variables']).is_a?(Array)
      self.variables = value
    end
  end
end

Instance Attribute Details

#audit_annotationsObject

auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required.



20
21
22
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 20

def audit_annotations
  @audit_annotations
end

#failure_policyObject

failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings. A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource. failurePolicy does not define how validations that evaluate to false are handled. When failurePolicy is set to Fail, ValidatingAdmissionPolicyBinding validationActions define how failures are enforced. Allowed values are Ignore or Fail. Defaults to Fail.



23
24
25
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 23

def failure_policy
  @failure_policy
end

#match_conditionsObject

MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed. If a parameter object is provided, it can be accessed via the ‘params` handle in the same manner as validation expressions. The exact matching logic is (in order): 1. If ANY matchCondition evaluates to FALSE, the policy is skipped. 2. If ALL matchConditions evaluate to TRUE, the policy is evaluated. 3. If any matchCondition evaluates to an error (but none are FALSE): - If failurePolicy=Fail, reject the request - If failurePolicy=Ignore, the policy is skipped



26
27
28
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 26

def match_conditions
  @match_conditions
end

#match_constraintsObject

Returns the value of attribute match_constraints.



28
29
30
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 28

def match_constraints
  @match_constraints
end

#param_kindObject

Returns the value of attribute param_kind.



30
31
32
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 30

def param_kind
  @param_kind
end

#validationsObject

Validations contain CEL expressions which is used to apply the validation. Validations and AuditAnnotations may not both be empty; a minimum of one Validations or AuditAnnotations is required.



33
34
35
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 33

def validations
  @validations
end

#variablesObject

Variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under ‘variables` in other expressions of the policy except MatchConditions because MatchConditions are evaluated before the rest of the policy. The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, Variables must be sorted by the order of first appearance and acyclic.



36
37
38
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 36

def variables
  @variables
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 52

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 39

def self.attribute_map
  {
    :'audit_annotations' => :'auditAnnotations',
    :'failure_policy' => :'failurePolicy',
    :'match_conditions' => :'matchConditions',
    :'match_constraints' => :'matchConstraints',
    :'param_kind' => :'paramKind',
    :'validations' => :'validations',
    :'variables' => :'variables'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 169

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 57

def self.openapi_types
  {
    :'audit_annotations' => :'Array<V1AuditAnnotation>',
    :'failure_policy' => :'String',
    :'match_conditions' => :'Array<V1MatchCondition>',
    :'match_constraints' => :'V1MatchResources',
    :'param_kind' => :'V1ParamKind',
    :'validations' => :'Array<V1Validation>',
    :'variables' => :'Array<V1Variable>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      audit_annotations == o.audit_annotations &&
      failure_policy == o.failure_policy &&
      match_conditions == o.match_conditions &&
      match_constraints == o.match_constraints &&
      param_kind == o.param_kind &&
      validations == o.validations &&
      variables == o.variables
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 199

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 270

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 176

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 162

def hash
  [audit_annotations, failure_policy, match_conditions, match_constraints, param_kind, validations, variables].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 129

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 246

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 252

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



240
241
242
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 240

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
# File 'lib/kubernetes/models/v1_validating_admission_policy_spec.rb', line 136

def valid?
  true
end