Class: Kubernetes::V1Validation

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_validation.rb

Overview

Validation specifies the CEL expression which is used to apply the validation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1Validation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/kubernetes/models/v1_validation.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1Validation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1Validation`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'expression')
    self.expression = attributes[:'expression']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'message_expression')
    self.message_expression = attributes[:'message_expression']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end
end

Instance Attribute Details

#expressionObject

Expression represents the expression which will be evaluated by CEL. ref: github.com/google/cel-spec CEL expressions have access to the contents of the API request/response, organized into CEL variables as well as some other useful variables: - ‘object’ - The object from the incoming request. The value is null for DELETE requests. - ‘oldObject’ - The existing object. The value is null for CREATE requests. - ‘request’ - Attributes of the API request((/pkg/apis/admission/types.go#AdmissionRequest)). - ‘params’ - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - ‘namespaceObject’ - The namespace object that the incoming object belongs to. The value is null for cluster-scoped resources. - ‘variables’ - Map of composited variables, from its name to its lazily evaluated value. For example, a variable named ‘foo’ can be accessed as ‘variables.foo’. - ‘authorizer’ - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request. See pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz - ‘authorizer.requestResource’ - A CEL ResourceCheck constructed from the ‘authorizer’ and configured with the request resource. The ‘apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible. Only property names of the form `[a-zA-Z_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - ’__’ escapes to ‘__underscores__’ - ‘.’ escapes to ‘__dot__’ - ‘-’ escapes to ‘__dash__’ - ‘/’ escapes to ‘__slash__’ - Property names that exactly match a CEL RESERVED keyword escape to ‘__keyword__’. The keywords are: "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if", "import", "let", "loop", "package", "namespace", "return". Examples: - Expression accessing a property named "namespace": "object.__namespace__ > 0" - Expression accessing a property named "x-prop": "object.x__dash__prop > 0" - Expression accessing a property named "redact__d": "object.redact__underscores__d > 0" Equality on arrays with list type of ‘set’ or ‘map’ ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type: - ‘set’: ‘X + Y` performs a union where the array positions of all elements in `X` are preserved and non-intersecting elements in `Y` are appended, retaining their partial order. - ’map’: ‘X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with non-intersecting keys are appended, retaining their partial order. Required.



20
21
22
# File 'lib/kubernetes/models/v1_validation.rb', line 20

def expression
  @expression
end

#messageObject

Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: Rule". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: Expression".



23
24
25
# File 'lib/kubernetes/models/v1_validation.rb', line 23

def message
  @message
end

#message_expressionObject

messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the ‘expression` except for ’authorizer’ and ‘authorizer.requestResource’. Example: "object.x must be less than max ("+string(params.max)+")"



26
27
28
# File 'lib/kubernetes/models/v1_validation.rb', line 26

def message_expression
  @message_expression
end

#reasonObject

Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client.



29
30
31
# File 'lib/kubernetes/models/v1_validation.rb', line 29

def reason
  @reason
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/kubernetes/models/v1_validation.rb', line 42

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/kubernetes/models/v1_validation.rb', line 32

def self.attribute_map
  {
    :'expression' => :'expression',
    :'message' => :'message',
    :'message_expression' => :'messageExpression',
    :'reason' => :'reason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



138
139
140
# File 'lib/kubernetes/models/v1_validation.rb', line 138

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/kubernetes/models/v1_validation.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/kubernetes/models/v1_validation.rb', line 47

def self.openapi_types
  {
    :'expression' => :'String',
    :'message' => :'String',
    :'message_expression' => :'String',
    :'reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



114
115
116
117
118
119
120
121
# File 'lib/kubernetes/models/v1_validation.rb', line 114

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      expression == o.expression &&
      message == o.message &&
      message_expression == o.message_expression &&
      reason == o.reason
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/kubernetes/models/v1_validation.rb', line 168

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/kubernetes/models/v1_validation.rb', line 239

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/kubernetes/models/v1_validation.rb', line 145

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


125
126
127
# File 'lib/kubernetes/models/v1_validation.rb', line 125

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



131
132
133
# File 'lib/kubernetes/models/v1_validation.rb', line 131

def hash
  [expression, message, message_expression, reason].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
100
101
102
103
# File 'lib/kubernetes/models/v1_validation.rb', line 96

def list_invalid_properties
  invalid_properties = Array.new
  if @expression.nil?
    invalid_properties.push('invalid value for "expression", expression cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
# File 'lib/kubernetes/models/v1_validation.rb', line 215

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/kubernetes/models/v1_validation.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



209
210
211
# File 'lib/kubernetes/models/v1_validation.rb', line 209

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



107
108
109
110
# File 'lib/kubernetes/models/v1_validation.rb', line 107

def valid?
  return false if @expression.nil?
  true
end