Class: Kubernetes::V1ValidationRule

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1_validation_rule.rb

Overview

ValidationRule describes a validation rule written in the CEL expression language.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1ValidationRule

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ValidationRule` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ValidationRule`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'field_path')
    self.field_path = attributes[:'field_path']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'message_expression')
    self.message_expression = attributes[:'message_expression']
  end

  if attributes.key?(:'optional_old_self')
    self.optional_old_self = attributes[:'optional_old_self']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end

  if attributes.key?(:'rule')
    self.rule = attributes[:'rule']
  end
end

Instance Attribute Details

#field_pathObject

fieldPath represents the field path returned when the validation fails. It must be a relative JSON path (i.e. with array notation) scoped to the location of this x-kubernetes-validations extension in the schema and refer to an existing field. e.g. when validation checks if a specific attribute ‘foo` under a map `testMap`, the fieldPath could be set to `.testMap.foo` If the validation checks two lists must have unique attributes, the fieldPath could be set to either of the list: e.g. `.testList` It does not support list numeric index. It supports child operation to refer to an existing field currently. Refer to [JSONPath support in Kubernetes](kubernetes.io/docs/reference/kubectl/jsonpath/) for more info. Numeric index of array is not supported. For field name which contains special characters, use `[’specialName’]‘ to refer the field name. e.g. for attribute `foo.34$` appears in a list `testList`, the fieldPath could be set to `.testList`



20
21
22
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 20

def field_path
  @field_path
end

#messageObject

Message represents the message displayed when validation fails. The message is required if the Rule contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: Rule". e.g. "must be a URL with the host matching spec.host"



23
24
25
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 23

def message
  @message
end

#message_expressionObject

MessageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a rule, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the rule; the only difference is the return type. Example: "x must be less than max ("+string(self.max)+")"



26
27
28
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 26

def message_expression
  @message_expression
end

#optional_old_selfObject

optionalOldSelf is used to opt a transition rule into evaluation even when the object is first created, or if the old object is missing the value. When enabled ‘oldSelf` will be a CEL optional whose value will be `None` if there is no old value, or when the object is initially created. You may check for presence of oldSelf using `oldSelf.hasValue()` and unwrap it after checking using `oldSelf.value()`. Check the CEL documentation for Optional types for more information: pkg.go.dev/github.com/google/cel-go/cel#OptionalTypes May not be set unless `oldSelf` is used in `rule`.



29
30
31
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 29

def optional_old_self
  @optional_old_self
end

#reasonObject

reason provides a machine-readable validation failure reason that is returned to the caller when a request fails this validation rule. The HTTP status code returned to the caller will match the reason of the reason of the first failed validation rule. The currently supported reasons are: "FieldValueInvalid", "FieldValueForbidden", "FieldValueRequired", "FieldValueDuplicate". If not set, default to use "FieldValueInvalid". All future added reasons must be accepted by clients when reading this value and unknown reasons should be treated as FieldValueInvalid.



32
33
34
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 32

def reason
  @reason
end

#ruleObject

Rule represents the expression which will be evaluated by CEL. ref: github.com/google/cel-spec The Rule is scoped to the location of the x-kubernetes-validations extension in the schema. The ‘self` variable in the CEL expression is bound to the scoped value. Example: - Rule scoped to the root of a resource with a status subresource: "self.status.actual <= self.spec.maxDesired" If the Rule is scoped to an object with properties, the accessible properties of the object are field selectable via `self.field` and field presence can be checked via `has(self.field)`. Null valued fields are treated as absent fields in CEL expressions. If the Rule is scoped to an object with additionalProperties (i.e. a map) the value of the map are accessible via `self`, map containment can be checked via `mapKey in self` and all entries of the map are accessible via CEL macros and functions such as `self.all(…)`. If the Rule is scoped to an array, the elements of the array are accessible via `self` and also by macros and functions. If the Rule is scoped to a scalar, `self` is bound to the scalar value. Examples: - Rule scoped to a map of objects: "self.components.priority < 10" - Rule scoped to a list of integers: "self.values.all(value, value >= 0 && value < 100)" - Rule scoped to a string value: "self.startsWith(’kube’)" The ‘apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object and from any x-kubernetes-embedded-resource annotated objects. No other metadata properties are accessible. Unknown data preserved in custom resources via x-kubernetes-preserve-unknown-fields is not accessible in CEL expressions. This includes: - Unknown field values that are preserved by object schemas with x-kubernetes-preserve-unknown-fields. - Object properties where the property schema is of an "unknown type". An "unknown type" is recursively defined as: - A schema with no type and x-kubernetes-preserve-unknown-fields set to true - An array where the items schema is of an "unknown type" - An object where the additionalProperties schema is of an "unknown type" Only property names of the form `[a-zA-Z_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - ’__’ escapes to ‘__underscores__’ - ‘.’ escapes to ‘__dot__’ - ‘-’ escapes to ‘__dash__’ - ‘/’ escapes to ‘__slash__’ - Property names that exactly match a CEL RESERVED keyword escape to ‘__keyword__’. The keywords are: "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if", "import", "let", "loop", "package", "namespace", "return". Examples: - Rule accessing a property named "namespace": "self.__namespace__ > 0" - Rule accessing a property named "x-prop": "self.x__dash__prop > 0" - Rule accessing a property named "redact__d": "self.redact__underscores__d > 0" Equality on arrays with x-kubernetes-list-type of ‘set’ or ‘map’ ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type: - ‘set’: ‘X + Y` performs a union where the array positions of all elements in `X` are preserved and non-intersecting elements in `Y` are appended, retaining their partial order. - ’map’: ‘X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with non-intersecting keys are appended, retaining their partial order. If `rule` makes use of the `oldSelf` variable it is implicitly a `transition rule`. By default, the `oldSelf` variable is the same type as `self`. When `optionalOldSelf` is true, the `oldSelf` variable is a CEL optional variable whose value() is the same type as `self`. See the documentation for the `optionalOldSelf` field for details. Transition rules by default are applied only on UPDATE requests and are skipped if an old value could not be found. You can opt a transition rule into unconditional evaluation by setting `optionalOldSelf` to true.



35
36
37
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 35

def rule
  @rule
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 50

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 38

def self.attribute_map
  {
    :'field_path' => :'fieldPath',
    :'message' => :'message',
    :'message_expression' => :'messageExpression',
    :'optional_old_self' => :'optionalOldSelf',
    :'reason' => :'reason',
    :'rule' => :'rule'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 158

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 55

def self.openapi_types
  {
    :'field_path' => :'String',
    :'message' => :'String',
    :'message_expression' => :'String',
    :'optional_old_self' => :'Boolean',
    :'reason' => :'String',
    :'rule' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



132
133
134
135
136
137
138
139
140
141
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 132

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      field_path == o.field_path &&
      message == o.message &&
      message_expression == o.message_expression &&
      optional_old_self == o.optional_old_self &&
      reason == o.reason &&
      rule == o.rule
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 188

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 259

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 165

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 145

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 151

def hash
  [field_path, message, message_expression, optional_old_self, reason, rule].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 114

def list_invalid_properties
  invalid_properties = Array.new
  if @rule.nil?
    invalid_properties.push('invalid value for "rule", rule cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 235

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



229
230
231
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 229

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
# File 'lib/kubernetes/models/v1_validation_rule.rb', line 125

def valid?
  return false if @rule.nil?
  true
end