Class: Kubernetes::V1VolumeMount
- Inherits:
-
Object
- Object
- Kubernetes::V1VolumeMount
- Defined in:
- lib/kubernetes/models/v1_volume_mount.rb
Overview
VolumeMount describes a mounting of a Volume within a container.
Instance Attribute Summary collapse
-
#mount_path ⇒ Object
Path within the container at which the volume should be mounted.
-
#mount_propagation ⇒ Object
mountPropagation determines how mounts are propagated from the host to container and the other way around.
-
#name ⇒ Object
This must match the Name of a Volume.
-
#read_only ⇒ Object
Mounted read-only if true, read-write otherwise (false or unspecified).
-
#recursive_read_only ⇒ Object
RecursiveReadOnly specifies whether read-only mounts should be handled recursively.
-
#sub_path ⇒ Object
Path within the volume from which the container’s volume should be mounted.
-
#sub_path_expr ⇒ Object
Expanded path within the volume from which the container’s volume should be mounted.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1VolumeMount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1VolumeMount
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1VolumeMount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1VolumeMount`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'mount_path') self.mount_path = attributes[:'mount_path'] end if attributes.key?(:'mount_propagation') self.mount_propagation = attributes[:'mount_propagation'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'read_only') self.read_only = attributes[:'read_only'] end if attributes.key?(:'recursive_read_only') self.recursive_read_only = attributes[:'recursive_read_only'] end if attributes.key?(:'sub_path') self.sub_path = attributes[:'sub_path'] end if attributes.key?(:'sub_path_expr') self.sub_path_expr = attributes[:'sub_path_expr'] end end |
Instance Attribute Details
#mount_path ⇒ Object
Path within the container at which the volume should be mounted. Must not contain ‘:’.
20 21 22 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 20 def mount_path @mount_path end |
#mount_propagation ⇒ Object
mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10. When RecursiveReadOnly is set to IfPossible or to Enabled, MountPropagation must be None or unspecified (which defaults to None).
23 24 25 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 23 def mount_propagation @mount_propagation end |
#name ⇒ Object
This must match the Name of a Volume.
26 27 28 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 26 def name @name end |
#read_only ⇒ Object
Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false.
29 30 31 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 29 def read_only @read_only end |
#recursive_read_only ⇒ Object
RecursiveReadOnly specifies whether read-only mounts should be handled recursively. If ReadOnly is false, this field has no meaning and must be unspecified. If ReadOnly is true, and this field is set to Disabled, the mount is not made recursively read-only. If this field is set to IfPossible, the mount is made recursively read-only, if it is supported by the container runtime. If this field is set to Enabled, the mount is made recursively read-only if it is supported by the container runtime, otherwise the pod will not be started and an error will be generated to indicate the reason. If this field is set to IfPossible or Enabled, MountPropagation must be set to None (or be unspecified, which defaults to None). If this field is not specified, it is treated as an equivalent of Disabled.
32 33 34 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 32 def recursive_read_only @recursive_read_only end |
#sub_path ⇒ Object
Path within the volume from which the container’s volume should be mounted. Defaults to "" (volume’s root).
35 36 37 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 35 def sub_path @sub_path end |
#sub_path_expr ⇒ Object
Expanded path within the volume from which the container’s volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container’s environment. Defaults to "" (volume’s root). SubPathExpr and SubPath are mutually exclusive.
38 39 40 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 38 def sub_path_expr @sub_path_expr end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 54 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 41 def self.attribute_map { :'mount_path' => :'mountPath', :'mount_propagation' => :'mountPropagation', :'name' => :'name', :'read_only' => :'readOnly', :'recursive_read_only' => :'recursiveReadOnly', :'sub_path' => :'subPath', :'sub_path_expr' => :'subPathExpr' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 173 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 59 def self.openapi_types { :'mount_path' => :'String', :'mount_propagation' => :'String', :'name' => :'String', :'read_only' => :'Boolean', :'recursive_read_only' => :'String', :'sub_path' => :'String', :'sub_path_expr' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 146 def ==(o) return true if self.equal?(o) self.class == o.class && mount_path == o.mount_path && mount_propagation == o.mount_propagation && name == o.name && read_only == o.read_only && recursive_read_only == o.recursive_read_only && sub_path == o.sub_path && sub_path_expr == o.sub_path_expr end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 203 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 274 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 180 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 166 def hash [mount_path, mount_propagation, name, read_only, recursive_read_only, sub_path, sub_path_expr].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 123 def list_invalid_properties invalid_properties = Array.new if @mount_path.nil? invalid_properties.push('invalid value for "mount_path", mount_path cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
250 251 252 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 250 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 256 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
244 245 246 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 244 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 |
# File 'lib/kubernetes/models/v1_volume_mount.rb', line 138 def valid? return false if @mount_path.nil? return false if @name.nil? true end |