Class: Kubernetes::V1alpha2PodGroupSpec
- Inherits:
-
Object
- Object
- Kubernetes::V1alpha2PodGroupSpec
- Defined in:
- lib/kubernetes/models/v1alpha2_pod_group_spec.rb
Overview
PodGroupSpec defines the desired state of a PodGroup.
Instance Attribute Summary collapse
-
#disruption_mode ⇒ Object
DisruptionMode defines the mode in which a given PodGroup can be disrupted.
-
#pod_group_template_ref ⇒ Object
Returns the value of attribute pod_group_template_ref.
-
#priority ⇒ Object
Priority is the value of priority of this pod group.
-
#priority_class_name ⇒ Object
PriorityClassName defines the priority that should be considered when scheduling this pod group.
-
#resource_claims ⇒ Object
ResourceClaims defines which ResourceClaims may be shared among Pods in the group.
-
#scheduling_constraints ⇒ Object
Returns the value of attribute scheduling_constraints.
-
#scheduling_policy ⇒ Object
Returns the value of attribute scheduling_policy.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1alpha2PodGroupSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1alpha2PodGroupSpec
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1alpha2PodGroupSpec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1alpha2PodGroupSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'disruption_mode') self.disruption_mode = attributes[:'disruption_mode'] end if attributes.key?(:'pod_group_template_ref') self.pod_group_template_ref = attributes[:'pod_group_template_ref'] end if attributes.key?(:'priority') self.priority = attributes[:'priority'] end if attributes.key?(:'priority_class_name') self.priority_class_name = attributes[:'priority_class_name'] end if attributes.key?(:'resource_claims') if (value = attributes[:'resource_claims']).is_a?(Array) self.resource_claims = value end end if attributes.key?(:'scheduling_constraints') self.scheduling_constraints = attributes[:'scheduling_constraints'] end if attributes.key?(:'scheduling_policy') self.scheduling_policy = attributes[:'scheduling_policy'] end end |
Instance Attribute Details
#disruption_mode ⇒ Object
DisruptionMode defines the mode in which a given PodGroup can be disrupted. Controllers are expected to fill this field by copying it from a PodGroupTemplate. One of Pod, PodGroup. Defaults to Pod if unset. This field is immutable. This field is available only when the WorkloadAwarePreemption feature gate is enabled.
20 21 22 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 20 def disruption_mode @disruption_mode end |
#pod_group_template_ref ⇒ Object
Returns the value of attribute pod_group_template_ref.
22 23 24 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 22 def pod_group_template_ref @pod_group_template_ref end |
#priority ⇒ Object
Priority is the value of priority of this pod group. Various system components use this field to find the priority of the pod group. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority. This field is immutable. This field is available only when the WorkloadAwarePreemption feature gate is enabled.
25 26 27 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 25 def priority @priority end |
#priority_class_name ⇒ Object
PriorityClassName defines the priority that should be considered when scheduling this pod group. Controllers are expected to fill this field by copying it from a PodGroupTemplate. Otherwise, it is validated and resolved similarly to the PriorityClassName on PodGroupTemplate (i.e. if no priority class is specified, admission control can set this to the global default priority class if it exists. Otherwise, the pod group’s priority will be zero). This field is immutable. This field is available only when the WorkloadAwarePreemption feature gate is enabled.
28 29 30 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 28 def priority_class_name @priority_class_name end |
#resource_claims ⇒ Object
ResourceClaims defines which ResourceClaims may be shared among Pods in the group. Pods consume the devices allocated to a PodGroup’s claim by defining a claim in its own Spec.ResourceClaims that matches the PodGroup’s claim exactly. The claim must have the same name and refer to the same ResourceClaim or ResourceClaimTemplate. This is an alpha-level field and requires that the DRAWorkloadResourceClaims feature gate is enabled. This field is immutable.
31 32 33 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 31 def resource_claims @resource_claims end |
#scheduling_constraints ⇒ Object
Returns the value of attribute scheduling_constraints.
33 34 35 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 33 def scheduling_constraints @scheduling_constraints end |
#scheduling_policy ⇒ Object
Returns the value of attribute scheduling_policy.
35 36 37 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 35 def scheduling_policy @scheduling_policy end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 51 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 38 def self.attribute_map { :'disruption_mode' => :'disruptionMode', :'pod_group_template_ref' => :'podGroupTemplateRef', :'priority' => :'priority', :'priority_class_name' => :'priorityClassName', :'resource_claims' => :'resourceClaims', :'scheduling_constraints' => :'schedulingConstraints', :'scheduling_policy' => :'schedulingPolicy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 167 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 56 def self.openapi_types { :'disruption_mode' => :'String', :'pod_group_template_ref' => :'V1alpha2PodGroupTemplateReference', :'priority' => :'Integer', :'priority_class_name' => :'String', :'resource_claims' => :'Array<V1alpha2PodGroupResourceClaim>', :'scheduling_constraints' => :'V1alpha2PodGroupSchedulingConstraints', :'scheduling_policy' => :'V1alpha2PodGroupSchedulingPolicy' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && disruption_mode == o.disruption_mode && pod_group_template_ref == o.pod_group_template_ref && priority == o.priority && priority_class_name == o.priority_class_name && resource_claims == o.resource_claims && scheduling_constraints == o.scheduling_constraints && scheduling_policy == o.scheduling_policy end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 197 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 268 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 174 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 160 def hash [disruption_mode, pod_group_template_ref, priority, priority_class_name, resource_claims, scheduling_constraints, scheduling_policy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
122 123 124 125 126 127 128 129 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 122 def list_invalid_properties invalid_properties = Array.new if @scheduling_policy.nil? invalid_properties.push('invalid value for "scheduling_policy", scheduling_policy cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
244 245 246 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 244 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
238 239 240 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 238 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 |
# File 'lib/kubernetes/models/v1alpha2_pod_group_spec.rb', line 133 def valid? return false if @scheduling_policy.nil? true end |