Class: Kubernetes::V1alpha2PodGroupTemplate

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1alpha2_pod_group_template.rb

Overview

PodGroupTemplate represents a template for a set of pods with a scheduling policy.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1alpha2PodGroupTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1alpha2PodGroupTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1alpha2PodGroupTemplate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'disruption_mode')
    self.disruption_mode = attributes[:'disruption_mode']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'priority_class_name')
    self.priority_class_name = attributes[:'priority_class_name']
  end

  if attributes.key?(:'resource_claims')
    if (value = attributes[:'resource_claims']).is_a?(Array)
      self.resource_claims = value
    end
  end

  if attributes.key?(:'scheduling_constraints')
    self.scheduling_constraints = attributes[:'scheduling_constraints']
  end

  if attributes.key?(:'scheduling_policy')
    self.scheduling_policy = attributes[:'scheduling_policy']
  end
end

Instance Attribute Details

#disruption_modeObject

DisruptionMode defines the mode in which a given PodGroup can be disrupted. One of Pod, PodGroup. This field is available only when the WorkloadAwarePreemption feature gate is enabled.



20
21
22
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 20

def disruption_mode
  @disruption_mode
end

#nameObject

Name is a unique identifier for the PodGroupTemplate within the Workload. It must be a DNS label. This field is immutable.



23
24
25
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 23

def name
  @name
end

#priorityObject

Priority is the value of priority of pod groups created from this template. Various system components use this field to find the priority of the pod group. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority. This field is available only when the WorkloadAwarePreemption feature gate is enabled.



26
27
28
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 26

def priority
  @priority
end

#priority_class_nameObject

PriorityClassName indicates the priority that should be considered when scheduling a pod group created from this template. If no priority class is specified, admission control can set this to the global default priority class if it exists. Otherwise, pod groups created from this template will have the priority set to zero. This field is available only when the WorkloadAwarePreemption feature gate is enabled.



29
30
31
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 29

def priority_class_name
  @priority_class_name
end

#resource_claimsObject

ResourceClaims defines which ResourceClaims may be shared among Pods in the group. Pods consume the devices allocated to a PodGroup’s claim by defining a claim in its own Spec.ResourceClaims that matches the PodGroup’s claim exactly. The claim must have the same name and refer to the same ResourceClaim or ResourceClaimTemplate. This is an alpha-level field and requires that the DRAWorkloadResourceClaims feature gate is enabled. This field is immutable.



32
33
34
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 32

def resource_claims
  @resource_claims
end

#scheduling_constraintsObject

Returns the value of attribute scheduling_constraints.



34
35
36
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 34

def scheduling_constraints
  @scheduling_constraints
end

#scheduling_policyObject

Returns the value of attribute scheduling_policy.



36
37
38
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 36

def scheduling_policy
  @scheduling_policy
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 52

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 39

def self.attribute_map
  {
    :'disruption_mode' => :'disruptionMode',
    :'name' => :'name',
    :'priority' => :'priority',
    :'priority_class_name' => :'priorityClassName',
    :'resource_claims' => :'resourceClaims',
    :'scheduling_constraints' => :'schedulingConstraints',
    :'scheduling_policy' => :'schedulingPolicy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 173

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 57

def self.openapi_types
  {
    :'disruption_mode' => :'String',
    :'name' => :'String',
    :'priority' => :'Integer',
    :'priority_class_name' => :'String',
    :'resource_claims' => :'Array<V1alpha2PodGroupResourceClaim>',
    :'scheduling_constraints' => :'V1alpha2PodGroupSchedulingConstraints',
    :'scheduling_policy' => :'V1alpha2PodGroupSchedulingPolicy'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      disruption_mode == o.disruption_mode &&
      name == o.name &&
      priority == o.priority &&
      priority_class_name == o.priority_class_name &&
      resource_claims == o.resource_claims &&
      scheduling_constraints == o.scheduling_constraints &&
      scheduling_policy == o.scheduling_policy
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 203

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 274

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 180

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 166

def hash
  [disruption_mode, name, priority, priority_class_name, resource_claims, scheduling_constraints, scheduling_policy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 123

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @scheduling_policy.nil?
    invalid_properties.push('invalid value for "scheduling_policy", scheduling_policy cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



250
251
252
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 250

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



244
245
246
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 244

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
# File 'lib/kubernetes/models/v1alpha2_pod_group_template.rb', line 138

def valid?
  return false if @name.nil?
  return false if @scheduling_policy.nil?
  true
end