Class: Kubernetes::V1beta1LeaseCandidateSpec

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1beta1_lease_candidate_spec.rb

Overview

LeaseCandidateSpec is a specification of a Lease.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1beta1LeaseCandidateSpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta1LeaseCandidateSpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta1LeaseCandidateSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'binary_version')
    self.binary_version = attributes[:'binary_version']
  end

  if attributes.key?(:'emulation_version')
    self.emulation_version = attributes[:'emulation_version']
  end

  if attributes.key?(:'lease_name')
    self.lease_name = attributes[:'lease_name']
  end

  if attributes.key?(:'ping_time')
    self.ping_time = attributes[:'ping_time']
  end

  if attributes.key?(:'renew_time')
    self.renew_time = attributes[:'renew_time']
  end

  if attributes.key?(:'strategy')
    self.strategy = attributes[:'strategy']
  end
end

Instance Attribute Details

#binary_versionObject

BinaryVersion is the binary version. It must be in a semver format without leading ‘v`. This field is required.



20
21
22
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 20

def binary_version
  @binary_version
end

#emulation_versionObject

EmulationVersion is the emulation version. It must be in a semver format without leading ‘v`. EmulationVersion must be less than or equal to BinaryVersion. This field is required when strategy is "OldestEmulationVersion"



23
24
25
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 23

def emulation_version
  @emulation_version
end

#lease_nameObject

LeaseName is the name of the lease for which this candidate is contending. The limits on this field are the same as on Lease.name. Multiple lease candidates may reference the same Lease.name. This field is immutable.



26
27
28
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 26

def lease_name
  @lease_name
end

#ping_timeObject

PingTime is the last time that the server has requested the LeaseCandidate to renew. It is only done during leader election to check if any LeaseCandidates have become ineligible. When PingTime is updated, the LeaseCandidate will respond by updating RenewTime.



29
30
31
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 29

def ping_time
  @ping_time
end

#renew_timeObject

RenewTime is the time that the LeaseCandidate was last updated. Any time a Lease needs to do leader election, the PingTime field is updated to signal to the LeaseCandidate that they should update the RenewTime. Old LeaseCandidate objects are also garbage collected if it has been hours since the last renew. The PingTime field is updated regularly to prevent garbage collection for still active LeaseCandidates.



32
33
34
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 32

def renew_time
  @renew_time
end

#strategyObject

Strategy is the strategy that coordinated leader election will use for picking the leader. If multiple candidates for the same Lease return different strategies, the strategy provided by the candidate with the latest BinaryVersion will be used. If there is still conflict, this is a user error and coordinated leader election will not operate the Lease until resolved.



35
36
37
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 35

def strategy
  @strategy
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 50

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 38

def self.attribute_map
  {
    :'binary_version' => :'binaryVersion',
    :'emulation_version' => :'emulationVersion',
    :'lease_name' => :'leaseName',
    :'ping_time' => :'pingTime',
    :'renew_time' => :'renewTime',
    :'strategy' => :'strategy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 168

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 55

def self.openapi_types
  {
    :'binary_version' => :'String',
    :'emulation_version' => :'String',
    :'lease_name' => :'String',
    :'ping_time' => :'Time',
    :'renew_time' => :'Time',
    :'strategy' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      binary_version == o.binary_version &&
      emulation_version == o.emulation_version &&
      lease_name == o.lease_name &&
      ping_time == o.ping_time &&
      renew_time == o.renew_time &&
      strategy == o.strategy
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 198

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 269

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 175

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 161

def hash
  [binary_version, emulation_version, lease_name, ping_time, renew_time, strategy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 114

def list_invalid_properties
  invalid_properties = Array.new
  if @binary_version.nil?
    invalid_properties.push('invalid value for "binary_version", binary_version cannot be nil.')
  end

  if @lease_name.nil?
    invalid_properties.push('invalid value for "lease_name", lease_name cannot be nil.')
  end

  if @strategy.nil?
    invalid_properties.push('invalid value for "strategy", strategy cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 245

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



239
240
241
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 239

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
# File 'lib/kubernetes/models/v1beta1_lease_candidate_spec.rb', line 133

def valid?
  return false if @binary_version.nil?
  return false if @lease_name.nil?
  return false if @strategy.nil?
  true
end