Class: Kubernetes::V1beta1MutatingAdmissionPolicySpec

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb

Overview

MutatingAdmissionPolicySpec is the specification of the desired behavior of the admission policy.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1beta1MutatingAdmissionPolicySpec

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta1MutatingAdmissionPolicySpec` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta1MutatingAdmissionPolicySpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'failure_policy')
    self.failure_policy = attributes[:'failure_policy']
  end

  if attributes.key?(:'match_conditions')
    if (value = attributes[:'match_conditions']).is_a?(Array)
      self.match_conditions = value
    end
  end

  if attributes.key?(:'match_constraints')
    self.match_constraints = attributes[:'match_constraints']
  end

  if attributes.key?(:'mutations')
    if (value = attributes[:'mutations']).is_a?(Array)
      self.mutations = value
    end
  end

  if attributes.key?(:'param_kind')
    self.param_kind = attributes[:'param_kind']
  end

  if attributes.key?(:'reinvocation_policy')
    self.reinvocation_policy = attributes[:'reinvocation_policy']
  end

  if attributes.key?(:'variables')
    if (value = attributes[:'variables']).is_a?(Array)
      self.variables = value
    end
  end
end

Instance Attribute Details

#failure_policyObject

failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings. A policy is invalid if paramKind refers to a non-existent Kind. A binding is invalid if paramRef.name refers to a non-existent resource. failurePolicy does not define how validations that evaluate to false are handled. Allowed values are Ignore or Fail. Defaults to Fail.



20
21
22
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 20

def failure_policy
  @failure_policy
end

#match_conditionsObject

matchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the matchConstraints. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed. If a parameter object is provided, it can be accessed via the ‘params` handle in the same manner as validation expressions. The exact matching logic is (in order): 1. If ANY matchCondition evaluates to FALSE, the policy is skipped. 2. If ALL matchConditions evaluate to TRUE, the policy is evaluated. 3. If any matchCondition evaluates to an error (but none are FALSE): - If failurePolicy=Fail, reject the request - If failurePolicy=Ignore, the policy is skipped



23
24
25
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 23

def match_conditions
  @match_conditions
end

#match_constraintsObject

Returns the value of attribute match_constraints.



25
26
27
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 25

def match_constraints
  @match_constraints
end

#mutationsObject

mutations contain operations to perform on matching objects. mutations may not be empty; a minimum of one mutation is required. mutations are evaluated in order, and are reinvoked according to the reinvocationPolicy. The mutations of a policy are invoked for each binding of this policy and reinvocation of mutations occurs on a per binding basis.



28
29
30
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 28

def mutations
  @mutations
end

#param_kindObject

Returns the value of attribute param_kind.



30
31
32
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 30

def param_kind
  @param_kind
end

#reinvocation_policyObject

reinvocationPolicy indicates whether mutations may be called multiple times per MutatingAdmissionPolicyBinding as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded". Never: These mutations will not be called more than once per binding in a single admission evaluation. IfNeeded: These mutations may be invoked more than once per binding for a single admission request and there is no guarantee of order with respect to other admission plugins, admission webhooks, bindings of this policy and admission policies. Mutations are only reinvoked when mutations change the object after this mutation is invoked. Required.



33
34
35
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 33

def reinvocation_policy
  @reinvocation_policy
end

#variablesObject

variables contain definitions of variables that can be used in composition of other expressions. Each variable is defined as a named CEL expression. The variables defined here will be available under ‘variables` in other expressions of the policy except matchConditions because matchConditions are evaluated before the rest of the policy. The expression of a variable can refer to other variables defined earlier in the list but not those after. Thus, variables must be sorted by the order of first appearance and acyclic.



36
37
38
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 36

def variables
  @variables
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 52

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 39

def self.attribute_map
  {
    :'failure_policy' => :'failurePolicy',
    :'match_conditions' => :'matchConditions',
    :'match_constraints' => :'matchConstraints',
    :'mutations' => :'mutations',
    :'param_kind' => :'paramKind',
    :'reinvocation_policy' => :'reinvocationPolicy',
    :'variables' => :'variables'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 167

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 57

def self.openapi_types
  {
    :'failure_policy' => :'String',
    :'match_conditions' => :'Array<V1beta1MatchCondition>',
    :'match_constraints' => :'V1beta1MatchResources',
    :'mutations' => :'Array<V1beta1Mutation>',
    :'param_kind' => :'V1beta1ParamKind',
    :'reinvocation_policy' => :'String',
    :'variables' => :'Array<V1beta1Variable>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



140
141
142
143
144
145
146
147
148
149
150
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      failure_policy == o.failure_policy &&
      match_conditions == o.match_conditions &&
      match_constraints == o.match_constraints &&
      mutations == o.mutations &&
      param_kind == o.param_kind &&
      reinvocation_policy == o.reinvocation_policy &&
      variables == o.variables
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 197

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 268

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 174

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 160

def hash
  [failure_policy, match_conditions, match_constraints, mutations, param_kind, reinvocation_policy, variables].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 127

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 244

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 250

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



238
239
240
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 238

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
# File 'lib/kubernetes/models/v1beta1_mutating_admission_policy_spec.rb', line 134

def valid?
  true
end