Class: Kubernetes::V1beta1PodCertificateRequestStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb

Overview

PodCertificateRequestStatus describes the status of the request, and holds the certificate data if the request is issued.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1beta1PodCertificateRequestStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta1PodCertificateRequestStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta1PodCertificateRequestStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'begin_refresh_at')
    self.begin_refresh_at = attributes[:'begin_refresh_at']
  end

  if attributes.key?(:'certificate_chain')
    self.certificate_chain = attributes[:'certificate_chain']
  end

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'not_after')
    self.not_after = attributes[:'not_after']
  end

  if attributes.key?(:'not_before')
    self.not_before = attributes[:'not_before']
  end
end

Instance Attribute Details

#begin_refresh_atObject

beginRefreshAt is the time at which the kubelet should begin trying to refresh the certificate. This field is set via the /status subresource, and must be set at the same time as certificateChain. Once populated, this field is immutable. This field is only a hint. Kubelet may start refreshing before or after this time if necessary.



20
21
22
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 20

def begin_refresh_at
  @begin_refresh_at
end

#certificate_chainObject

certificateChain is populated with an issued certificate by the signer. This field is set via the /status subresource. Once populated, this field is immutable. If the certificate signing request is denied, a condition of type "Denied" is added and this field remains empty. If the signer cannot issue the certificate, a condition of type "Failed" is added and this field remains empty. Validation requirements: 1. certificateChain must consist of one or more PEM-formatted certificates. 2. Each entry must be a valid PEM-wrapped, DER-encoded ASN.1 Certificate as described in section 4 of RFC5280. If more than one block is present, and the definition of the requested spec.signerName does not indicate otherwise, the first block is the issued certificate, and subsequent blocks should be treated as intermediate certificates and presented in TLS handshakes. When projecting the chain into a pod volume, kubelet will drop any data in-between the PEM blocks, as well as any PEM block headers.



23
24
25
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 23

def certificate_chain
  @certificate_chain
end

#conditionsObject

conditions applied to the request. The types "Issued", "Denied", and "Failed" have special handling. At most one of these conditions may be present, and they must have status "True". If the request is denied with ‘Reason=UnsupportedKeyType`, the signer may suggest a key type that will work in the message field.



26
27
28
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 26

def conditions
  @conditions
end

#not_afterObject

notAfter is the time at which the certificate expires. The value must be the same as the notAfter value in the leaf certificate in certificateChain. This field is set via the /status subresource. Once populated, it is immutable. The signer must set this field at the same time it sets certificateChain.



29
30
31
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 29

def not_after
  @not_after
end

#not_beforeObject

notBefore is the time at which the certificate becomes valid. The value must be the same as the notBefore value in the leaf certificate in certificateChain. This field is set via the /status subresource. Once populated, it is immutable. The signer must set this field at the same time it sets certificateChain.



32
33
34
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 32

def not_before
  @not_before
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 46

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 35

def self.attribute_map
  {
    :'begin_refresh_at' => :'beginRefreshAt',
    :'certificate_chain' => :'certificateChain',
    :'conditions' => :'conditions',
    :'not_after' => :'notAfter',
    :'not_before' => :'notBefore'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 145

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 51

def self.openapi_types
  {
    :'begin_refresh_at' => :'Time',
    :'certificate_chain' => :'String',
    :'conditions' => :'Array<V1Condition>',
    :'not_after' => :'Time',
    :'not_before' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



120
121
122
123
124
125
126
127
128
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 120

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      begin_refresh_at == o.begin_refresh_at &&
      certificate_chain == o.certificate_chain &&
      conditions == o.conditions &&
      not_after == o.not_after &&
      not_before == o.not_before
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 175

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 246

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 152

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 132

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



138
139
140
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 138

def hash
  [begin_refresh_at, certificate_chain, conditions, not_after, not_before].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 107

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 222

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



216
217
218
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 216

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



114
115
116
# File 'lib/kubernetes/models/v1beta1_pod_certificate_request_status.rb', line 114

def valid?
  true
end