Class: Kubernetes::V1beta1VolumeAttributesClass
- Inherits:
-
Object
- Object
- Kubernetes::V1beta1VolumeAttributesClass
- Defined in:
- lib/kubernetes/models/v1beta1_volume_attributes_class.rb
Overview
VolumeAttributesClass represents a specification of mutable volume attributes defined by the CSI driver. The class can be specified during dynamic provisioning of PersistentVolumeClaims, and changed in the PersistentVolumeClaim spec after provisioning.
Instance Attribute Summary collapse
-
#api_version ⇒ Object
APIVersion defines the versioned schema of this representation of an object.
-
#driver_name ⇒ Object
Name of the CSI driver This field is immutable.
-
#kind ⇒ Object
Kind is a string value representing the REST resource this object represents.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#parameters ⇒ Object
parameters hold volume attributes defined by the CSI driver.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1beta1VolumeAttributesClass
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1beta1VolumeAttributesClass
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta1VolumeAttributesClass` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta1VolumeAttributesClass`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'api_version') self.api_version = attributes[:'api_version'] end if attributes.key?(:'driver_name') self.driver_name = attributes[:'driver_name'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'parameters') if (value = attributes[:'parameters']).is_a?(Hash) self.parameters = value end end end |
Instance Attribute Details
#api_version ⇒ Object
APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
20 21 22 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 20 def api_version @api_version end |
#driver_name ⇒ Object
Name of the CSI driver This field is immutable.
23 24 25 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 23 def driver_name @driver_name end |
#kind ⇒ Object
Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
26 27 28 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 26 def kind @kind end |
#metadata ⇒ Object
Returns the value of attribute metadata.
28 29 30 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 28 def @metadata end |
#parameters ⇒ Object
parameters hold volume attributes defined by the CSI driver. These values are opaque to the Kubernetes and are passed directly to the CSI driver. The underlying storage provider supports changing these attributes on an existing volume, however the parameters field itself is immutable. To invoke a volume update, a new VolumeAttributesClass should be created with new parameters, and the PersistentVolumeClaim should be updated to reference the new VolumeAttributesClass. This field is required and must contain at least one key/value pair. The keys cannot be empty, and the maximum number of parameters is 512, with a cumulative max size of 256K. If the CSI driver rejects invalid parameters, the target PersistentVolumeClaim will be set to an "Infeasible" state in the modifyVolumeStatus field.
31 32 33 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 31 def parameters @parameters end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 45 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 34 def self.attribute_map { :'api_version' => :'apiVersion', :'driver_name' => :'driverName', :'kind' => :'kind', :'metadata' => :'metadata', :'parameters' => :'parameters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 149 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 50 def self.openapi_types { :'api_version' => :'String', :'driver_name' => :'String', :'kind' => :'String', :'metadata' => :'V1ObjectMeta', :'parameters' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 124 def ==(o) return true if self.equal?(o) self.class == o.class && api_version == o.api_version && driver_name == o.driver_name && kind == o.kind && == o. && parameters == o.parameters end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 179 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 250 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 156 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 142 def hash [api_version, driver_name, kind, , parameters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 106 def list_invalid_properties invalid_properties = Array.new if @driver_name.nil? invalid_properties.push('invalid value for "driver_name", driver_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
226 227 228 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 226 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
220 221 222 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 220 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 |
# File 'lib/kubernetes/models/v1beta1_volume_attributes_class.rb', line 117 def valid? return false if @driver_name.nil? true end |