Class: Kubernetes::V1beta2AllocatedDeviceStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/v1beta2_allocated_device_status.rb

Overview

AllocatedDeviceStatus contains the status of an allocated device, if the driver chooses to report it. This may include driver-specific information. The combination of Driver, Pool, Device, and ShareID must match the corresponding key in Status.Allocation.Devices.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ V1beta2AllocatedDeviceStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta2AllocatedDeviceStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta2AllocatedDeviceStatus`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'conditions')
    if (value = attributes[:'conditions']).is_a?(Array)
      self.conditions = value
    end
  end

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  end

  if attributes.key?(:'device')
    self.device = attributes[:'device']
  end

  if attributes.key?(:'driver')
    self.driver = attributes[:'driver']
  end

  if attributes.key?(:'network_data')
    self.network_data = attributes[:'network_data']
  end

  if attributes.key?(:'pool')
    self.pool = attributes[:'pool']
  end

  if attributes.key?(:'share_id')
    self.share_id = attributes[:'share_id']
  end
end

Instance Attribute Details

#conditionsObject

Conditions contains the latest observation of the device’s state. If the device has been configured according to the class and claim config references, the ‘Ready` condition should be True. Must not contain more than 8 entries.



20
21
22
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 20

def conditions
  @conditions
end

#dataObject

Data contains arbitrary driver-specific data. The length of the raw data must be smaller or equal to 10 Ki.



23
24
25
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 23

def data
  @data
end

#deviceObject

Device references one device instance via its name in the driver’s resource pool. It must be a DNS label.



26
27
28
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 26

def device
  @device
end

#driverObject

Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node. Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. It should use only lower case characters.



29
30
31
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 29

def driver
  @driver
end

#network_dataObject

Returns the value of attribute network_data.



31
32
33
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 31

def network_data
  @network_data
end

#poolObject

This name together with the driver name and the device name field identify which device was allocated (‘<driver name>/<pool name>/<device name>`). Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.



34
35
36
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 34

def pool
  @pool
end

#share_idObject

ShareID uniquely identifies an individual allocation share of the device.



37
38
39
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 37

def share_id
  @share_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 53

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 40

def self.attribute_map
  {
    :'conditions' => :'conditions',
    :'data' => :'data',
    :'device' => :'device',
    :'driver' => :'driver',
    :'network_data' => :'networkData',
    :'pool' => :'pool',
    :'share_id' => :'shareID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 179

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 58

def self.openapi_types
  {
    :'conditions' => :'Array<V1Condition>',
    :'data' => :'Object',
    :'device' => :'String',
    :'driver' => :'String',
    :'network_data' => :'V1beta2NetworkDeviceData',
    :'pool' => :'String',
    :'share_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
162
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      conditions == o.conditions &&
      data == o.data &&
      device == o.device &&
      driver == o.driver &&
      network_data == o.network_data &&
      pool == o.pool &&
      share_id == o.share_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 209

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 280

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 186

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 166

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



172
173
174
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 172

def hash
  [conditions, data, device, driver, network_data, pool, share_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 124

def list_invalid_properties
  invalid_properties = Array.new
  if @device.nil?
    invalid_properties.push('invalid value for "device", device cannot be nil.')
  end

  if @driver.nil?
    invalid_properties.push('invalid value for "driver", driver cannot be nil.')
  end

  if @pool.nil?
    invalid_properties.push('invalid value for "pool", pool cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 256

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



250
251
252
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 250

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
147
148
# File 'lib/kubernetes/models/v1beta2_allocated_device_status.rb', line 143

def valid?
  return false if @device.nil?
  return false if @driver.nil?
  return false if @pool.nil?
  true
end