Class: Kubernetes::V2HPAScalingRules
- Inherits:
-
Object
- Object
- Kubernetes::V2HPAScalingRules
- Defined in:
- lib/kubernetes/models/v2_hpa_scaling_rules.rb
Overview
HPAScalingRules configures the scaling behavior for one direction via scaling Policy Rules and a configurable metric tolerance. Scaling Policy Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen. The tolerance is applied to the metric values and prevents scaling too eagerly for small metric variations. (Note that setting a tolerance requires the beta HPAConfigurableTolerance feature gate to be enabled.)
Instance Attribute Summary collapse
-
#policies ⇒ Object
policies is a list of potential scaling polices which can be used during scaling.
-
#select_policy ⇒ Object
selectPolicy is used to specify which policy should be used.
-
#stabilization_window_seconds ⇒ Object
stabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down.
-
#tolerance ⇒ Object
tolerance is the tolerance on the ratio between the current and desired metric value under which no updates are made to the desired number of replicas (e.g. 0.01 for 1%).
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V2HPAScalingRules
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V2HPAScalingRules
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V2HPAScalingRules` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V2HPAScalingRules`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'policies') if (value = attributes[:'policies']).is_a?(Array) self.policies = value end end if attributes.key?(:'select_policy') self.select_policy = attributes[:'select_policy'] end if attributes.key?(:'stabilization_window_seconds') self.stabilization_window_seconds = attributes[:'stabilization_window_seconds'] end if attributes.key?(:'tolerance') self.tolerance = attributes[:'tolerance'] end end |
Instance Attribute Details
#policies ⇒ Object
policies is a list of potential scaling polices which can be used during scaling. If not set, use the default values: - For scale up: allow doubling the number of pods, or an absolute change of 4 pods in a 15s window. - For scale down: allow all pods to be removed in a 15s window.
20 21 22 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 20 def policies @policies end |
#select_policy ⇒ Object
selectPolicy is used to specify which policy should be used. If not set, the default value Max is used.
23 24 25 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 23 def select_policy @select_policy end |
#stabilization_window_seconds ⇒ Object
stabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long).
26 27 28 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 26 def stabilization_window_seconds @stabilization_window_seconds end |
#tolerance ⇒ Object
tolerance is the tolerance on the ratio between the current and desired metric value under which no updates are made to the desired number of replicas (e.g. 0.01 for 1%). Must be greater than or equal to zero. If not set, the default cluster-wide tolerance is applied (by default 10%). For example, if autoscaling is configured with a memory consumption target of 100Mi, and scale-down and scale-up tolerances of 5% and 1% respectively, scaling will be triggered when the actual consumption falls below 95Mi or exceeds 101Mi. This is an beta field and requires the HPAConfigurableTolerance feature gate to be enabled.
29 30 31 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 29 def tolerance @tolerance end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 42 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 32 def self.attribute_map { :'policies' => :'policies', :'select_policy' => :'selectPolicy', :'stabilization_window_seconds' => :'stabilizationWindowSeconds', :'tolerance' => :'tolerance' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
135 136 137 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 135 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 54 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 47 def self.openapi_types { :'policies' => :'Array<V2HPAScalingPolicy>', :'select_policy' => :'String', :'stabilization_window_seconds' => :'Integer', :'tolerance' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 111 def ==(o) return true if self.equal?(o) self.class == o.class && policies == o.policies && select_policy == o.select_policy && stabilization_window_seconds == o.stabilization_window_seconds && tolerance == o.tolerance end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 165 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 236 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 142 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
122 123 124 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 122 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 128 def hash [policies, select_policy, stabilization_window_seconds, tolerance].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
98 99 100 101 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 98 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
212 213 214 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 212 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
206 207 208 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 206 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
105 106 107 |
# File 'lib/kubernetes/models/v2_hpa_scaling_rules.rb', line 105 def valid? true end |