Class: Kubernetes::VersionInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/kubernetes/models/version_info.rb

Overview

Info contains versioning information. how we’ll want to distribute that information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ VersionInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/kubernetes/models/version_info.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::VersionInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::VersionInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'build_date')
    self.build_date = attributes[:'build_date']
  end

  if attributes.key?(:'compiler')
    self.compiler = attributes[:'compiler']
  end

  if attributes.key?(:'emulation_major')
    self.emulation_major = attributes[:'emulation_major']
  end

  if attributes.key?(:'emulation_minor')
    self.emulation_minor = attributes[:'emulation_minor']
  end

  if attributes.key?(:'git_commit')
    self.git_commit = attributes[:'git_commit']
  end

  if attributes.key?(:'git_tree_state')
    self.git_tree_state = attributes[:'git_tree_state']
  end

  if attributes.key?(:'git_version')
    self.git_version = attributes[:'git_version']
  end

  if attributes.key?(:'go_version')
    self.go_version = attributes[:'go_version']
  end

  if attributes.key?(:'major')
    self.major = attributes[:'major']
  end

  if attributes.key?(:'min_compatibility_major')
    self.min_compatibility_major = attributes[:'min_compatibility_major']
  end

  if attributes.key?(:'min_compatibility_minor')
    self.min_compatibility_minor = attributes[:'min_compatibility_minor']
  end

  if attributes.key?(:'minor')
    self.minor = attributes[:'minor']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end
end

Instance Attribute Details

#build_dateObject

Returns the value of attribute build_date.



19
20
21
# File 'lib/kubernetes/models/version_info.rb', line 19

def build_date
  @build_date
end

#compilerObject

Returns the value of attribute compiler.



21
22
23
# File 'lib/kubernetes/models/version_info.rb', line 21

def compiler
  @compiler
end

#emulation_majorObject

EmulationMajor is the major version of the emulation version



24
25
26
# File 'lib/kubernetes/models/version_info.rb', line 24

def emulation_major
  @emulation_major
end

#emulation_minorObject

EmulationMinor is the minor version of the emulation version



27
28
29
# File 'lib/kubernetes/models/version_info.rb', line 27

def emulation_minor
  @emulation_minor
end

#git_commitObject

Returns the value of attribute git_commit.



29
30
31
# File 'lib/kubernetes/models/version_info.rb', line 29

def git_commit
  @git_commit
end

#git_tree_stateObject

Returns the value of attribute git_tree_state.



31
32
33
# File 'lib/kubernetes/models/version_info.rb', line 31

def git_tree_state
  @git_tree_state
end

#git_versionObject

Returns the value of attribute git_version.



33
34
35
# File 'lib/kubernetes/models/version_info.rb', line 33

def git_version
  @git_version
end

#go_versionObject

Returns the value of attribute go_version.



35
36
37
# File 'lib/kubernetes/models/version_info.rb', line 35

def go_version
  @go_version
end

#majorObject

Major is the major version of the binary version



38
39
40
# File 'lib/kubernetes/models/version_info.rb', line 38

def major
  @major
end

#min_compatibility_majorObject

MinCompatibilityMajor is the major version of the minimum compatibility version



41
42
43
# File 'lib/kubernetes/models/version_info.rb', line 41

def min_compatibility_major
  @min_compatibility_major
end

#min_compatibility_minorObject

MinCompatibilityMinor is the minor version of the minimum compatibility version



44
45
46
# File 'lib/kubernetes/models/version_info.rb', line 44

def min_compatibility_minor
  @min_compatibility_minor
end

#minorObject

Minor is the minor version of the binary version



47
48
49
# File 'lib/kubernetes/models/version_info.rb', line 47

def minor
  @minor
end

#platformObject

Returns the value of attribute platform.



49
50
51
# File 'lib/kubernetes/models/version_info.rb', line 49

def platform
  @platform
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/kubernetes/models/version_info.rb', line 71

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/kubernetes/models/version_info.rb', line 52

def self.attribute_map
  {
    :'build_date' => :'buildDate',
    :'compiler' => :'compiler',
    :'emulation_major' => :'emulationMajor',
    :'emulation_minor' => :'emulationMinor',
    :'git_commit' => :'gitCommit',
    :'git_tree_state' => :'gitTreeState',
    :'git_version' => :'gitVersion',
    :'go_version' => :'goVersion',
    :'major' => :'major',
    :'min_compatibility_major' => :'minCompatibilityMajor',
    :'min_compatibility_minor' => :'minCompatibilityMinor',
    :'minor' => :'minor',
    :'platform' => :'platform'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
# File 'lib/kubernetes/models/version_info.rb', line 261

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/kubernetes/models/version_info.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/kubernetes/models/version_info.rb', line 76

def self.openapi_types
  {
    :'build_date' => :'String',
    :'compiler' => :'String',
    :'emulation_major' => :'String',
    :'emulation_minor' => :'String',
    :'git_commit' => :'String',
    :'git_tree_state' => :'String',
    :'git_version' => :'String',
    :'go_version' => :'String',
    :'major' => :'String',
    :'min_compatibility_major' => :'String',
    :'min_compatibility_minor' => :'String',
    :'minor' => :'String',
    :'platform' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/kubernetes/models/version_info.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      build_date == o.build_date &&
      compiler == o.compiler &&
      emulation_major == o.emulation_major &&
      emulation_minor == o.emulation_minor &&
      git_commit == o.git_commit &&
      git_tree_state == o.git_tree_state &&
      git_version == o.git_version &&
      go_version == o.go_version &&
      major == o.major &&
      min_compatibility_major == o.min_compatibility_major &&
      min_compatibility_minor == o.min_compatibility_minor &&
      minor == o.minor &&
      platform == o.platform
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/kubernetes/models/version_info.rb', line 291

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Kubernetes.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/kubernetes/models/version_info.rb', line 362

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/kubernetes/models/version_info.rb', line 268

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


248
249
250
# File 'lib/kubernetes/models/version_info.rb', line 248

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



254
255
256
# File 'lib/kubernetes/models/version_info.rb', line 254

def hash
  [build_date, compiler, emulation_major, emulation_minor, git_commit, git_tree_state, git_version, go_version, major, min_compatibility_major, min_compatibility_minor, minor, platform].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/kubernetes/models/version_info.rb', line 170

def list_invalid_properties
  invalid_properties = Array.new
  if @build_date.nil?
    invalid_properties.push('invalid value for "build_date", build_date cannot be nil.')
  end

  if @compiler.nil?
    invalid_properties.push('invalid value for "compiler", compiler cannot be nil.')
  end

  if @git_commit.nil?
    invalid_properties.push('invalid value for "git_commit", git_commit cannot be nil.')
  end

  if @git_tree_state.nil?
    invalid_properties.push('invalid value for "git_tree_state", git_tree_state cannot be nil.')
  end

  if @git_version.nil?
    invalid_properties.push('invalid value for "git_version", git_version cannot be nil.')
  end

  if @go_version.nil?
    invalid_properties.push('invalid value for "go_version", go_version cannot be nil.')
  end

  if @major.nil?
    invalid_properties.push('invalid value for "major", major cannot be nil.')
  end

  if @minor.nil?
    invalid_properties.push('invalid value for "minor", minor cannot be nil.')
  end

  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



338
339
340
# File 'lib/kubernetes/models/version_info.rb', line 338

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/kubernetes/models/version_info.rb', line 344

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



332
333
334
# File 'lib/kubernetes/models/version_info.rb', line 332

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/kubernetes/models/version_info.rb', line 213

def valid?
  return false if @build_date.nil?
  return false if @compiler.nil?
  return false if @git_commit.nil?
  return false if @git_tree_state.nil?
  return false if @git_version.nil?
  return false if @go_version.nil?
  return false if @major.nil?
  return false if @minor.nil?
  return false if @platform.nil?
  true
end