Class: Kubernetes::V1Container
- Inherits:
-
Object
- Object
- Kubernetes::V1Container
- Defined in:
- lib/kubernetes/models/v1_container.rb
Overview
A single application container that you want to run within a pod.
Instance Attribute Summary collapse
-
#args ⇒ Object
Arguments to the entrypoint.
-
#command ⇒ Object
Entrypoint array.
-
#env ⇒ Object
List of environment variables to set in the container.
-
#env_from ⇒ Object
List of sources to populate environment variables in the container.
-
#image ⇒ Object
Container image name.
-
#image_pull_policy ⇒ Object
Image pull policy.
-
#lifecycle ⇒ Object
Returns the value of attribute lifecycle.
-
#liveness_probe ⇒ Object
Returns the value of attribute liveness_probe.
-
#name ⇒ Object
Name of the container specified as a DNS_LABEL.
-
#ports ⇒ Object
List of ports to expose from the container.
-
#readiness_probe ⇒ Object
Returns the value of attribute readiness_probe.
-
#resize_policy ⇒ Object
Resources resize policy for the container.
-
#resources ⇒ Object
Returns the value of attribute resources.
-
#restart_policy ⇒ Object
RestartPolicy defines the restart behavior of individual containers in a pod.
-
#restart_policy_rules ⇒ Object
Represents a list of rules to be checked to determine if the container should be restarted on exit.
-
#security_context ⇒ Object
Returns the value of attribute security_context.
-
#startup_probe ⇒ Object
Returns the value of attribute startup_probe.
-
#stdin ⇒ Object
Whether this container should allocate a buffer for stdin in the container runtime.
-
#stdin_once ⇒ Object
Whether the container runtime should close the stdin channel after it has been opened by a single attach.
-
#termination_message_path ⇒ Object
Optional: Path at which the file to which the container’s termination message will be written is mounted into the container’s filesystem.
-
#termination_message_policy ⇒ Object
Indicate how the termination message should be populated.
-
#tty ⇒ Object
Whether this container should allocate a TTY for itself, also requires ‘stdin’ to be true.
-
#volume_devices ⇒ Object
volumeDevices is the list of block devices to be used by the container.
-
#volume_mounts ⇒ Object
Pod volumes to mount into the container’s filesystem.
-
#working_dir ⇒ Object
Container’s working directory.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1Container
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1Container
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/kubernetes/models/v1_container.rb', line 163 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1Container` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1Container`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'args') if (value = attributes[:'args']).is_a?(Array) self.args = value end end if attributes.key?(:'command') if (value = attributes[:'command']).is_a?(Array) self.command = value end end if attributes.key?(:'env') if (value = attributes[:'env']).is_a?(Array) self.env = value end end if attributes.key?(:'env_from') if (value = attributes[:'env_from']).is_a?(Array) self.env_from = value end end if attributes.key?(:'image') self.image = attributes[:'image'] end if attributes.key?(:'image_pull_policy') self.image_pull_policy = attributes[:'image_pull_policy'] end if attributes.key?(:'lifecycle') self.lifecycle = attributes[:'lifecycle'] end if attributes.key?(:'liveness_probe') self.liveness_probe = attributes[:'liveness_probe'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'ports') if (value = attributes[:'ports']).is_a?(Array) self.ports = value end end if attributes.key?(:'readiness_probe') self.readiness_probe = attributes[:'readiness_probe'] end if attributes.key?(:'resize_policy') if (value = attributes[:'resize_policy']).is_a?(Array) self.resize_policy = value end end if attributes.key?(:'resources') self.resources = attributes[:'resources'] end if attributes.key?(:'restart_policy') self.restart_policy = attributes[:'restart_policy'] end if attributes.key?(:'restart_policy_rules') if (value = attributes[:'restart_policy_rules']).is_a?(Array) self.restart_policy_rules = value end end if attributes.key?(:'security_context') self.security_context = attributes[:'security_context'] end if attributes.key?(:'startup_probe') self.startup_probe = attributes[:'startup_probe'] end if attributes.key?(:'stdin') self.stdin = attributes[:'stdin'] end if attributes.key?(:'stdin_once') self.stdin_once = attributes[:'stdin_once'] end if attributes.key?(:'termination_message_path') self. = attributes[:'termination_message_path'] end if attributes.key?(:'termination_message_policy') self. = attributes[:'termination_message_policy'] end if attributes.key?(:'tty') self.tty = attributes[:'tty'] end if attributes.key?(:'volume_devices') if (value = attributes[:'volume_devices']).is_a?(Array) self.volume_devices = value end end if attributes.key?(:'volume_mounts') if (value = attributes[:'volume_mounts']).is_a?(Array) self.volume_mounts = value end end if attributes.key?(:'working_dir') self.working_dir = attributes[:'working_dir'] end end |
Instance Attribute Details
#args ⇒ Object
Arguments to the entrypoint. The container image’s CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container’s environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
20 21 22 |
# File 'lib/kubernetes/models/v1_container.rb', line 20 def args @args end |
#command ⇒ Object
Entrypoint array. Not executed within a shell. The container image’s ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container’s environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell
23 24 25 |
# File 'lib/kubernetes/models/v1_container.rb', line 23 def command @command end |
#env ⇒ Object
List of environment variables to set in the container. Cannot be updated.
26 27 28 |
# File 'lib/kubernetes/models/v1_container.rb', line 26 def env @env end |
#env_from ⇒ Object
List of sources to populate environment variables in the container. The keys defined within a source may consist of any printable ASCII characters except ‘=’. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.
29 30 31 |
# File 'lib/kubernetes/models/v1_container.rb', line 29 def env_from @env_from end |
#image ⇒ Object
Container image name. More info: kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets.
32 33 34 |
# File 'lib/kubernetes/models/v1_container.rb', line 32 def image @image end |
#image_pull_policy ⇒ Object
Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: kubernetes.io/docs/concepts/containers/images#updating-images
35 36 37 |
# File 'lib/kubernetes/models/v1_container.rb', line 35 def image_pull_policy @image_pull_policy end |
#lifecycle ⇒ Object
Returns the value of attribute lifecycle.
37 38 39 |
# File 'lib/kubernetes/models/v1_container.rb', line 37 def lifecycle @lifecycle end |
#liveness_probe ⇒ Object
Returns the value of attribute liveness_probe.
39 40 41 |
# File 'lib/kubernetes/models/v1_container.rb', line 39 def liveness_probe @liveness_probe end |
#name ⇒ Object
Name of the container specified as a DNS_LABEL. Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated.
42 43 44 |
# File 'lib/kubernetes/models/v1_container.rb', line 42 def name @name end |
#ports ⇒ Object
List of ports to expose from the container. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Modifying this array with strategic merge patch may corrupt the data. For more information See github.com/kubernetes/kubernetes/issues/108255. Cannot be updated.
45 46 47 |
# File 'lib/kubernetes/models/v1_container.rb', line 45 def ports @ports end |
#readiness_probe ⇒ Object
Returns the value of attribute readiness_probe.
47 48 49 |
# File 'lib/kubernetes/models/v1_container.rb', line 47 def readiness_probe @readiness_probe end |
#resize_policy ⇒ Object
Resources resize policy for the container. This field cannot be set on ephemeral containers.
50 51 52 |
# File 'lib/kubernetes/models/v1_container.rb', line 50 def resize_policy @resize_policy end |
#resources ⇒ Object
Returns the value of attribute resources.
52 53 54 |
# File 'lib/kubernetes/models/v1_container.rb', line 52 def resources @resources end |
#restart_policy ⇒ Object
RestartPolicy defines the restart behavior of individual containers in a pod. This overrides the pod-level restart policy. When this field is not specified, the restart behavior is defined by the Pod’s restart policy and the container type. Additionally, setting the RestartPolicy as "Always" for the init container will have the following effect: this init container will be continually restarted on exit until all regular containers have terminated. Once all regular containers have completed, all init containers with restartPolicy "Always" will be shut down. This lifecycle differs from normal init containers and is often referred to as a "sidecar" container. Although this init container still starts in the init container sequence, it does not wait for the container to complete before proceeding to the next init container. Instead, the next init container starts immediately after this init container is started, or after any startupProbe has successfully completed.
55 56 57 |
# File 'lib/kubernetes/models/v1_container.rb', line 55 def restart_policy @restart_policy end |
#restart_policy_rules ⇒ Object
Represents a list of rules to be checked to determine if the container should be restarted on exit. The rules are evaluated in order. Once a rule matches a container exit condition, the remaining rules are ignored. If no rule matches the container exit condition, the Container-level restart policy determines the whether the container is restarted or not. Constraints on the rules: - At most 20 rules are allowed. - Rules can have the same action. - Identical rules are not forbidden in validations. When rules are specified, container MUST set RestartPolicy explicitly even it if matches the Pod’s RestartPolicy.
58 59 60 |
# File 'lib/kubernetes/models/v1_container.rb', line 58 def restart_policy_rules @restart_policy_rules end |
#security_context ⇒ Object
Returns the value of attribute security_context.
60 61 62 |
# File 'lib/kubernetes/models/v1_container.rb', line 60 def security_context @security_context end |
#startup_probe ⇒ Object
Returns the value of attribute startup_probe.
62 63 64 |
# File 'lib/kubernetes/models/v1_container.rb', line 62 def startup_probe @startup_probe end |
#stdin ⇒ Object
Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.
65 66 67 |
# File 'lib/kubernetes/models/v1_container.rb', line 65 def stdin @stdin end |
#stdin_once ⇒ Object
Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false
68 69 70 |
# File 'lib/kubernetes/models/v1_container.rb', line 68 def stdin_once @stdin_once end |
#termination_message_path ⇒ Object
Optional: Path at which the file to which the container’s termination message will be written is mounted into the container’s filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.
71 72 73 |
# File 'lib/kubernetes/models/v1_container.rb', line 71 def @termination_message_path end |
#termination_message_policy ⇒ Object
Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
74 75 76 |
# File 'lib/kubernetes/models/v1_container.rb', line 74 def @termination_message_policy end |
#tty ⇒ Object
Whether this container should allocate a TTY for itself, also requires ‘stdin’ to be true. Default is false.
77 78 79 |
# File 'lib/kubernetes/models/v1_container.rb', line 77 def tty @tty end |
#volume_devices ⇒ Object
volumeDevices is the list of block devices to be used by the container.
80 81 82 |
# File 'lib/kubernetes/models/v1_container.rb', line 80 def volume_devices @volume_devices end |
#volume_mounts ⇒ Object
Pod volumes to mount into the container’s filesystem. Cannot be updated.
83 84 85 |
# File 'lib/kubernetes/models/v1_container.rb', line 83 def volume_mounts @volume_mounts end |
#working_dir ⇒ Object
Container’s working directory. If not specified, the container runtime’s default will be used, which might be configured in the container image. Cannot be updated.
86 87 88 |
# File 'lib/kubernetes/models/v1_container.rb', line 86 def working_dir @working_dir end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
120 121 122 |
# File 'lib/kubernetes/models/v1_container.rb', line 120 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/kubernetes/models/v1_container.rb', line 89 def self.attribute_map { :'args' => :'args', :'command' => :'command', :'env' => :'env', :'env_from' => :'envFrom', :'image' => :'image', :'image_pull_policy' => :'imagePullPolicy', :'lifecycle' => :'lifecycle', :'liveness_probe' => :'livenessProbe', :'name' => :'name', :'ports' => :'ports', :'readiness_probe' => :'readinessProbe', :'resize_policy' => :'resizePolicy', :'resources' => :'resources', :'restart_policy' => :'restartPolicy', :'restart_policy_rules' => :'restartPolicyRules', :'security_context' => :'securityContext', :'startup_probe' => :'startupProbe', :'stdin' => :'stdin', :'stdin_once' => :'stdinOnce', :'termination_message_path' => :'terminationMessagePath', :'termination_message_policy' => :'terminationMessagePolicy', :'tty' => :'tty', :'volume_devices' => :'volumeDevices', :'volume_mounts' => :'volumeMounts', :'working_dir' => :'workingDir' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
360 361 362 |
# File 'lib/kubernetes/models/v1_container.rb', line 360 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
156 157 158 159 |
# File 'lib/kubernetes/models/v1_container.rb', line 156 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/kubernetes/models/v1_container.rb', line 125 def self.openapi_types { :'args' => :'Array<String>', :'command' => :'Array<String>', :'env' => :'Array<V1EnvVar>', :'env_from' => :'Array<V1EnvFromSource>', :'image' => :'String', :'image_pull_policy' => :'String', :'lifecycle' => :'V1Lifecycle', :'liveness_probe' => :'V1Probe', :'name' => :'String', :'ports' => :'Array<V1ContainerPort>', :'readiness_probe' => :'V1Probe', :'resize_policy' => :'Array<V1ContainerResizePolicy>', :'resources' => :'V1ResourceRequirements', :'restart_policy' => :'String', :'restart_policy_rules' => :'Array<V1ContainerRestartRule>', :'security_context' => :'V1SecurityContext', :'startup_probe' => :'V1Probe', :'stdin' => :'Boolean', :'stdin_once' => :'Boolean', :'termination_message_path' => :'String', :'termination_message_policy' => :'String', :'tty' => :'Boolean', :'volume_devices' => :'Array<V1VolumeDevice>', :'volume_mounts' => :'Array<V1VolumeMount>', :'working_dir' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/kubernetes/models/v1_container.rb', line 315 def ==(o) return true if self.equal?(o) self.class == o.class && args == o.args && command == o.command && env == o.env && env_from == o.env_from && image == o.image && image_pull_policy == o.image_pull_policy && lifecycle == o.lifecycle && liveness_probe == o.liveness_probe && name == o.name && ports == o.ports && readiness_probe == o.readiness_probe && resize_policy == o.resize_policy && resources == o.resources && restart_policy == o.restart_policy && restart_policy_rules == o.restart_policy_rules && security_context == o.security_context && startup_probe == o.startup_probe && stdin == o.stdin && stdin_once == o.stdin_once && == o. && == o. && tty == o.tty && volume_devices == o.volume_devices && volume_mounts == o.volume_mounts && working_dir == o.working_dir end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/kubernetes/models/v1_container.rb', line 390 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/kubernetes/models/v1_container.rb', line 461 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/kubernetes/models/v1_container.rb', line 367 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
347 348 349 |
# File 'lib/kubernetes/models/v1_container.rb', line 347 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
353 354 355 |
# File 'lib/kubernetes/models/v1_container.rb', line 353 def hash [args, command, env, env_from, image, image_pull_policy, lifecycle, liveness_probe, name, ports, readiness_probe, resize_policy, resources, restart_policy, restart_policy_rules, security_context, startup_probe, stdin, stdin_once, , , tty, volume_devices, volume_mounts, working_dir].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
297 298 299 300 301 302 303 304 |
# File 'lib/kubernetes/models/v1_container.rb', line 297 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
437 438 439 |
# File 'lib/kubernetes/models/v1_container.rb', line 437 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/kubernetes/models/v1_container.rb', line 443 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
431 432 433 |
# File 'lib/kubernetes/models/v1_container.rb', line 431 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
308 309 310 311 |
# File 'lib/kubernetes/models/v1_container.rb', line 308 def valid? return false if @name.nil? true end |