Class: Kubernetes::V1LimitedPriorityLevelConfiguration
- Inherits:
-
Object
- Object
- Kubernetes::V1LimitedPriorityLevelConfiguration
- Defined in:
- lib/kubernetes/models/v1_limited_priority_level_configuration.rb
Overview
LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues: - How are requests for this priority level limited? - What should be done with requests that exceed the limit?
Instance Attribute Summary collapse
-
#borrowing_limit_percent ⇒ Object
‘borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels.
-
#lendable_percent ⇒ Object
‘lendablePercent` prescribes the fraction of the level’s NominalCL that can be borrowed by other priority levels.
-
#limit_response ⇒ Object
Returns the value of attribute limit_response.
-
#nominal_concurrency_shares ⇒ Object
‘nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1LimitedPriorityLevelConfiguration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1LimitedPriorityLevelConfiguration
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1LimitedPriorityLevelConfiguration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1LimitedPriorityLevelConfiguration`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'borrowing_limit_percent') self.borrowing_limit_percent = attributes[:'borrowing_limit_percent'] end if attributes.key?(:'lendable_percent') self.lendable_percent = attributes[:'lendable_percent'] end if attributes.key?(:'limit_response') self.limit_response = attributes[:'limit_response'] end if attributes.key?(:'nominal_concurrency_shares') self.nominal_concurrency_shares = attributes[:'nominal_concurrency_shares'] end end |
Instance Attribute Details
#borrowing_limit_percent ⇒ Object
‘borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level’s BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level’s nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows. BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 ) The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left ‘nil`, the limit is effectively infinite.
20 21 22 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 20 def borrowing_limit_percent @borrowing_limit_percent end |
#lendable_percent ⇒ Object
‘lendablePercent` prescribes the fraction of the level’s NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level’s LendableConcurrencyLimit (LendableCL), is defined as follows. LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
23 24 25 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 23 def lendable_percent @lendable_percent end |
#limit_response ⇒ Object
Returns the value of attribute limit_response.
25 26 27 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 25 def limit_response @limit_response end |
#nominal_concurrency_shares ⇒ Object
‘nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats available at this priority level. This is used both for requests dispatched from this priority level as well as requests dispatched from other priority levels borrowing seats from this level. The server’s concurrency limit (ServerCL) is divided among the Limited priority levels in proportion to their NCS values: NominalCL(i) = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k) Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. If not specified, this field defaults to a value of 30. Setting this field to zero supports the construction of a "jail" for this priority level that is used to hold some request(s)
28 29 30 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 28 def nominal_concurrency_shares @nominal_concurrency_shares end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 41 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 31 def self.attribute_map { :'borrowing_limit_percent' => :'borrowingLimitPercent', :'lendable_percent' => :'lendablePercent', :'limit_response' => :'limitResponse', :'nominal_concurrency_shares' => :'nominalConcurrencyShares' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
132 133 134 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 132 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 53 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 46 def self.openapi_types { :'borrowing_limit_percent' => :'Integer', :'lendable_percent' => :'Integer', :'limit_response' => :'V1LimitResponse', :'nominal_concurrency_shares' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 115 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 108 def ==(o) return true if self.equal?(o) self.class == o.class && borrowing_limit_percent == o.borrowing_limit_percent && lendable_percent == o.lendable_percent && limit_response == o.limit_response && nominal_concurrency_shares == o.nominal_concurrency_shares end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 162 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 233 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 139 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
119 120 121 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 119 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
125 126 127 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 125 def hash [borrowing_limit_percent, lendable_percent, limit_response, nominal_concurrency_shares].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
95 96 97 98 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 95 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
209 210 211 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 209 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
203 204 205 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 203 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 |
# File 'lib/kubernetes/models/v1_limited_priority_level_configuration.rb', line 102 def valid? true end |