Class: Kubernetes::V1PodCertificateProjection
- Inherits:
-
Object
- Object
- Kubernetes::V1PodCertificateProjection
- Defined in:
- lib/kubernetes/models/v1_pod_certificate_projection.rb
Overview
PodCertificateProjection provides a private key and X.509 certificate in the pod filesystem.
Instance Attribute Summary collapse
-
#certificate_chain_path ⇒ Object
Write the certificate chain at this path in the projected volume.
-
#credential_bundle_path ⇒ Object
Write the credential bundle at this path in the projected volume.
-
#key_path ⇒ Object
Write the key at this path in the projected volume.
-
#key_type ⇒ Object
The type of keypair Kubelet will generate for the pod.
-
#max_expiration_seconds ⇒ Object
maxExpirationSeconds is the maximum lifetime permitted for the certificate.
-
#signer_name ⇒ Object
Kubelet’s generated CSRs will be addressed to this signer.
-
#user_annotations ⇒ Object
userAnnotations allow pod authors to pass additional information to the signer implementation.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1PodCertificateProjection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1PodCertificateProjection
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1PodCertificateProjection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1PodCertificateProjection`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'certificate_chain_path') self.certificate_chain_path = attributes[:'certificate_chain_path'] end if attributes.key?(:'credential_bundle_path') self.credential_bundle_path = attributes[:'credential_bundle_path'] end if attributes.key?(:'key_path') self.key_path = attributes[:'key_path'] end if attributes.key?(:'key_type') self.key_type = attributes[:'key_type'] end if attributes.key?(:'max_expiration_seconds') self.max_expiration_seconds = attributes[:'max_expiration_seconds'] end if attributes.key?(:'signer_name') self.signer_name = attributes[:'signer_name'] end if attributes.key?(:'user_annotations') if (value = attributes[:'user_annotations']).is_a?(Hash) self.user_annotations = value end end end |
Instance Attribute Details
#certificate_chain_path ⇒ Object
Write the certificate chain at this path in the projected volume. Most applications should use credentialBundlePath. When using keyPath and certificateChainPath, your application needs to check that the key and leaf certificate are consistent, because it is possible to read the files mid-rotation.
20 21 22 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 20 def certificate_chain_path @certificate_chain_path end |
#credential_bundle_path ⇒ Object
Write the credential bundle at this path in the projected volume. The credential bundle is a single file that contains multiple PEM blocks. The first PEM block is a PRIVATE KEY block, containing a PKCS#8 private key. The remaining blocks are CERTIFICATE blocks, containing the issued certificate chain from the signer (leaf and any intermediates). Using credentialBundlePath lets your Pod’s application code make a single atomic read that retrieves a consistent key and certificate chain. If you project them to separate files, your application code will need to additionally check that the leaf certificate was issued to the key.
23 24 25 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 23 def credential_bundle_path @credential_bundle_path end |
#key_path ⇒ Object
Write the key at this path in the projected volume. Most applications should use credentialBundlePath. When using keyPath and certificateChainPath, your application needs to check that the key and leaf certificate are consistent, because it is possible to read the files mid-rotation.
26 27 28 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 26 def key_path @key_path end |
#key_type ⇒ Object
The type of keypair Kubelet will generate for the pod. Valid values are "RSA3072", "RSA4096", "ECDSAP256", "ECDSAP384", "ECDSAP521", and "ED25519".
29 30 31 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 29 def key_type @key_type end |
#max_expiration_seconds ⇒ Object
maxExpirationSeconds is the maximum lifetime permitted for the certificate. Kubelet copies this value verbatim into the PodCertificateRequests it generates for this projection. If omitted, kube-apiserver will set it to 86400(24 hours). kube-apiserver will reject values shorter than 3600 (1 hour). The maximum allowable value is 7862400 (91 days). The signer implementation is then free to issue a certificate with any lifetime shorter than MaxExpirationSeconds, but no shorter than 3600 seconds (1 hour). This constraint is enforced by kube-apiserver. ‘kubernetes.io` signers will never issue certificates with a lifetime longer than 24 hours.
32 33 34 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 32 def max_expiration_seconds @max_expiration_seconds end |
#signer_name ⇒ Object
Kubelet’s generated CSRs will be addressed to this signer.
35 36 37 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 35 def signer_name @signer_name end |
#user_annotations ⇒ Object
userAnnotations allow pod authors to pass additional information to the signer implementation. Kubernetes does not restrict or validate this metadata in any way. These values are copied verbatim into the ‘spec.unverifiedUserAnnotations` field of the PodCertificateRequest objects that Kubelet creates. Entries are subject to the same validation as object metadata annotations, with the addition that all keys must be domain-prefixed. No restrictions are placed on values, except an overall size limitation on the entire field. Signers should document the keys and values they support. Signers should deny requests that contain keys they do not recognize.
38 39 40 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 38 def user_annotations @user_annotations end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 54 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 41 def self.attribute_map { :'certificate_chain_path' => :'certificateChainPath', :'credential_bundle_path' => :'credentialBundlePath', :'key_path' => :'keyPath', :'key_type' => :'keyType', :'max_expiration_seconds' => :'maxExpirationSeconds', :'signer_name' => :'signerName', :'user_annotations' => :'userAnnotations' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
175 176 177 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 175 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 59 def self.openapi_types { :'certificate_chain_path' => :'String', :'credential_bundle_path' => :'String', :'key_path' => :'String', :'key_type' => :'String', :'max_expiration_seconds' => :'Integer', :'signer_name' => :'String', :'user_annotations' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && certificate_chain_path == o.certificate_chain_path && credential_bundle_path == o.credential_bundle_path && key_path == o.key_path && key_type == o.key_type && max_expiration_seconds == o.max_expiration_seconds && signer_name == o.signer_name && user_annotations == o.user_annotations end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 205 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 276 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 182 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
162 163 164 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 162 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
168 169 170 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 168 def hash [certificate_chain_path, credential_bundle_path, key_path, key_type, max_expiration_seconds, signer_name, user_annotations].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 125 def list_invalid_properties invalid_properties = Array.new if @key_type.nil? invalid_properties.push('invalid value for "key_type", key_type cannot be nil.') end if @signer_name.nil? invalid_properties.push('invalid value for "signer_name", signer_name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
252 253 254 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 252 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
246 247 248 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 246 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 144 |
# File 'lib/kubernetes/models/v1_pod_certificate_projection.rb', line 140 def valid? return false if @key_type.nil? return false if @signer_name.nil? true end |