Class: Kubernetes::V1RollingUpdateDaemonSet
- Inherits:
-
Object
- Object
- Kubernetes::V1RollingUpdateDaemonSet
- Defined in:
- lib/kubernetes/models/v1_rolling_update_daemon_set.rb
Overview
Spec to control the desired behavior of daemon set rolling update.
Instance Attribute Summary collapse
-
#max_surge ⇒ Object
The maximum number of nodes with an existing available DaemonSet pod that can have an updated DaemonSet pod during during an update.
-
#max_unavailable ⇒ Object
The maximum number of DaemonSet pods that can be unavailable during the update.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1RollingUpdateDaemonSet
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1RollingUpdateDaemonSet
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 54 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1RollingUpdateDaemonSet` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1RollingUpdateDaemonSet`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'max_surge') self.max_surge = attributes[:'max_surge'] end if attributes.key?(:'max_unavailable') self.max_unavailable = attributes[:'max_unavailable'] end end |
Instance Attribute Details
#max_surge ⇒ Object
The maximum number of nodes with an existing available DaemonSet pod that can have an updated DaemonSet pod during during an update. Value can be an absolute number (ex: 5) or a percentage of desired pods (ex: 10%). This can not be 0 if MaxUnavailable is 0. Absolute number is calculated from percentage by rounding up to a minimum of 1. Default value is 0. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their a new pod created before the old pod is marked as deleted. The update starts by launching new pods on 30% of nodes. Once an updated pod is available (Ready for at least minReadySeconds) the old DaemonSet pod on that node is marked deleted. If the old pod becomes unavailable for any reason (Ready transitions to false, is evicted, or is drained) an updated pod is immediately created on that node without considering surge limits. Allowing surge implies the possibility that the resources consumed by the daemonset on any given node can double if the readiness check fails, and so resource intensive daemonsets should take into account that they may cause evictions during disruption.
20 21 22 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 20 def max_surge @max_surge end |
#max_unavailable ⇒ Object
The maximum number of DaemonSet pods that can be unavailable during the update. Value can be an absolute number (ex: 5) or a percentage of total number of DaemonSet pods at the start of the update (ex: 10%). Absolute number is calculated from percentage by rounding up. This cannot be 0 if MaxSurge is 0 Default value is 1. Example: when this is set to 30%, at most 30% of the total number of nodes that should be running the daemon pod (i.e. status.desiredNumberScheduled) can have their pods stopped for an update at any given time. The update starts by stopping at most 30% of those DaemonSet pods and then brings up new DaemonSet pods in their place. Once the new pods are available, it then proceeds onto other DaemonSet pods, thus ensuring that at least 70% of original number of DaemonSet pods are available at all times during the update.
23 24 25 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 23 def max_unavailable @max_unavailable end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
34 35 36 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 34 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 26 def self.attribute_map { :'max_surge' => :'maxSurge', :'max_unavailable' => :'maxUnavailable' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
113 114 115 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 113 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
47 48 49 50 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 47 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 39 def self.openapi_types { :'max_surge' => :'Object', :'max_unavailable' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
91 92 93 94 95 96 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 91 def ==(o) return true if self.equal?(o) self.class == o.class && max_surge == o.max_surge && max_unavailable == o.max_unavailable end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 143 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 214 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 120 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
100 101 102 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 100 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
106 107 108 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 106 def hash [max_surge, max_unavailable].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
78 79 80 81 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 78 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
190 191 192 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 190 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
184 185 186 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 184 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
85 86 87 |
# File 'lib/kubernetes/models/v1_rolling_update_daemon_set.rb', line 85 def valid? true end |