Class: Kubernetes::V1ServicePort
- Inherits:
-
Object
- Object
- Kubernetes::V1ServicePort
- Defined in:
- lib/kubernetes/models/v1_service_port.rb
Overview
ServicePort contains information on service’s port.
Instance Attribute Summary collapse
-
#app_protocol ⇒ Object
The application protocol for this port.
-
#name ⇒ Object
The name of this port within the service.
-
#node_port ⇒ Object
The port on each node on which this service is exposed when type is NodePort or LoadBalancer.
-
#port ⇒ Object
The port that will be exposed by this service.
-
#protocol ⇒ Object
The IP protocol for this port.
-
#target_port ⇒ Object
Number or name of the port to access on the pods targeted by the service.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1ServicePort
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1ServicePort
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ServicePort` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ServicePort`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'app_protocol') self.app_protocol = attributes[:'app_protocol'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'node_port') self.node_port = attributes[:'node_port'] end if attributes.key?(:'port') self.port = attributes[:'port'] end if attributes.key?(:'protocol') self.protocol = attributes[:'protocol'] end if attributes.key?(:'target_port') self.target_port = attributes[:'target_port'] end end |
Instance Attribute Details
#app_protocol ⇒ Object
The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either: * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and www.iana.org/assignments/service-names). * Kubernetes-defined prefixed names: * ‘kubernetes.io/h2c’ - HTTP/2 prior knowledge over cleartext as described in www.rfc-editor.org/rfc/rfc9113.html#name-starting-http-2-with-prior- * ‘kubernetes.io/ws’ - WebSocket over cleartext as described in www.rfc-editor.org/rfc/rfc6455 * ‘kubernetes.io/wss’ - WebSocket over TLS as described in www.rfc-editor.org/rfc/rfc6455 * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
20 21 22 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 20 def app_protocol @app_protocol end |
#name ⇒ Object
The name of this port within the service. This must be a DNS_LABEL. All ports within a ServiceSpec must have unique names. When considering the endpoints for a Service, this must match the ‘name’ field in the EndpointPort. Optional if only one ServicePort is defined on this service.
23 24 25 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 23 def name @name end |
#node_port ⇒ Object
The port on each node on which this service is exposed when type is NodePort or LoadBalancer. Usually assigned by the system. If a value is specified, in-range, and not in use it will be used, otherwise the operation will fail. If not specified, a port will be allocated if this Service requires one. If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type from NodePort to ClusterIP). More info: kubernetes.io/docs/concepts/services-networking/service/#type-nodeport
26 27 28 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 26 def node_port @node_port end |
#port ⇒ Object
The port that will be exposed by this service.
29 30 31 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 29 def port @port end |
#protocol ⇒ Object
The IP protocol for this port. Supports "TCP", "UDP", and "SCTP". Default is TCP.
32 33 34 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 32 def protocol @protocol end |
#target_port ⇒ Object
Number or name of the port to access on the pods targeted by the service. Number must be in the range 1 to 65535. Name must be an IANA_SVC_NAME. If this is a string, it will be looked up as a named port in the target Pod’s container ports. If this is not specified, the value of the ‘port’ field is used (an identity map). This field is ignored for services with clusterIP=None, and should be omitted or set equal to the ‘port’ field. More info: kubernetes.io/docs/concepts/services-networking/service/#defining-a-service
35 36 37 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 35 def target_port @target_port end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 50 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 38 def self.attribute_map { :'app_protocol' => :'appProtocol', :'name' => :'name', :'node_port' => :'nodePort', :'port' => :'port', :'protocol' => :'protocol', :'target_port' => :'targetPort' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 158 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 55 def self.openapi_types { :'app_protocol' => :'String', :'name' => :'String', :'node_port' => :'Integer', :'port' => :'Integer', :'protocol' => :'String', :'target_port' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 132 def ==(o) return true if self.equal?(o) self.class == o.class && app_protocol == o.app_protocol && name == o.name && node_port == o.node_port && port == o.port && protocol == o.protocol && target_port == o.target_port end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 188 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 259 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 165 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 151 def hash [app_protocol, name, node_port, port, protocol, target_port].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 119 120 121 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 114 def list_invalid_properties invalid_properties = Array.new if @port.nil? invalid_properties.push('invalid value for "port", port cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
235 236 237 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 235 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
229 230 231 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 229 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 |
# File 'lib/kubernetes/models/v1_service_port.rb', line 125 def valid? return false if @port.nil? true end |