Class: Kubernetes::V1ValidatingWebhook
- Inherits:
-
Object
- Object
- Kubernetes::V1ValidatingWebhook
- Defined in:
- lib/kubernetes/models/v1_validating_webhook.rb
Overview
ValidatingWebhook describes an admission webhook and the resources and operations it applies to.
Instance Attribute Summary collapse
-
#admission_review_versions ⇒ Object
AdmissionReviewVersions is an ordered list of preferred ‘AdmissionReview` versions the Webhook expects.
-
#client_config ⇒ Object
Returns the value of attribute client_config.
-
#failure_policy ⇒ Object
FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail.
-
#match_conditions ⇒ Object
MatchConditions is a list of conditions that must be met for a request to be sent to this webhook.
-
#match_policy ⇒ Object
matchPolicy defines how the "rules" list is used to match incoming requests.
-
#name ⇒ Object
The name of the admission webhook.
-
#namespace_selector ⇒ Object
Returns the value of attribute namespace_selector.
-
#object_selector ⇒ Object
Returns the value of attribute object_selector.
-
#rules ⇒ Object
Rules describes what operations on what resources/subresources the webhook cares about.
-
#side_effects ⇒ Object
SideEffects states whether this webhook has side effects.
-
#timeout_seconds ⇒ Object
TimeoutSeconds specifies the timeout for this webhook.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1ValidatingWebhook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1ValidatingWebhook
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1ValidatingWebhook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1ValidatingWebhook`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'admission_review_versions') if (value = attributes[:'admission_review_versions']).is_a?(Array) self.admission_review_versions = value end end if attributes.key?(:'client_config') self.client_config = attributes[:'client_config'] end if attributes.key?(:'failure_policy') self.failure_policy = attributes[:'failure_policy'] end if attributes.key?(:'match_conditions') if (value = attributes[:'match_conditions']).is_a?(Array) self.match_conditions = value end end if attributes.key?(:'match_policy') self.match_policy = attributes[:'match_policy'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'namespace_selector') self.namespace_selector = attributes[:'namespace_selector'] end if attributes.key?(:'object_selector') self.object_selector = attributes[:'object_selector'] end if attributes.key?(:'rules') if (value = attributes[:'rules']).is_a?(Array) self.rules = value end end if attributes.key?(:'side_effects') self.side_effects = attributes[:'side_effects'] end if attributes.key?(:'timeout_seconds') self.timeout_seconds = attributes[:'timeout_seconds'] end end |
Instance Attribute Details
#admission_review_versions ⇒ Object
AdmissionReviewVersions is an ordered list of preferred ‘AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy.
20 21 22 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 20 def admission_review_versions @admission_review_versions end |
#client_config ⇒ Object
Returns the value of attribute client_config.
22 23 24 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 22 def client_config @client_config end |
#failure_policy ⇒ Object
FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail.
25 26 27 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 25 def failure_policy @failure_policy end |
#match_conditions ⇒ Object
MatchConditions is a list of conditions that must be met for a request to be sent to this webhook. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed. The exact matching logic is (in order): 1. If ANY matchCondition evaluates to FALSE, the webhook is skipped. 2. If ALL matchConditions evaluate to TRUE, the webhook is called. 3. If any matchCondition evaluates to an error (but none are FALSE): - If failurePolicy=Fail, reject the request - If failurePolicy=Ignore, the error is ignored and the webhook is skipped
28 29 30 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 28 def match_conditions @match_conditions end |
#match_policy ⇒ Object
matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent". - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included ‘apiGroups:, apiVersions:, resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook. - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:, apiVersions:, resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook. Defaults to "Equivalent"
31 32 33 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 31 def match_policy @match_policy end |
#name ⇒ Object
The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required.
34 35 36 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 34 def name @name end |
#namespace_selector ⇒ Object
Returns the value of attribute namespace_selector.
36 37 38 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 36 def namespace_selector @namespace_selector end |
#object_selector ⇒ Object
Returns the value of attribute object_selector.
38 39 40 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 38 def object_selector @object_selector end |
#rules ⇒ Object
Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches any Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects.
41 42 43 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 41 def rules @rules end |
#side_effects ⇒ Object
SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some.
44 45 46 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 44 def side_effects @side_effects end |
#timeout_seconds ⇒ Object
TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds.
47 48 49 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 47 def timeout_seconds @timeout_seconds end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 67 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 50 def self.attribute_map { :'admission_review_versions' => :'admissionReviewVersions', :'client_config' => :'clientConfig', :'failure_policy' => :'failurePolicy', :'match_conditions' => :'matchConditions', :'match_policy' => :'matchPolicy', :'name' => :'name', :'namespace_selector' => :'namespaceSelector', :'object_selector' => :'objectSelector', :'rules' => :'rules', :'side_effects' => :'sideEffects', :'timeout_seconds' => :'timeoutSeconds' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 226 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 72 def self.openapi_types { :'admission_review_versions' => :'Array<String>', :'client_config' => :'AdmissionregistrationV1WebhookClientConfig', :'failure_policy' => :'String', :'match_conditions' => :'Array<V1MatchCondition>', :'match_policy' => :'String', :'name' => :'String', :'namespace_selector' => :'V1LabelSelector', :'object_selector' => :'V1LabelSelector', :'rules' => :'Array<V1RuleWithOperations>', :'side_effects' => :'String', :'timeout_seconds' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && admission_review_versions == o.admission_review_versions && client_config == o.client_config && failure_policy == o.failure_policy && match_conditions == o.match_conditions && match_policy == o.match_policy && name == o.name && namespace_selector == o.namespace_selector && object_selector == o.object_selector && rules == o.rules && side_effects == o.side_effects && timeout_seconds == o.timeout_seconds end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 256 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 233 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
213 214 215 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 213 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 219 def hash [admission_review_versions, client_config, failure_policy, match_conditions, match_policy, name, namespace_selector, object_selector, rules, side_effects, timeout_seconds].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 162 def list_invalid_properties invalid_properties = Array.new if @admission_review_versions.nil? invalid_properties.push('invalid value for "admission_review_versions", admission_review_versions cannot be nil.') end if @client_config.nil? invalid_properties.push('invalid value for "client_config", client_config cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @side_effects.nil? invalid_properties.push('invalid value for "side_effects", side_effects cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
303 304 305 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 303 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 297 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 190 191 |
# File 'lib/kubernetes/models/v1_validating_webhook.rb', line 185 def valid? return false if @admission_review_versions.nil? return false if @client_config.nil? return false if @name.nil? return false if @side_effects.nil? true end |