Class: Kubernetes::V1beta1DeviceRequest
- Inherits:
-
Object
- Object
- Kubernetes::V1beta1DeviceRequest
- Defined in:
- lib/kubernetes/models/v1beta1_device_request.rb
Overview
DeviceRequest is a request for devices required for a claim. This is typically a request for a single resource like a device, but can also ask for several identical devices.
Instance Attribute Summary collapse
-
#admin_access ⇒ Object
AdminAccess indicates that this is a claim for administrative access to the device(s).
-
#allocation_mode ⇒ Object
AllocationMode and its related fields define how devices are allocated to satisfy this request.
-
#capacity ⇒ Object
Returns the value of attribute capacity.
-
#count ⇒ Object
Count is used only when the count mode is "ExactCount".
-
#device_class_name ⇒ Object
DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request.
-
#first_available ⇒ Object
FirstAvailable contains subrequests, of which exactly one will be satisfied by the scheduler to satisfy this request.
-
#name ⇒ Object
Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.
-
#selectors ⇒ Object
Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request.
-
#tolerations ⇒ Object
If specified, the request’s tolerations.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1beta1DeviceRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1beta1DeviceRequest
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta1DeviceRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta1DeviceRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'admin_access') self.admin_access = attributes[:'admin_access'] end if attributes.key?(:'allocation_mode') self.allocation_mode = attributes[:'allocation_mode'] end if attributes.key?(:'capacity') self.capacity = attributes[:'capacity'] end if attributes.key?(:'count') self.count = attributes[:'count'] end if attributes.key?(:'device_class_name') self.device_class_name = attributes[:'device_class_name'] end if attributes.key?(:'first_available') if (value = attributes[:'first_available']).is_a?(Array) self.first_available = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'selectors') if (value = attributes[:'selectors']).is_a?(Array) self.selectors = value end end if attributes.key?(:'tolerations') if (value = attributes[:'tolerations']).is_a?(Array) self.tolerations = value end end end |
Instance Attribute Details
#admin_access ⇒ Object
AdminAccess indicates that this is a claim for administrative access to the device(s). Claims with AdminAccess are expected to be used for monitoring or other management services for a device. They ignore all ordinary claims to the device with respect to access modes and any resource allocations. This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list. This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
20 21 22 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 20 def admin_access @admin_access end |
#allocation_mode ⇒ Object
AllocationMode and its related fields define how devices are allocated to satisfy this request. Supported values are: - ExactCount: This request is for a specific number of devices. This is the default. The exact number is provided in the count field. - All: This request is for all of the matching devices in a pool. At least one device must exist on the node for the allocation to succeed. Allocation will fail if some devices are already allocated, unless adminAccess is requested. If AllocationMode is not specified, the default mode is ExactCount. If the mode is ExactCount and count is not specified, the default count is one. Any other requests must specify this field. This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list. More modes may get added in the future. Clients must refuse to handle requests with unknown modes.
23 24 25 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 23 def allocation_mode @allocation_mode end |
#capacity ⇒ Object
Returns the value of attribute capacity.
25 26 27 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 25 def capacity @capacity end |
#count ⇒ Object
Count is used only when the count mode is "ExactCount". Must be greater than zero. If AllocationMode is ExactCount and this field is not specified, the default is one. This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
28 29 30 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 28 def count @count end |
#device_class_name ⇒ Object
DeviceClassName references a specific DeviceClass, which can define additional configuration and selectors to be inherited by this request. A class is required if no subrequests are specified in the firstAvailable list and no class can be set if subrequests are specified in the firstAvailable list. Which classes are available depends on the cluster. Administrators may use this to restrict which devices may get requested by only installing classes with selectors for permitted devices. If users are free to request anything without restrictions, then administrators can create an empty DeviceClass for users to reference.
31 32 33 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 31 def device_class_name @device_class_name end |
#first_available ⇒ Object
FirstAvailable contains subrequests, of which exactly one will be satisfied by the scheduler to satisfy this request. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one cannot be used. This field may only be set in the entries of DeviceClaim.Requests. DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.
34 35 36 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 34 def first_available @first_available end |
#name ⇒ Object
Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim. Must be a DNS label and unique among all DeviceRequests in a ResourceClaim.
37 38 39 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 37 def name @name end |
#selectors ⇒ Object
Selectors define criteria which must be satisfied by a specific device in order for that device to be considered for this request. All selectors must be satisfied for a device to be considered. This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list.
40 41 42 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 40 def selectors @selectors end |
#tolerations ⇒ Object
If specified, the request’s tolerations. Tolerations for NoSchedule are required to allocate a device which has a taint with that effect. The same applies to NoExecute. In addition, should any of the allocated devices get tainted with NoExecute after allocation and that effect is not tolerated, then all pods consuming the ResourceClaim get deleted to evict them. The scheduler will not let new pods reserve the claim while it has these tainted devices. Once all pods are evicted, the claim will get deallocated. The maximum number of tolerations is 16. This field can only be set when deviceClassName is set and no subrequests are specified in the firstAvailable list. This is an alpha field and requires enabling the DRADeviceTaints feature gate.
43 44 45 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 43 def tolerations @tolerations end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 61 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 46 def self.attribute_map { :'admin_access' => :'adminAccess', :'allocation_mode' => :'allocationMode', :'capacity' => :'capacity', :'count' => :'count', :'device_class_name' => :'deviceClassName', :'first_available' => :'firstAvailable', :'name' => :'name', :'selectors' => :'selectors', :'tolerations' => :'tolerations' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 193 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 66 def self.openapi_types { :'admin_access' => :'Boolean', :'allocation_mode' => :'String', :'capacity' => :'V1beta1CapacityRequirements', :'count' => :'Integer', :'device_class_name' => :'String', :'first_available' => :'Array<V1beta1DeviceSubRequest>', :'name' => :'String', :'selectors' => :'Array<V1beta1DeviceSelector>', :'tolerations' => :'Array<V1beta1DeviceToleration>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && admin_access == o.admin_access && allocation_mode == o.allocation_mode && capacity == o.capacity && count == o.count && device_class_name == o.device_class_name && first_available == o.first_available && name == o.name && selectors == o.selectors && tolerations == o.tolerations end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 223 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 294 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 200 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 186 def hash [admin_access, allocation_mode, capacity, count, device_class_name, first_available, name, selectors, tolerations].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 146 def list_invalid_properties invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
270 271 272 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 270 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
264 265 266 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 264 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 |
# File 'lib/kubernetes/models/v1beta1_device_request.rb', line 157 def valid? return false if @name.nil? true end |