Class: Kubernetes::V1beta2DeviceRequestAllocationResult
- Inherits:
-
Object
- Object
- Kubernetes::V1beta2DeviceRequestAllocationResult
- Defined in:
- lib/kubernetes/models/v1beta2_device_request_allocation_result.rb
Overview
DeviceRequestAllocationResult contains the allocation result for one request.
Instance Attribute Summary collapse
-
#admin_access ⇒ Object
AdminAccess indicates that this device was allocated for administrative access.
-
#binding_conditions ⇒ Object
BindingConditions contains a copy of the BindingConditions from the corresponding ResourceSlice at the time of allocation.
-
#binding_failure_conditions ⇒ Object
BindingFailureConditions contains a copy of the BindingFailureConditions from the corresponding ResourceSlice at the time of allocation.
-
#consumed_capacity ⇒ Object
ConsumedCapacity tracks the amount of capacity consumed per device as part of the claim request.
-
#device ⇒ Object
Device references one device instance via its name in the driver’s resource pool.
-
#driver ⇒ Object
Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node.
-
#pool ⇒ Object
This name together with the driver name and the device name field identify which device was allocated (‘<driver name>/<pool name>/<device name>`).
-
#request ⇒ Object
Request is the name of the request in the claim which caused this device to be allocated.
-
#share_id ⇒ Object
ShareID uniquely identifies an individual allocation share of the device, used when the device supports multiple simultaneous allocations.
-
#tolerations ⇒ Object
A copy of all tolerations specified in the request at the time when the device got allocated.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1beta2DeviceRequestAllocationResult
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1beta2DeviceRequestAllocationResult
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta2DeviceRequestAllocationResult` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta2DeviceRequestAllocationResult`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'admin_access') self.admin_access = attributes[:'admin_access'] end if attributes.key?(:'binding_conditions') if (value = attributes[:'binding_conditions']).is_a?(Array) self.binding_conditions = value end end if attributes.key?(:'binding_failure_conditions') if (value = attributes[:'binding_failure_conditions']).is_a?(Array) self.binding_failure_conditions = value end end if attributes.key?(:'consumed_capacity') if (value = attributes[:'consumed_capacity']).is_a?(Hash) self.consumed_capacity = value end end if attributes.key?(:'device') self.device = attributes[:'device'] end if attributes.key?(:'driver') self.driver = attributes[:'driver'] end if attributes.key?(:'pool') self.pool = attributes[:'pool'] end if attributes.key?(:'request') self.request = attributes[:'request'] end if attributes.key?(:'share_id') self.share_id = attributes[:'share_id'] end if attributes.key?(:'tolerations') if (value = attributes[:'tolerations']).is_a?(Array) self.tolerations = value end end end |
Instance Attribute Details
#admin_access ⇒ Object
AdminAccess indicates that this device was allocated for administrative access. See the corresponding request field for a definition of mode. This is an alpha field and requires enabling the DRAAdminAccess feature gate. Admin access is disabled if this field is unset or set to false, otherwise it is enabled.
20 21 22 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 20 def admin_access @admin_access end |
#binding_conditions ⇒ Object
BindingConditions contains a copy of the BindingConditions from the corresponding ResourceSlice at the time of allocation. This is an alpha field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.
23 24 25 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 23 def binding_conditions @binding_conditions end |
#binding_failure_conditions ⇒ Object
BindingFailureConditions contains a copy of the BindingFailureConditions from the corresponding ResourceSlice at the time of allocation. This is an alpha field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.
26 27 28 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 26 def binding_failure_conditions @binding_failure_conditions end |
#consumed_capacity ⇒ Object
ConsumedCapacity tracks the amount of capacity consumed per device as part of the claim request. The consumed amount may differ from the requested amount: it is rounded up to the nearest valid value based on the device’s requestPolicy if applicable (i.e., may not be less than the requested amount). The total consumed capacity for each device must not exceed the DeviceCapacity’s Value. This field is populated only for devices that allow multiple allocations. All capacity entries are included, even if the consumed amount is zero.
29 30 31 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 29 def consumed_capacity @consumed_capacity end |
#device ⇒ Object
Device references one device instance via its name in the driver’s resource pool. It must be a DNS label.
32 33 34 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 32 def device @device end |
#driver ⇒ Object
Driver specifies the name of the DRA driver whose kubelet plugin should be invoked to process the allocation once the claim is needed on a node. Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. It should use only lower case characters.
35 36 37 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 35 def driver @driver end |
#pool ⇒ Object
This name together with the driver name and the device name field identify which device was allocated (‘<driver name>/<pool name>/<device name>`). Must not be longer than 253 characters and may contain one or more DNS sub-domains separated by slashes.
38 39 40 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 38 def pool @pool end |
#request ⇒ Object
Request is the name of the request in the claim which caused this device to be allocated. If it references a subrequest in the firstAvailable list on a DeviceRequest, this field must include both the name of the main request and the subrequest using the format <main request>/<subrequest>. Multiple devices may have been allocated per request.
41 42 43 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 41 def request @request end |
#share_id ⇒ Object
ShareID uniquely identifies an individual allocation share of the device, used when the device supports multiple simultaneous allocations. It serves as an additional map key to differentiate concurrent shares of the same device.
44 45 46 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 44 def share_id @share_id end |
#tolerations ⇒ Object
A copy of all tolerations specified in the request at the time when the device got allocated. The maximum number of tolerations is 16. This is an alpha field and requires enabling the DRADeviceTaints feature gate.
47 48 49 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 47 def tolerations @tolerations end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 66 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 50 def self.attribute_map { :'admin_access' => :'adminAccess', :'binding_conditions' => :'bindingConditions', :'binding_failure_conditions' => :'bindingFailureConditions', :'consumed_capacity' => :'consumedCapacity', :'device' => :'device', :'driver' => :'driver', :'pool' => :'pool', :'request' => :'request', :'share_id' => :'shareID', :'tolerations' => :'tolerations' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 221 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 71 def self.openapi_types { :'admin_access' => :'Boolean', :'binding_conditions' => :'Array<String>', :'binding_failure_conditions' => :'Array<String>', :'consumed_capacity' => :'Hash<String, String>', :'device' => :'String', :'driver' => :'String', :'pool' => :'String', :'request' => :'String', :'share_id' => :'String', :'tolerations' => :'Array<V1beta2DeviceToleration>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && admin_access == o.admin_access && binding_conditions == o.binding_conditions && binding_failure_conditions == o.binding_failure_conditions && consumed_capacity == o.consumed_capacity && device == o.device && driver == o.driver && pool == o.pool && request == o.request && share_id == o.share_id && tolerations == o.tolerations end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 251 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 322 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 228 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 214 def hash [admin_access, binding_conditions, binding_failure_conditions, consumed_capacity, device, driver, pool, request, share_id, tolerations].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 158 def list_invalid_properties invalid_properties = Array.new if @device.nil? invalid_properties.push('invalid value for "device", device cannot be nil.') end if @driver.nil? invalid_properties.push('invalid value for "driver", driver cannot be nil.') end if @pool.nil? invalid_properties.push('invalid value for "pool", pool cannot be nil.') end if @request.nil? invalid_properties.push('invalid value for "request", request cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
298 299 300 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 298 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 292 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 |
# File 'lib/kubernetes/models/v1beta2_device_request_allocation_result.rb', line 181 def valid? return false if @device.nil? return false if @driver.nil? return false if @pool.nil? return false if @request.nil? true end |