Class: Kubernetes::V1beta2ResourceSliceSpec
- Inherits:
-
Object
- Object
- Kubernetes::V1beta2ResourceSliceSpec
- Defined in:
- lib/kubernetes/models/v1beta2_resource_slice_spec.rb
Overview
ResourceSliceSpec contains the information published by the driver in one ResourceSlice.
Instance Attribute Summary collapse
-
#all_nodes ⇒ Object
AllNodes indicates that all nodes have access to the resources in the pool.
-
#devices ⇒ Object
Devices lists some or all of the devices in this pool.
-
#driver ⇒ Object
Driver identifies the DRA driver providing the capacity information.
-
#node_name ⇒ Object
NodeName identifies the node which provides the resources in this pool.
-
#node_selector ⇒ Object
Returns the value of attribute node_selector.
-
#per_device_node_selection ⇒ Object
PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device.
-
#pool ⇒ Object
Returns the value of attribute pool.
-
#shared_counters ⇒ Object
SharedCounters defines a list of counter sets, each of which has a name and a list of counters available.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ V1beta2ResourceSliceSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ V1beta2ResourceSliceSpec
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Kubernetes::V1beta2ResourceSliceSpec` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Kubernetes::V1beta2ResourceSliceSpec`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'all_nodes') self.all_nodes = attributes[:'all_nodes'] end if attributes.key?(:'devices') if (value = attributes[:'devices']).is_a?(Array) self.devices = value end end if attributes.key?(:'driver') self.driver = attributes[:'driver'] end if attributes.key?(:'node_name') self.node_name = attributes[:'node_name'] end if attributes.key?(:'node_selector') self.node_selector = attributes[:'node_selector'] end if attributes.key?(:'per_device_node_selection') self.per_device_node_selection = attributes[:'per_device_node_selection'] end if attributes.key?(:'pool') self.pool = attributes[:'pool'] end if attributes.key?(:'shared_counters') if (value = attributes[:'shared_counters']).is_a?(Array) self.shared_counters = value end end end |
Instance Attribute Details
#all_nodes ⇒ Object
AllNodes indicates that all nodes have access to the resources in the pool. Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
20 21 22 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 20 def all_nodes @all_nodes end |
#devices ⇒ Object
Devices lists some or all of the devices in this pool. Must not have more than 128 entries. If any device uses taints or consumes counters the limit is 64. Only one of Devices and SharedCounters can be set in a ResourceSlice.
23 24 25 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 23 def devices @devices end |
#driver ⇒ Object
Driver identifies the DRA driver providing the capacity information. A field selector can be used to list only ResourceSlice objects with a certain driver name. Must be a DNS subdomain and should end with a DNS domain owned by the vendor of the driver. It should use only lower case characters. This field is immutable.
26 27 28 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 26 def driver @driver end |
#node_name ⇒ Object
NodeName identifies the node which provides the resources in this pool. A field selector can be used to list only ResourceSlice objects belonging to a certain node. This field can be used to limit access from nodes to ResourceSlices with the same node name. It also indicates to autoscalers that adding new nodes of the same type as some old node might also make new resources available. Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set. This field is immutable.
29 30 31 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 29 def node_name @node_name end |
#node_selector ⇒ Object
Returns the value of attribute node_selector.
31 32 33 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 31 def node_selector @node_selector end |
#per_device_node_selection ⇒ Object
PerDeviceNodeSelection defines whether the access from nodes to resources in the pool is set on the ResourceSlice level or on each device. If it is set to true, every device defined the ResourceSlice must specify this individually. Exactly one of NodeName, NodeSelector, AllNodes, and PerDeviceNodeSelection must be set.
34 35 36 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 34 def per_device_node_selection @per_device_node_selection end |
#pool ⇒ Object
Returns the value of attribute pool.
36 37 38 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 36 def pool @pool end |
#shared_counters ⇒ Object
SharedCounters defines a list of counter sets, each of which has a name and a list of counters available. The names of the counter sets must be unique in the ResourcePool. Only one of Devices and SharedCounters can be set in a ResourceSlice. The maximum number of counter sets is 8.
39 40 41 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 39 def shared_counters @shared_counters end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 56 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 42 def self.attribute_map { :'all_nodes' => :'allNodes', :'devices' => :'devices', :'driver' => :'driver', :'node_name' => :'nodeName', :'node_selector' => :'nodeSelector', :'per_device_node_selection' => :'perDeviceNodeSelection', :'pool' => :'pool', :'shared_counters' => :'sharedCounters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 185 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 61 def self.openapi_types { :'all_nodes' => :'Boolean', :'devices' => :'Array<V1beta2Device>', :'driver' => :'String', :'node_name' => :'String', :'node_selector' => :'V1NodeSelector', :'per_device_node_selection' => :'Boolean', :'pool' => :'V1beta2ResourcePool', :'shared_counters' => :'Array<V1beta2CounterSet>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && all_nodes == o.all_nodes && devices == o.devices && driver == o.driver && node_name == o.node_name && node_selector == o.node_selector && per_device_node_selection == o.per_device_node_selection && pool == o.pool && shared_counters == o.shared_counters end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 215 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Kubernetes.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 286 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 192 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
172 173 174 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 172 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 178 def hash [all_nodes, devices, driver, node_name, node_selector, per_device_node_selection, pool, shared_counters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 134 def list_invalid_properties invalid_properties = Array.new if @driver.nil? invalid_properties.push('invalid value for "driver", driver cannot be nil.') end if @pool.nil? invalid_properties.push('invalid value for "pool", pool cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
262 263 264 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 262 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
256 257 258 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 256 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 |
# File 'lib/kubernetes/models/v1beta2_resource_slice_spec.rb', line 149 def valid? return false if @driver.nil? return false if @pool.nil? true end |